@@ -17,8 +17,6 @@ package org.eclipse.jdt.compiler.apt.tests.processors.elements;
 import static org.junit.Assert.fail;
 
 import java.io.IOException;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -26,7 +24,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
-
 import javax.annotation.processing.ProcessingEnvironment;
 import javax.annotation.processing.RoundEnvironment;
 import javax.annotation.processing.SupportedAnnotationTypes;
@@ -45,7 +42,6 @@ import javax.lang.model.type.PrimitiveType;
 import javax.lang.model.type.TypeKind;
 import javax.lang.model.type.TypeMirror;
 import javax.lang.model.util.ElementFilter;
-
 import org.eclipse.jdt.internal.compiler.apt.dispatch.BaseProcessingEnvImpl;
 
 @SupportedAnnotationTypes("*")
@@ -82,7 +78,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
 					super.reportSuccess();
 				}
 			} catch (AssertionFailedError e) {
-				super.reportError(getExceptionStackTrace(e));
+				super.reportError(e);
 			} catch (Throwable e) {
 				e.printStackTrace();
 			}
@@ -90,28 +86,6 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		return false;
 	}
 
-	private boolean invokeTestMethods(Map<String, String> options) throws Throwable {
-		Method testMethod = null;
-		Set<String> keys = options.keySet();
-		boolean testsFound = false;
-		for (String option : keys) {
-			if (option.startsWith("test")) {
-				try {
-					testMethod = this.getClass().getDeclaredMethod(option, new Class[0]);
-					if (testMethod != null) {
-						testsFound = true;
-						testMethod.invoke(this,  new Object[0]);
-					}
-				} catch (InvocationTargetException e) {
-					throw e.getCause();
-				} catch (Exception e) {
-					super.reportError(getExceptionStackTrace(e));
-				}
-			}
-		}
-		return testsFound;
-	}
-
 	public void testAll() throws AssertionFailedError, IOException {
 		testPreviewFlagTrue();
 		testRecords1();
@@ -305,8 +279,8 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		recordComponent = (RecordComponentElement) element;
 		verifyAnnotations(recordComponent, new String[]{});
 		List<ExecutableElement> methodsIn = ElementFilter.methodsIn(enclosedElements);
-		List<String> actualMethodNames = methodsIn.stream().filter((m) -> m.getSimpleName().toString().startsWith("comp"))
-																	.map((m) -> m.getSimpleName().toString())
+		List<String> actualMethodNames = methodsIn.stream().filter(m -> m.getSimpleName().toString().startsWith("comp"))
+																	.map(m -> m.getSimpleName().toString())
 																	.collect(Collectors.toList());
 		assertEquals("incorrect method", 6, actualMethodNames.size());
 		for (ExecutableElement method : methodsIn) {
@@ -428,8 +402,8 @@ public class RecordElementProcessor extends BaseElementProcessor {
             assertEquals("expected enclosed Record Components mismatch", expRecComps.get(key), actRecComp.asType().getKind());
         }
 
-        List<String> actualMethodNames = methods.stream().map((m) -> m.getSimpleName().toString()).collect(Collectors.toList());
-        List<String> actualRecordCompNames = actRecComps.stream().map((m) -> m.getSimpleName().toString()).collect(Collectors.toList());
+        List<String> actualMethodNames = methods.stream().map(m -> m.getSimpleName().toString()).collect(Collectors.toList());
+        List<String> actualRecordCompNames = actRecComps.stream().map(m -> m.getSimpleName().toString()).collect(Collectors.toList());
 
         //checking the size
         assertEquals("expected enclosed Record Components size mismatch", expMethodNames.size(), actualMethodNames.size());
@@ -465,7 +439,7 @@ public class RecordElementProcessor extends BaseElementProcessor {
             assertEquals("expected enclosed Record Components mismatch", expRecComps.get(key), actRecComp.asType().getKind());
         }
 
-        List<String> actualRecordCompNames = actRecComps.stream().map((m) -> m.getSimpleName().toString()).collect(Collectors.toList());
+        List<String> actualRecordCompNames = actRecComps.stream().map(m -> m.getSimpleName().toString()).collect(Collectors.toList());
 
         if (!actualRecordCompNames.containsAll(expRecComppNames)) {
         	fail(" expected enclosed record components mismatch - expected at least : " + expRecComppNames + " " +
@@ -490,16 +464,16 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		assertTrue("Constructors must be within all members", members.containsAll(constructors));
 		assertTrue("Constructors must be within enclosed elements", enclosedElements.containsAll(constructors));
 		assertEquals("Overloaded versions of ElementFilter.constructorsIn() must return equal results",
-				new HashSet<Element>(constructors), constructorsSet);
+				new HashSet<>(constructors), constructorsSet);
 
 		assertTrue("Methods must be within all members", members.containsAll(methods));
 		assertTrue("Methods must be within enclosed elements", enclosedElements.containsAll(methods));
 		assertEquals("Overloaded versions of ElementFilter.methodsIn() must return equal results",
-				new HashSet<Element>(methods), methodsSet);
+				new HashSet<>(methods), methodsSet);
 
 		assertTrue("Fields must be within all members", members.containsAll(fields));
 		assertTrue("Fields must be within enclosed elements", enclosedElements.containsAll(fields));
-		assertEquals("Overloaded versions of ElementFilter.fieldsIn() must return equal results", new HashSet<Element>(fields), fieldsSet);
+		assertEquals("Overloaded versions of ElementFilter.fieldsIn() must return equal results", new HashSet<>(fields), fieldsSet);
 	}
 	public void testRecords7() {
 		TypeElement recordElement = _elementUtils.getTypeElement("records.Record2");
@@ -592,6 +566,15 @@ public class RecordElementProcessor extends BaseElementProcessor {
 		VariableElement var = parameters.get(0);
 		assertEquals("component name incorrect", "i", var.getSimpleName().toString());
 		verifyAnnotations(var, new String[]{"@Marker4()"});
+		asType = var.asType();
+		verifyAnnotations(asType, new String[]{});
+
+		List<VariableElement> fieldsIn = ElementFilter.fieldsIn(enclosedElements);
+		assertEquals("incorrect method", 1, methodsIn.size());
+		VariableElement field = fieldsIn.get(0);
+		verifyAnnotations(field, new String[]{"@Marker4()"});
+		asType = field.asType();
+		verifyAnnotations(asType, new String[]{});
 	}
 	public void testRecordsConstructors() {
 		Set<? extends Element> elements = roundEnv.getRootElements();
