@@ -20,16 +20,13 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.ArrayList;
 import java.util.List;
-
 import javax.lang.model.SourceVersion;
 import javax.tools.JavaCompiler;
 import javax.tools.ToolProvider;
-
+import junit.framework.TestCase;
 import org.eclipse.jdt.compiler.apt.tests.NegativeTests.TestDiagnosticListener;
 import org.eclipse.jdt.internal.compiler.tool.EclipseCompiler;
 
-import junit.framework.TestCase;
-
 public class Java9ElementsTests extends TestCase {
 	private static final String MODULE_PROC = "org.eclipse.jdt.compiler.apt.tests.processors.elements.Java9ElementProcessor";
 	
@@ -434,7 +431,7 @@ public class Java9ElementsTests extends TestCase {
 		JavaCompiler compiler = BatchTestUtils.getEclipseCompiler();
 		final String autoModuleJar = BatchTestUtils.setupProcessorJar("lib/lib.x.jar", BatchTestUtils._tmpFolder);
 		internalTest(compiler, MODULE_PROC, "testBug572673", null, "bug572673", true, 
-				(options) -> {
+				options -> {
 					options.add("--module-path");
 					options.add(BatchTestUtils._jls8ProcessorJarPath + 
 							File.pathSeparator + autoModuleJar);
@@ -509,7 +506,7 @@ public class Java9ElementsTests extends TestCase {
 		}
 
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-A" + processor);
 		options.add("-A" + testMethod);
 		options.add("-processor");
@@ -539,7 +536,7 @@ public class Java9ElementsTests extends TestCase {
 			BatchTestUtils.writeFile(targetFile, source[i++].getBytes());
 		}
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-processor");
 		options.add(MODULE_PROC);
 		options.add("-A" + processor);
@@ -570,7 +567,7 @@ public class Java9ElementsTests extends TestCase {
 		}
 
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-A" + processor);
 		options.add("-A" + testMethod);
 		if (compiler instanceof EclipseCompiler) {
@@ -603,7 +600,7 @@ public class Java9ElementsTests extends TestCase {
 		File srcRoot = TestUtils.concatPath(BatchTestUtils.getSrcFolderName());
 		BatchTestUtils.copyResources("mod_locations" + File.separator + modLocation, srcRoot);
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-processor");
 		options.add(processor);
 		options.add("-A" + processor);
@@ -625,7 +622,7 @@ public class Java9ElementsTests extends TestCase {
 		File srcRoot = TestUtils.concatPath(BatchTestUtils.getSrcFolderName());
 		BatchTestUtils.copyResources("mod_locations/modules", srcRoot);
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-processor");
 		options.add(processor);
 		options.add("-A" + processor);
@@ -647,7 +644,7 @@ public class Java9ElementsTests extends TestCase {
 		File srcRoot = TestUtils.concatPath(BatchTestUtils.getSrcFolderName());
 		BatchTestUtils.copyResources("mod_locations/modules", srcRoot);
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-processor");
 		options.add(processor);
 		options.add("-A" + processor);
