@@ -30,7 +30,6 @@ import java.util.List;
 import java.util.Properties;
 import java.util.Set;
 import java.util.logging.LogRecord;
-
 import javax.lang.model.SourceVersion;
 import javax.tools.FileObject;
 import javax.tools.ForwardingJavaFileObject;
@@ -39,13 +38,11 @@ import javax.tools.JavaFileObject;
 import javax.tools.JavaFileObject.Kind;
 import javax.tools.StandardJavaFileManager;
 import javax.tools.StandardLocation;
-
+import junit.framework.Test;
 import org.eclipse.jdt.internal.compiler.batch.Main;
-import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileReader;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;
-
-import junit.framework.Test;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 public class CompilerInvocationTests extends AbstractCompilerToolTest {
 	static {
@@ -57,7 +54,7 @@ public CompilerInvocationTests(String name) {
 	super(name);
 }
 public static Test suite() {
-	return buildUniqueComplianceTestSuite(CompilerInvocationTests.class, ClassFileConstants.JDK1_6);
+	return buildUniqueComplianceTestSuite(CompilerInvocationTests.class, CompilerOptions.getFirstSupportedJdkLevel());
 }
 public static Class<CompilerInvocationTests> testClass() {
 	return CompilerInvocationTests.class;
@@ -81,7 +78,34 @@ protected void checkClassFiles(String[] fileNames) {
 			fail("IO exception for file " + fileNames[i]);
 		}
 		assertNotNull("Could not read " + fileNames[i], reader);
-		assertEquals("Wrong Java version for " + fileNames[i], ClassFileConstants.JDK1_6, reader.getVersion());
+		assertEquals("Wrong Java version for " + fileNames[i], CompilerOptions.getFirstSupportedJdkLevel(), reader.getVersion());
+	}
+}
+void runTest(
+		boolean shouldCompileOK,
+		String[] sourceFiles,
+		StandardJavaFileManager standardJavaFileManager,
+		String source,
+		List<String> options,
+		String[] compileFileNames,
+		String expectedOutOutputString,
+		String expectedErrOutputString,
+		boolean shouldFlushOutputDirectory,
+		String[] classFileNames) {
+	List<String> opt = options == null ? new ArrayList<>() : new ArrayList<>(options);
+	opt.add("-source");
+	opt.add(source);
+	super.runTest(
+		shouldCompileOK,
+		sourceFiles,
+		new CompilerInvocationTestsArguments(standardJavaFileManager, opt, compileFileNames),
+		expectedOutOutputString,
+		expectedErrOutputString,
+		shouldFlushOutputDirectory,
+		null /* progress */);
+	// TODO maxime introduce stderr comparison based upon specific diagnostic listener
+	if (classFileNames != null) {
+		checkClassFiles(classFileNames);
 	}
 }
 void runTest(
@@ -96,7 +120,7 @@ void runTest(
 		String[] classFileNames) {
 	List<String> opt = options == null ? new ArrayList<>() : new ArrayList<>(options);
 	opt.add("-source");
-	opt.add("1.6");
+	opt.add(CompilerOptions.getFirstSupportedJavaVersion());
 	super.runTest(
 		shouldCompileOK,
 		sourceFiles,
@@ -152,7 +176,7 @@ abstract class GetJavaFileDetector extends ForwardingStandardJavaFileManager<Sta
 	@Override
 	public Iterable<? extends JavaFileObject> getJavaFileObjectsFromFiles(
 			Iterable<? extends File> files) {
-		ArrayList<JavaFileObject> result = new ArrayList<JavaFileObject>();
+		ArrayList<JavaFileObject> result = new ArrayList<>();
 		for (JavaFileObject file: super.getJavaFileObjectsFromFiles(files)) {
 			result.add(detector(file));
 		}
@@ -161,7 +185,7 @@ abstract class GetJavaFileDetector extends ForwardingStandardJavaFileManager<Sta
 	@Override
 	public Iterable<? extends JavaFileObject> getJavaFileObjectsFromStrings(
 			Iterable<String> names) {
-		ArrayList<JavaFileObject> result = new ArrayList<JavaFileObject>();
+		ArrayList<JavaFileObject> result = new ArrayList<>();
 		for (JavaFileObject file: getJavaFileObjectsFromStrings(names)) {
 			result.add(detector(file));
 		}
@@ -170,7 +194,7 @@ abstract class GetJavaFileDetector extends ForwardingStandardJavaFileManager<Sta
 	@Override
 	public Iterable<JavaFileObject> list(Location location, String packageName,
 			Set<Kind> kinds, boolean recurse) throws IOException {
-		ArrayList<JavaFileObject> result = new ArrayList<JavaFileObject>();
+		ArrayList<JavaFileObject> result = new ArrayList<>();
 		for (JavaFileObject file: super.list(location, packageName, kinds, recurse)) {
 			result.add(detector(file));
 		}
@@ -562,7 +586,7 @@ public void test009_options_consumption() throws IOException {
 	StandardJavaFileManager ecjStandardJavaFileManager =
 		COMPILER.getStandardFileManager(null /* diagnosticListener */, null /* locale */, null /* charset */);
 	for (String option: CompilerToolTests.ONE_ARG_OPTIONS) {
-		if (isOnJRE9() && (option.equals("-extdirs") || option.equals("-endorseddirs")))
+		if (isOnJRE9() && option.equals("-endorseddirs"))
 				continue;
 		if (ecjStandardJavaFileManager.isSupportedOption(option) != -1) { // some options that the compiler support could well not be supported by the file manager
 			Iterator<String> remaining = remainingAsList.iterator();
@@ -996,14 +1020,8 @@ public void test021_output_streams() throws IOException {
 		Arrays.asList("-v"), null, null);
 	assertTrue(task.call());
 	Properties properties = new Properties();
-	InputStream resourceAsStream = null;
-	try {
-		resourceAsStream = Main.class.getResourceAsStream("messages.properties");
+	try (InputStream resourceAsStream = Main.class.getResourceAsStream("messages.properties")) {
 		properties.load(resourceAsStream);
-	} finally {
-		if (resourceAsStream != null) {
-			resourceAsStream.close();
-		}
 	}
 	assertTrue(outBuffer.toString().startsWith(properties.getProperty("compiler.name")));
 	assertTrue(errBuffer.toString().isEmpty());
@@ -1091,4 +1109,50 @@ public void test024_bug577550_test_empty_classes_argument() {
 					.getJavaFileObjectsFromFiles(Arrays.asList(new File(OUTPUT_DIR + File.separator + "X.java"))))
 			.call());
 }
+public void test025_extdirs_1() {
+	runTest(
+		true /* shouldCompileOK */,
+		new String [] { /* sourceFiles */
+			"X.java",
+			"public class X {}",
+		},
+		null /* standardJavaFileManager */,
+		"1.8",
+		Arrays.asList("-d", OUTPUT_DIR, "-extdirs", LIB_DIR) /* options */,
+		new String[] { /* compileFileNames */
+			"X.java"
+		},
+		"" /* expectedOutOutputString */,
+		"" /* expectedErrOutputString */,
+		true /* shouldFlushOutputDirectory */,
+		new String[] { /* classFileNames */
+			"X.class"
+		});
+}
+public void test025_extdirs_2() {
+	String trace = null;
+	try {
+		runTest(
+			true /* shouldCompileOK */,
+			new String [] { /* sourceFiles */
+				"X.java",
+				"public class X {}",
+			},
+			null /* standardJavaFileManager */,
+			"9",
+			Arrays.asList("-d", OUTPUT_DIR, "-extdirs", LIB_DIR) /* options */,
+			new String[] { /* compileFileNames */
+				"X.java"
+			},
+			"" /* expectedOutOutputString */,
+			"" /* expectedErrOutputString */,
+			true /* shouldFlushOutputDirectory */,
+			new String[] { /* classFileNames */
+				"X.class"
+			});
+	} catch(IllegalArgumentException iae) {
+		trace = iae.getMessage();
+	}
+	assertEquals("IAE not thrown", "option -extdirs not supported at compliance level 9 and above", trace);
+}
 }
