@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2017, 2021 IBM Corporation and others.
+ * Copyright (c) 2017, 2024 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -21,6 +21,9 @@ import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.StringWriter;
 import java.io.Writer;
+import java.lang.reflect.InvocationHandler;
+import java.lang.reflect.Method;
+import java.lang.reflect.Proxy;
 import java.net.URL;
 import java.nio.charset.Charset;
 import java.nio.file.Files;
@@ -33,21 +36,20 @@ import java.util.Locale;
 import java.util.ServiceLoader;
 import java.util.Set;
 import java.util.function.Consumer;
-
 import javax.lang.model.SourceVersion;
 import javax.tools.Diagnostic;
 import javax.tools.FileObject;
 import javax.tools.ForwardingJavaFileManager;
 import javax.tools.JavaCompiler;
+import javax.tools.JavaCompiler.CompilationTask;
 import javax.tools.JavaFileManager;
-import javax.tools.JavaFileObject;
 import javax.tools.JavaFileManager.Location;
+import javax.tools.JavaFileObject;
 import javax.tools.JavaFileObject.Kind;
 import javax.tools.StandardJavaFileManager;
 import javax.tools.StandardLocation;
 import javax.tools.ToolProvider;
-import javax.tools.JavaCompiler.CompilationTask;
-
+import junit.framework.TestCase;
 import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.jdt.compiler.tool.tests.AbstractCompilerToolTest.CompilerInvocationDiagnosticListener;
@@ -58,8 +60,6 @@ import org.eclipse.jdt.internal.compiler.tool.EclipseCompiler;
 import org.junit.FixMethodOrder;
 import org.junit.runners.MethodSorters;
 
-import junit.framework.TestCase;
-
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
 public class CompilerToolJava9Tests extends TestCase {
 	private static final boolean DEBUG = false;
@@ -218,7 +218,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		}
 	}
 	public ForwardingJavaFileManager<JavaFileManager> getFileManager(JavaFileManager manager) {
-		return new ForwardingJavaFileManager<JavaFileManager>(manager) {
+		return new ForwardingJavaFileManager<>(manager) {
 			@Override
 			public FileObject getFileForInput(Location location, String packageName, String relativeName)
 					throws IOException {
@@ -256,7 +256,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow9) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))) {
@@ -266,13 +266,13 @@ public class CompilerToolJava9Tests extends TestCase {
 			} catch (IOException e1) {
 				e1.printStackTrace();
 			}
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
 
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -318,7 +318,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow9) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))){
@@ -329,13 +329,13 @@ public class CompilerToolJava9Tests extends TestCase {
 				e1.printStackTrace();
 			}
 			// create new list containing input file
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
 
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -381,7 +381,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow9) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))){
@@ -394,13 +394,13 @@ public class CompilerToolJava9Tests extends TestCase {
 			
 
 			// create new list containing input file
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
 
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -431,7 +431,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow9) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))) {
@@ -450,13 +450,13 @@ public class CompilerToolJava9Tests extends TestCase {
 			}
 
 			// create new list containing input file
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
 
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -520,7 +520,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow12) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))){
@@ -534,12 +534,12 @@ public class CompilerToolJava9Tests extends TestCase {
 				e.printStackTrace();
 			}
 			// create new list containing input file
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -551,7 +551,6 @@ public class CompilerToolJava9Tests extends TestCase {
 			Boolean result = task.call();
 			printWriter.flush();
 			printWriter.close();
-			System.err.println(stringWriter.getBuffer().toString());
 			if (result.booleanValue()) {
 				System.err.println("Compilation did not fail as expected: " + stringWriter.getBuffer().toString());
 				assertTrue("Compilation did not fail as expected", false);
@@ -564,7 +563,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		if (this.isJREBelow12) return;
 		JavaCompiler compiler = this.compilers[1];
 		StandardJavaFileManager standardManager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
-		Consumer<JavaFileManager> cons = (manager) -> {
+		Consumer<JavaFileManager> cons = manager -> {
 			String tmpFolder = _tmpFolder;
 			File inputFile = new File(tmpFolder, "X.java");
 			try (Writer writer = new BufferedWriter(new FileWriter(inputFile))){
@@ -578,12 +577,12 @@ public class CompilerToolJava9Tests extends TestCase {
 				e.printStackTrace();
 			}
 			// create new list containing input file
-			List<File> files = new ArrayList<File>();
+			List<File> files = new ArrayList<>();
 			files.add(inputFile);
 			Iterable<? extends JavaFileObject> units = standardManager.getJavaFileObjectsFromFiles(files);
 			StringWriter stringWriter = new StringWriter();
 			PrintWriter printWriter = new PrintWriter(stringWriter);
-			List<String> options = new ArrayList<String>();
+			List<String> options = new ArrayList<>();
 			options.add("-d");
 			options.add(tmpFolder);
 			options.add("--release");
@@ -696,7 +695,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		StandardJavaFileManager manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 
 		// create new list containing input file
-		List<File> files = new ArrayList<File>();
+		List<File> files = new ArrayList<>();
 		files.add(new File(modules_directory + File.separator + "source" + File.separator + "SimpleModules" +
 										File.separator + "module.one" + File.separator + "module-info.java"));
 		files.add(new File(modules_directory + File.separator + "source" + File.separator + "SimpleModules" +
@@ -705,7 +704,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		StringWriter stringWriter = new StringWriter();
 		PrintWriter printWriter = new PrintWriter(stringWriter);
 
-		List<String> options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
 		options.add("-d");
 		options.add(tmpFolder);
 		options.add("--module-source-path");
@@ -734,14 +733,14 @@ public class CompilerToolJava9Tests extends TestCase {
 		manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 
 		// create new list containing input file
-		files = new ArrayList<File>();
+		files = new ArrayList<>();
 		files.add(new File(modules_directory + File.separator + "bug565748" + File.separator + 
 									"mod.test" + File.separator + "module-info.java"));
 		units = manager.getJavaFileObjectsFromFiles(files);
 		stringWriter = new StringWriter();
 		printWriter = new PrintWriter(stringWriter);
 
-		options = new ArrayList<String>();
+		options = new ArrayList<>();
 		options.add("-d");
 		options.add(tmpFolder);
 		options.add("--module-path");
@@ -780,14 +779,14 @@ public class CompilerToolJava9Tests extends TestCase {
  		manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 
  		// create new list containing input file
- 		files = new ArrayList<File>();
+ 		files = new ArrayList<>();
  		files.add(new File(modules_directory + File.separator + "bug565748" + File.separator + 
  				"mod.test" + File.separator + "module-info.java"));
  		units = manager.getJavaFileObjectsFromFiles(files);
  		stringWriter = new StringWriter();
  		printWriter = new PrintWriter(stringWriter);
 
- 		options = new ArrayList<String>();
+ 		options = new ArrayList<>();
  		options.add("-d");
  		options.add(tmpFolder);
  		options.add("--module-path");
@@ -820,7 +819,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		StandardJavaFileManager manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 
 		// create new list containing input file
-		List<File> files = new ArrayList<File>();
+		List<File> files = new ArrayList<>();
 		files.add(new File(modules_directory + File.separator + "bug566749" + File.separator + 
  				"mod.test" + File.separator + "module-info.java"));
 		
@@ -828,8 +827,8 @@ public class CompilerToolJava9Tests extends TestCase {
 		StringWriter stringWriter = new StringWriter();
 		PrintWriter printWriter = new PrintWriter(stringWriter);
 
-		List<String> options = new ArrayList<String>();
-		options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
+		options = new ArrayList<>();
  		options.add("-d");
  		options.add(tmpFolder);
  		options.add("--module-path");
@@ -861,7 +860,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		StandardJavaFileManager manager = compiler.getStandardFileManager(null, Locale.getDefault(), Charset.defaultCharset());
 
 		// create new list containing input file
-		List<File> files = new ArrayList<File>();
+		List<File> files = new ArrayList<>();
 		files.add(new File(modules_directory + File.separator + "bug574097" + File.separator + 
  				"mod.one" + File.separator + "module-info.java"));
 		files.add(new File(modules_directory + File.separator + "bug574097" + File.separator + 
@@ -871,8 +870,8 @@ public class CompilerToolJava9Tests extends TestCase {
 		StringWriter stringWriter = new StringWriter();
 		PrintWriter printWriter = new PrintWriter(stringWriter);
 
-		List<String> options = new ArrayList<String>();
-		options = new ArrayList<String>();
+		List<String> options = new ArrayList<>();
+		options = new ArrayList<>();
  		options.add("-d");
  		options.add(tmpFolder);
  		options.add("--module-path");
@@ -958,6 +957,93 @@ public class CompilerToolJava9Tests extends TestCase {
 		//-- We must now also have a diagnostic
 		assertTrue("The diagnostic listener did not receive an error for the illegal option", b.listener().hasDiagnostic("option -source is not supported when --release is used"));
 	}
+	
+	/**
+	 * Proxy that transparently delegates to a JavaFileManager impl, but hides the physical
+	 * implementation of the delegated file manager to prevent ECJ performing analysis based
+	 * on the superclasses of the file manager object.
+	 */
+	static class DemotingFileManagerProxy implements InvocationHandler {
+		private final JavaFileManager fileManager;
+		
+		private DemotingFileManagerProxy(JavaFileManager fileManager) {
+			this.fileManager = fileManager;
+		}
+		
+		@Override
+		public Object invoke(Object proxy, Method method, Object[] args) throws Throwable {
+			System.err.printf("Calling %s(%s)%n", method.getName(), Arrays.toString(args));
+			try {
+				var result = method.invoke(fileManager, args);
+				System.err.printf("Call to %s(%s) returned %s%n", method.getName(), Arrays.toString(args), result);
+				return result;
+			} catch (Throwable ex) {
+				ex.printStackTrace();
+				throw ex;
+			}
+		}
+		
+		public static JavaFileManager demote(JavaFileManager fileManager) {
+			return (JavaFileManager) Proxy.newProxyInstance(
+					fileManager.getClass().getClassLoader(),
+					new Class<?>[]{ JavaFileManager.class },
+					new DemotingFileManagerProxy(fileManager)
+					);
+		}
+	}
+	public void testGH958() throws Exception {
+		File classOutput = new File(_tmpFolder);
+		JavaCompiler compiler = new EclipseCompiler();
+		StandardJavaFileManager standardFileManager = compiler.getStandardFileManager(null, null, null);
+
+		List<File> modulePath = List.of(new File("resources/module_locations/GH958_automod.jar"));
+		List<File> sourcePath = List.of(new File("resources/module_locations/GH958"));
+		standardFileManager.setLocation(StandardLocation.MODULE_PATH, modulePath);
+		standardFileManager.setLocation(StandardLocation.SOURCE_PATH, sourcePath);
+		standardFileManager.setLocation(StandardLocation.CLASS_OUTPUT, List.of(classOutput));
+
+		// Make ECJ think we don't inherit StandardJavaFileManager by wrapping it.
+		JavaFileManager demotedFileManager = DemotingFileManagerProxy.demote(standardFileManager);
+		Iterable<JavaFileObject> compilationUnits = demotedFileManager.list(StandardLocation.SOURCE_PATH, "", Set.of(JavaFileObject.Kind.SOURCE), true);
+
+		CompilationTask task = compiler.getTask(
+				null,
+				demotedFileManager,
+				null,
+				List.of("--release", "11", "-verbose"),
+				List.of(),
+				compilationUnits
+		);
+
+		assertTrue(task.call());
+	}
+	public void testGH958_2modules() throws Exception {
+		File classOutput = new File(_tmpFolder);
+		JavaCompiler compiler = new EclipseCompiler();
+		StandardJavaFileManager standardFileManager = compiler.getStandardFileManager(null, null, null);
+
+		List<File> modulesPath = List.of(new File("resources/module_locations/GH958_automod.jar"),
+											new File("resources/module_locations/GH958_mod.jar"));
+		List<File> sourcePath = List.of(new File("resources/module_locations/GH958_2"));
+		standardFileManager.setLocation(StandardLocation.MODULE_PATH, modulesPath);
+		standardFileManager.setLocation(StandardLocation.SOURCE_PATH, sourcePath);
+		standardFileManager.setLocation(StandardLocation.CLASS_OUTPUT, List.of(classOutput));
+
+		// Make ECJ think we don't inherit StandardJavaFileManager by wrapping it.
+		JavaFileManager demotedFileManager = DemotingFileManagerProxy.demote(standardFileManager);
+		Iterable<JavaFileObject> compilationUnits = demotedFileManager.list(StandardLocation.SOURCE_PATH, "", Set.of(JavaFileObject.Kind.SOURCE), true);
+
+		CompilationTask task = compiler.getTask(
+				null,
+				demotedFileManager,
+				null,
+				List.of("--release", "11", "-verbose"),
+				List.of(),
+				compilationUnits
+		);
+
+		assertTrue(task.call());
+	}
 
 	/**
 	 * Helps with building a compiler invocation, handling the common parts of testing.
@@ -1011,7 +1097,7 @@ public class CompilerToolJava9Tests extends TestCase {
 		}
 
 		public ForwardingJavaFileManager<StandardJavaFileManager> createFileManager(StandardJavaFileManager manager) {
-			ForwardingJavaFileManager<StandardJavaFileManager> forwardingJavaFileManager = new ForwardingJavaFileManager<StandardJavaFileManager>(manager) {
+			ForwardingJavaFileManager<StandardJavaFileManager> forwardingJavaFileManager = new ForwardingJavaFileManager<>(manager) {
 				@Override
 				public FileObject getFileForInput(Location location, String packageName, String relativeName)
 						throws IOException {
@@ -1114,7 +1200,7 @@ public class CompilerToolJava9Tests extends TestCase {
 	 *
 	 * @param src
 	 *            the full path to the resource location.
-	 * @param destFolder
+	 * @param dest
 	 *            the full path to the destination location.
 	 */
 	public static void copyResource(File src, File dest) throws IOException {
@@ -1174,7 +1260,7 @@ public class CompilerToolJava9Tests extends TestCase {
 	 * named "CVS" will be ignored.
 	 * @param resourceFolderName the name of the source folder, relative to
 	 * <code>[plugin-root]/resources</code>
-	 * @param the absolute path of the destination folder
+	 * @param destFolder the absolute path of the destination folder
 	 */
 	public static void copyResources(String resourceFolderName, File destFolder) throws IOException {
 		File resDir = new File(getPluginDirectoryPath(), RESOURCES_DIR);
@@ -1226,7 +1312,7 @@ public class CompilerToolJava9Tests extends TestCase {
 
 	public static String convertToIndependentLineDelimiter(String source) {
 		if (source.indexOf('\n') == -1 && source.indexOf('\r') == -1) return source;
-		StringBuffer buffer = new StringBuffer();
+		StringBuilder buffer = new StringBuilder();
 		for (int i = 0, length = source.length(); i < length; i++) {
 			char car = source.charAt(i);
 			if (car == '\r') {
