@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2023 IBM Corporation and others.
+ * Copyright (c) 2000, 2025 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,41 +53,13 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.internal.compiler.ASTVisitor;
 import org.eclipse.jdt.internal.compiler.ast.TypeReference.AnnotationPosition;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.env.AccessRestriction;
-import org.eclipse.jdt.internal.compiler.lookup.AnnotationBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ArrayBinding;
-import org.eclipse.jdt.internal.compiler.lookup.Binding;
-import org.eclipse.jdt.internal.compiler.lookup.BlockScope;
-import org.eclipse.jdt.internal.compiler.lookup.ExtraCompilerModifiers;
-import org.eclipse.jdt.internal.compiler.lookup.FieldBinding;
-import org.eclipse.jdt.internal.compiler.lookup.InferenceContext18;
-import org.eclipse.jdt.internal.compiler.lookup.InvocationSite;
-import org.eclipse.jdt.internal.compiler.lookup.LocalVariableBinding;
-import org.eclipse.jdt.internal.compiler.lookup.LookupEnvironment;
-import org.eclipse.jdt.internal.compiler.lookup.MethodBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ModuleBinding;
-import org.eclipse.jdt.internal.compiler.lookup.PackageBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ParameterizedGenericMethodBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ParameterizedMethodBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ParameterizedTypeBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ProblemMethodBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ProblemReasons;
-import org.eclipse.jdt.internal.compiler.lookup.RecordComponentBinding;
-import org.eclipse.jdt.internal.compiler.lookup.ReferenceBinding;
-import org.eclipse.jdt.internal.compiler.lookup.Scope;
-import org.eclipse.jdt.internal.compiler.lookup.SourceTypeBinding;
-import org.eclipse.jdt.internal.compiler.lookup.TagBits;
-import org.eclipse.jdt.internal.compiler.lookup.TypeBinding;
-import org.eclipse.jdt.internal.compiler.lookup.TypeConstants;
-import org.eclipse.jdt.internal.compiler.lookup.TypeIds;
-import org.eclipse.jdt.internal.compiler.lookup.TypeVariableBinding;
-import org.eclipse.jdt.internal.compiler.lookup.VariableBinding;
-import org.eclipse.jdt.internal.compiler.lookup.WildcardBinding;
+import org.eclipse.jdt.internal.compiler.env.IBinaryAnnotation;
+import org.eclipse.jdt.internal.compiler.lookup.*;
 
 @SuppressWarnings({"rawtypes", "unchecked"})
 public abstract class ASTNode implements TypeConstants, TypeIds {
@@ -104,12 +76,12 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public final static int Bit7 = 0x40;					// depth (name ref, msg) | need runtime checkcast (cast expression) | label used (labelStatement) | needFreeReturn (AbstractMethodDeclaration) | Used in Pattern Guard expression (NameReference)
 	public final static int Bit8 = 0x80;					// depth (name ref, msg) | unsafe cast (cast expression) | is default constructor (constructor declaration) | isElseStatementUnreachable (if statement)
 	public final static int Bit9 = 0x100;				// depth (name ref, msg) | operator (operator) | is local type (type decl) | isThenStatementUnreachable (if statement) | can be static
-	public final static int Bit10= 0x200;				// depth (name ref, msg) | operator (operator) | is anonymous type (type decl) | is implicit constructor (constructor)
+	public final static int Bit10= 0x200;				// depth (name ref, msg) | operator (operator) | is anonymous type (type decl)
 	public final static int Bit11 = 0x400;				// depth (name ref, msg) | operator (operator) | is member type (type decl)
 	public final static int Bit12 = 0x800;				// depth (name ref, msg) | operator (operator) | has abstract methods (type decl)
 	public final static int Bit13 = 0x1000;			// depth (name ref, msg) | operator (operator) | is secondary type (type decl)
 	public final static int Bit14 = 0x2000;			// strictly assigned (reference lhs) | discard enclosing instance (explicit constr call) | hasBeenGenerated (type decl)
-	public final static int Bit15 = 0x4000;			// is unnecessary cast (expression) | is varargs (type ref) | isSubRoutineEscaping (try statement) | superAccess (javadoc allocation expression/javadoc message send/javadoc return statement)
+	public final static int Bit15 = 0x4000;			// is unnecessary cast (expression) | is varargs (type ref) | IsFinallyBlockEscaping (try statement) | superAccess (javadoc allocation expression/javadoc message send/javadoc return statement)
 	public final static int Bit16 = 0x8000;			// in javadoc comment (name ref, type ref, msg)
 	public final static int Bit17 = 0x10000;			// compound assigned (reference lhs) | unchecked (msg, alloc, explicit constr call)
 	public final static int Bit18 = 0x20000;			// non null (expression) | onDemand (import reference)
@@ -124,7 +96,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public final static int Bit27 = 0x4000000;		// parenthesis count (expression)
 	public final static int Bit28 = 0x8000000;		// parenthesis count (expression)
 	public final static int Bit29 = 0x10000000;		// parenthesis count (expression)
-	public final static int Bit30 = 0x20000000;		// elseif (if statement) | try block exit (try statement) | fall-through (case statement) | ignore no effect assign (expression ref) | needScope (for statement) | isAnySubRoutineEscaping (return statement) | blockExit (synchronized statement)
+	public final static int Bit30 = 0x20000000;		// elseif (if statement) | try block exit (try statement) | fall-through (case statement) | ignore no effect assign (expression ref) | needScope (for statement) | IsAnyFinallyBlockEscaping (return|yield statement) | blockExit (synchronized statement)
 	public final static int Bit31 = 0x40000000;		// local declaration reachable (local decl) | ignore raw type check (type ref) | discard entire assignment (assignment) | isSynchronized (return statement) | thenExit (if statement)
 	public final static int Bit32 = 0x80000000;		// reachable (statement)
 
@@ -187,6 +159,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int IsForeachElementVariable = Bit5;
 	public static final int ShadowsOuterLocal = Bit22;
 	public static final int IsAdditionalDeclarator = Bit23;
+	public static final int IsPatternVariable = Bit24;
 
 	// for name refs or local decls
 	public static final int FirstAssignmentToLocal = Bit4;
@@ -205,7 +178,6 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int IsSecretYieldValueUsage = Bit5;
 
 	// for statements
-//	public static final int IsImplicit = Bit11; // record declaration
 	public static final int IsReachable = Bit32;
 	public static final int LabelUsed = Bit7;
 	public static final int DocumentedFallthrough = Bit30; // switch statement
@@ -213,7 +185,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 
 
 	// try statements
-	public static final int IsSubRoutineEscaping = Bit15;
+	public static final int IsFinallyBlockEscaping = Bit15;
 	public static final int IsTryBlockExiting = Bit30;
 
 	// for type declaration
@@ -229,13 +201,16 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int HasLocalType = Bit2; // cannot conflict with AddAssertionMASK
 	public static final int HasBeenResolved = Bit5; // field decl only (to handle forward references)
 
+	// for lambda expressions
+	public static final int ArgumentsTypeElided = Bit2; // A lambda with var typed arguments is considered to be type elided, but the Arguments themselves are considered var typed.
+
 	// for expression
 	public static final int ParenthesizedSHIFT = 21; // Bit22 -> Bit29
 	public static final int ParenthesizedMASK = Bit22|Bit23|Bit24|Bit25|Bit26|Bit27|Bit28|Bit29; // 8 bits for parenthesis count value (max. 255)
 	public static final int IgnoreNoEffectAssignCheck = Bit30;
 
 	// for references on lhs of assignment
-	public static final int IsStrictlyAssigned = Bit14; // set only for true assignments, as opposed to compound ones
+	public static final int IsStrictlyAssigned = Bit14; // set only for true assignments, as opposed to compound ones. Used also for JEP 482 to allow assignment, but not read
 	public static final int IsCompoundAssigned = Bit17; // set only for compound assignments, as opposed to other ones
 
 	// for explicit constructor call
@@ -251,6 +226,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int IsUsefulEmptyStatement = Bit1;
 
 	// for block and method declaration
+	public static final int BlockShouldEndDead = Bit1;
 	public static final int UndocumentedEmptyBlock = Bit4;
 	public static final int OverridingMethodWithSupercall = Bit5;
 	public static final int CanBeStatic = Bit9;   // used to flag a method that can be declared static
@@ -264,7 +240,6 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	// for constructor declaration
 	public static final int IsDefaultConstructor = Bit8;
 	public static final int IsCanonicalConstructor = Bit10; // record declaration
-	public static final int IsImplicit = Bit11; // record declaration / generated statements in compact constructor
 
 	// for compilation unit
 	public static final int HasAllMethodBodies = Bit5;
@@ -286,7 +261,6 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int IsThenStatementUnreachable = Bit9; // as computed by control flow analysis or null analysis
 
 	// for type reference
-	public static final int IsSuperType = Bit5;
 	public static final int IsVarArgs = Bit15;
 	public static final int IgnoreRawTypeCheck = Bit31;
 
@@ -302,13 +276,13 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	// for import reference
 	public static final int OnDemand = Bit18;
 	public static final int Used = Bit2;
-	public static final int inModule = Bit19;
+	public static final int inModule = Bit19; // signals the package reference of an exports or opens declaration
 
 	// for parameterized qualified/single type ref
 	public static final int DidResolve = Bit19;
 
-	// for return statement
-	public static final int IsAnySubRoutineEscaping = Bit30;
+	// for return & yield statements
+	public static final int IsAnyFinallyBlockEscaping = Bit30;
 	public static final int IsSynchronized = Bit31;
 
 	// for synchronized statement
@@ -339,15 +313,17 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public static final int InsideExpressionStatement = Bit21;
 
 	// for annotation reference, signal if annotation was created from a default:
-	// also used for implicit method creation of records Java 14
 	public static final int IsSynthetic = ASTNode.Bit7;
 
 	// for all reference context entries.
 	public static final int HasFunctionalInterfaceTypes = ASTNode.Bit22;
 
+	public static final FieldDeclaration [] NO_FIELD_DECLARATIONS = new FieldDeclaration [0];
 	public static final Argument [] NO_ARGUMENTS = new Argument [0];
 	public static final RecordComponent [] NO_RECORD_COMPONENTS = new RecordComponent [0];
 	public static final TypePattern[] NO_TYPE_PATTERNS = new TypePattern[0];
+	public static final LocalVariableBinding[] NO_VARIABLES = new LocalVariableBinding[0];
+	public static final Annotation[] NO_ANNOTATIONS = new Annotation[0];
 
 	public ASTNode() {
 
@@ -381,8 +357,6 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return INVOCATION_ARGUMENT_OK;
 	}
 	public static boolean checkInvocationArguments(BlockScope scope, Expression receiver, TypeBinding receiverType, MethodBinding method, Expression[] arguments, TypeBinding[] argumentTypes, boolean argsContainCast, InvocationSite invocationSite) {
-		long sourceLevel = scope.compilerOptions().sourceLevel;
-		boolean is1_7 = sourceLevel >= ClassFileConstants.JDK1_7;
 		TypeBinding[] params = method.parameters;
 		int paramLength = params.length;
 		boolean isRawMemberInvocation = !method.isStatic()
@@ -405,7 +379,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 			if (method.isVarargs()) {
 				TypeBinding parameterType = ((ArrayBinding) params[paramLength-1]).elementsType(); // no element was supplied for vararg parameter
 				if (!parameterType.isReifiable()
-						&& (!is1_7 || ((method.tagBits & TagBits.AnnotationSafeVarargs) == 0))) {
+						&& (method.tagBits & TagBits.AnnotationSafeVarargs) == 0) {
 					scope.problemReporter().unsafeGenericArrayForVarargs(parameterType, (ASTNode)invocationSite);
 				}
 			}
@@ -425,7 +399,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 					if (paramLength != argLength || parameterType.dimensions() != argumentTypes[lastIndex].dimensions()) {
 						parameterType = ((ArrayBinding) parameterType).elementsType(); // single element was provided for vararg parameter
 						if (!parameterType.isReifiable()
-								&& (!is1_7 || ((method.tagBits & TagBits.AnnotationSafeVarargs) == 0))) {
+								&& (method.tagBits & TagBits.AnnotationSafeVarargs) == 0) {
 							scope.problemReporter().unsafeGenericArrayForVarargs(parameterType, (ASTNode)invocationSite);
 						}
 						originalRawParam = rawOriginalGenericMethod == null ? null : ((ArrayBinding)rawOriginalGenericMethod.parameters[lastIndex]).elementsType();
@@ -480,20 +454,16 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 				scope.problemReporter().unsafeRawGenericMethodInvocation((ASTNode)invocationSite, method, argumentTypes);
 				return true;
 			}
-			if (sourceLevel >= ClassFileConstants.JDK1_8)
-				return true; // signal to erase return type and exceptions, while keeping javac compatibility at 1.7-
+			return true; // signal to erase return type and exceptions, while keeping javac compatibility at 1.7-
 		}
 		return false;
 	}
 	public ASTNode concreteStatement() {
 		return this;
 	}
-	private void reportPreviewAPI(Scope scope, long modifiers) {
-		if (scope.compilerOptions().enablePreviewFeatures)
-			return;
-		if((modifiers & TagBits.AnnotationPreviewFeature) == TagBits.AnnotationPreviewFeature) {
-			scope.problemReporter().previewAPIUsed(this.sourceStart, this.sourceEnd,
-					(modifiers & TagBits.EssentialAPI) != 0);
+	private void reportPreviewAPI(Scope scope, IBinaryAnnotation previewAnnotation) {
+		if(previewAnnotation != null) {
+			scope.problemReporter().previewAPIUsed(scope, this.sourceStart, this.sourceEnd, previewAnnotation);
 		}
 	}
 	public final boolean isFieldUseDeprecated(FieldBinding field, Scope scope, int filteredBits) {
@@ -508,7 +478,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 			else
 				field.original().modifiers |= ExtraCompilerModifiers.AccLocallyUsed;
 		}
-		reportPreviewAPI(scope, field.tagBits);
+		reportPreviewAPI(scope, field.binaryPreviewAnnotation);
 
 		if ((field.modifiers & ExtraCompilerModifiers.AccRestrictedAccess) != 0) {
 			ModuleBinding module = field.declaringClass.module();
@@ -548,7 +518,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	public final boolean isMethodUseDeprecated(MethodBinding method, Scope scope,
 			boolean isExplicitUse, InvocationSite invocation) {
 
-		reportPreviewAPI(scope, method.tagBits);
+		reportPreviewAPI(scope, method.binaryPreviewAnnotation);
 
 		// ignore references insing Javadoc comments
 		if ((this.bits & ASTNode.InsideJavadoc) == 0 && method.isOrEnclosedByPrivateType() && !scope.isDefinedInMethod(method)) {
@@ -629,7 +599,9 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 			// ignore cases where type is used from inside itself
 			((ReferenceBinding)refType.erasure()).modifiers |= ExtraCompilerModifiers.AccLocallyUsed;
 		}
-		reportPreviewAPI(scope, type.extendedTagBits);
+		if (type instanceof BinaryTypeBinding btb) {
+			reportPreviewAPI(scope, btb.binaryPreviewAnnotation);
+		}
 		if (refType.hasRestrictedAccess()) {
 			ModuleBinding module = refType.module();
 			LookupEnvironment env = (module == null) ? scope.environment() : module.environment;
@@ -663,9 +635,9 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return false;
 	}
 
-	public abstract StringBuffer print(int indent, StringBuffer output);
+	public abstract StringBuilder print(int indent, StringBuilder output);
 
-	public static StringBuffer printAnnotations(Annotation[] annotations, StringBuffer output) {
+	public static StringBuilder printAnnotations(Annotation[] annotations, StringBuilder output) {
 		int length = annotations.length;
 		for (int i = 0; i < length; i++) {
 			if (i > 0) {
@@ -681,13 +653,13 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return output;
 	}
 
-	public static StringBuffer printIndent(int indent, StringBuffer output) {
+	public static StringBuilder printIndent(int indent, StringBuilder output) {
 
 		for (int i = indent; i > 0; i--) output.append("  "); //$NON-NLS-1$
 		return output;
 	}
 
-	public static StringBuffer printModifiers(int modifiers, StringBuffer output) {
+	public static StringBuilder printModifiers(int modifiers, StringBuilder output) {
 
 		if ((modifiers & ClassFileConstants.AccPublic) != 0)
 			output.append("public "); //$NON-NLS-1$
@@ -718,6 +690,14 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return output;
 	}
 
+	public static void resolveStatements(Statement[] statements, BlockScope scope) {
+		LocalVariableBinding [] livePatternVariables = NO_VARIABLES;
+		for (final Statement stmt : statements) {
+			stmt.resolveWithBindings(livePatternVariables, scope);
+			livePatternVariables = LocalVariableBinding.merge(livePatternVariables, stmt.bindingsWhenComplete());
+		}
+	}
+
 	/**
 	 * After method lookup has produced 'methodBinding' but when poly expressions have been seen as arguments,
 	 * inspect the arguments to trigger another round of resolving with improved target types from the methods parameters.
@@ -730,6 +710,16 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 	 * @return either the original method or a problem method
 	 */
 	public static MethodBinding resolvePolyExpressionArguments(Invocation invocation, MethodBinding method, TypeBinding[] argumentTypes, BlockScope scope) {
+		ClassScope cScope = scope.enclosingClassScope();
+		boolean resolvingPolyExpressionArguments = cScope.resolvingPolyExpressionArguments;
+		try {
+			cScope.resolvingPolyExpressionArguments = true;
+			return resolvePolyExpressionArguments0(invocation, method, argumentTypes, scope);
+		} finally {
+			cScope.resolvingPolyExpressionArguments = resolvingPolyExpressionArguments;
+		}
+	}
+	private static MethodBinding resolvePolyExpressionArguments0(Invocation invocation, MethodBinding method, TypeBinding[] argumentTypes, BlockScope scope) {
 		MethodBinding candidateMethod = method.isValidBinding() ? method : method instanceof ProblemMethodBinding ? ((ProblemMethodBinding) method).closestMatch : null;
 		if (candidateMethod == null)
 			return method;
@@ -812,74 +802,29 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		int length = sourceAnnotations == null ? 0 : sourceAnnotations.length;
 		if (recipient != null) {
 			switch (recipient.kind()) {
+				case Binding.MODULE:
 				case Binding.PACKAGE :
-					PackageBinding packageBinding = (PackageBinding) recipient;
-					if ((packageBinding.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					packageBinding.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					break;
 				case Binding.TYPE :
 				case Binding.GENERIC_TYPE :
-					ReferenceBinding type = (ReferenceBinding) recipient;
-					if ((type.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					type.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					if (length > 0) {
-						annotations = new AnnotationBinding[length];
-						type.setAnnotations(annotations, false);
-					}
-					break;
 				case Binding.METHOD :
-					MethodBinding method = (MethodBinding) recipient;
-					if ((method.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					method.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					if (length > 0) {
-						annotations = new AnnotationBinding[length];
-						method.setAnnotations(annotations, false);
-					}
-					break;
 				case Binding.FIELD :
-					FieldBinding field = (FieldBinding) recipient;
-					if ((field.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					field.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					if (length > 0) {
-						annotations = new AnnotationBinding[length];
-						field.setAnnotations(annotations, false);
-					}
-					break;
 				case Binding.RECORD_COMPONENT :
-					RecordComponentBinding rcb = (RecordComponentBinding) recipient;
-					if ((rcb.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					rcb.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					if (length > 0) {
-						annotations = new AnnotationBinding[length];
-						rcb.setAnnotations(annotations, false);
-					}
-					break;
 				case Binding.LOCAL :
-					LocalVariableBinding local = (LocalVariableBinding) recipient;
-					if ((local.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					local.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
+					if (ExtendedTagBits.areAllAnnotationsResolved(recipient.extendedTagBits)) return annotations;
+					recipient.extendedTagBits |= ExtendedTagBits.AllAnnotationsResolved;
 					if (length > 0) {
 						annotations = new AnnotationBinding[length];
-						local.setAnnotations(annotations, scope, false);
+						recipient.setAnnotations(annotations, scope, false);
 					}
 					break;
 				case Binding.TYPE_PARAMETER :
-					((TypeVariableBinding) recipient).tagBits |= TagBits.AnnotationResolved;
+					recipient.extendedTagBits |= ExtendedTagBits.AllAnnotationsResolved;
 					//$FALL-THROUGH$
 				case Binding.TYPE_USE :
 					// for TYPE_USE we deliberately don't set the annotation resolved tagbits,
 					// it is not material and also we are working with a dummy static object.
 					annotations = new AnnotationBinding[length];
 					break;
-				case Binding.MODULE:
-					ModuleBinding module = (ModuleBinding)recipient;
-					if ((module.tagBits & TagBits.AnnotationResolved) != 0) return annotations;
-					module.tagBits |= (TagBits.AnnotationResolved | TagBits.DeprecatedAnnotationResolved);
-					if (length > 0) {
-						annotations = new AnnotationBinding[length];
-						module.setAnnotations(annotations, scope, false);
-					}
-					break;
 				default :
 					return annotations;
 			}
@@ -892,28 +837,11 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 			if (annotationRecipient != null && recipient != null) {
 				// only local and field can share annotations and their types.
 				switch (recipient.kind()) {
-					case Binding.TYPE_USE:
-						if (annotations != null) {
-							// need to fill the instances array
-							for (int j = 0; j < length; j++) {
-								annotations[j] = sourceAnnotations[j].getCompilerAnnotation();
-							}
-						}
-						break;
 					case Binding.FIELD :
-						FieldBinding field = (FieldBinding) recipient;
-						field.tagBits = ((FieldBinding) annotationRecipient).tagBits;
-						if (annotations != null) {
-							// need to fill the instances array
-							for (int j = 0; j < length; j++) {
-								Annotation annot = sourceAnnotations[j];
-								annotations[j] = annot.getCompilerAnnotation();
-							}
-						}
-						break;
 					case Binding.RECORD_COMPONENT :
-						RecordComponentBinding recordComponentBinding = (RecordComponentBinding) recipient;
-						recordComponentBinding.tagBits = ((RecordComponentBinding) annotationRecipient).tagBits;
+						recipient.tagBits = annotationRecipient.tagBits;
+						//$FALL-THROUGH$
+					case Binding.TYPE_USE: // deliberately not setting tagBits (see above)
 						if (annotations != null) {
 							// need to fill the instances array
 							for (int j = 0; j < length; j++) {
@@ -921,11 +849,11 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 								annotations[j] = annot.getCompilerAnnotation();
 							}
 						}
-						break;
+						return annotations;
 					case Binding.LOCAL :
 						LocalVariableBinding local = (LocalVariableBinding) recipient;
 						// Note for JDK>=14, this could be LVB or RCB, hence typecasting to VB
-						long otherLocalTagBits = ((VariableBinding) annotationRecipient).tagBits;
+						long otherLocalTagBits = annotationRecipient.tagBits;
 						// Make sure we retain the TagBits.IsArgument bit
 						local.tagBits = otherLocalTagBits | (local.tagBits & TagBits.IsArgument);
 						if ((otherLocalTagBits & TagBits.AnnotationSuppressWarnings) == 0) {
@@ -939,7 +867,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 							}
 						} else if (annotations != null) {
 							// One of the annotations at least is a SuppressWarnings annotation
-							LocalDeclaration localDeclaration = local.declaration;
+							AbstractVariableDeclaration localDeclaration = local.declaration;
 							int declarationSourceEnd = localDeclaration.declarationSourceEnd;
 							int declarationSourceStart = localDeclaration.declarationSourceStart;
 							for (int j = 0; j < length; j++) {
@@ -962,9 +890,10 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 						// copy the se8 annotations.
 						if (annotationRecipient instanceof RecordComponentBinding && copySE8AnnotationsToType)
 							copySE8AnnotationsToType(scope, recipient, sourceAnnotations, false);
-						break;
+						return annotations;
+					default:
+						annotations[i] = annotation.compilerAnnotation;
 				}
-				return annotations;
 			} else {
 				annotation.recipient = recipient;
 				annotation.resolveType(scope);
@@ -972,6 +901,7 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 				if (annotations != null) {
 					annotations[i] = annotation.getCompilerAnnotation();
 				}
+				tagMissingAnalysisAnnotation(scope, recipient, annotation);
 			}
 		}
 
@@ -1047,7 +977,33 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return annotations;
 	}
 
-	/**	Resolve JSR308 annotations on a type reference, array creation expression or a wildcard. Type parameters go directly to the subroutine,
+	private static void tagMissingAnalysisAnnotation(Scope scope, Binding recipient, Annotation annotation) {
+		long extendedTagBits = scope.environment().checkForMissingAnalysisAnnotation(annotation.resolvedType);
+		if (extendedTagBits != 0) {
+			if (recipient instanceof MethodBinding method) {
+				method.extendedTagBits |= extendedTagBits;
+			} else if (recipient instanceof VariableBinding variable) {
+				if (extendedTagBits == ExtendedTagBits.HasMissingOwningAnnotation
+						&& scope instanceof MethodScope methodScope
+						&& variable.isParameter()
+						&& variable instanceof LocalVariableBinding local
+						&& local.declaration instanceof Argument arg)
+				{
+					Argument[] arguments = methodScope.referenceMethod().arguments;
+					for (int j=0;j < arguments.length;j++){
+						if (arguments[j] == arg) {
+							methodScope.referenceMethodBinding().original().markMissingOwningAnnotationOnParameter(j);
+							break;
+						}
+					}
+				} else if (variable instanceof FieldBinding field) {
+					field.extendedTagBits |= extendedTagBits;
+				}
+			}
+		}
+	}
+
+	/**	Resolve JSR308 annotations on a type reference, array creation expression or a wildcard. Type parameters go directly to the method/ctor,
 	    By construction the bindings associated with QTR, PQTR etc get resolved first and then annotations for different levels get resolved
 	    and applied at one go. Likewise for multidimensional arrays.
 
@@ -1200,8 +1156,8 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 						recordComponent.bits |= HasTypeAnnotations;
 						recordComponent.type.bits |= HasTypeAnnotations;
 						recordComponentBinding.type = mergeAnnotationsIntoType(scope, se8Annotations, se8nullBits, se8NullAnnotation, recordComponent.type,
-								Binding.DefaultLocationField, recordComponentBinding.type);
-						if(scope.environment().usesNullTypeAnnotations()) { //TODO Bug 562478
+								Binding.DefaultLocationRecordComponent, recordComponentBinding.type);
+						if (scope.environment().usesNullTypeAnnotations()) { //TODO Bug 562478
 							recordComponentBinding.tagBits &= ~(se8nullBits);
 						}
 					}
@@ -1332,8 +1288,9 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 			}
 			oldLeafType = oldLeafType.withoutToplevelNullAnnotation();
 		} else if (se8nullBits == TagBits.AnnotationNonNull
-					&& location != Binding.DefaultLocationReturnType // normal return type cases are handled in MethodBinding.fillInDefaultNonNullness18()
-					&& location != Binding.DefaultLocationField      // normal field type cases are handled in FieldBinding.fillInDefaultNonNullness()
+					&& location != Binding.DefaultLocationReturnType      // normal return type cases are handled in MethodBinding.fillInDefaultNonNullness18()
+					&& location != Binding.DefaultLocationField           // normal field type cases are handled in VariableBinding.fillInDefaultNonNullness()
+					&& location != Binding.DefaultLocationRecordComponent // record component type cases are handled in VariableBinding.fillInDefaultNonNullness()
 					&& scope.hasDefaultNullnessForType(typeRef.resolvedType, location, typeRef.sourceStart)) {
 			scope.problemReporter().nullAnnotationIsRedundant(typeRef, new Annotation[] { se8NullAnnotation });
 		}
@@ -1356,126 +1313,66 @@ public abstract class ASTNode implements TypeConstants, TypeIds {
 		return typeRef.resolvedType;
 	}
 
-/**
- * Figures if @Deprecated annotation is specified, do not resolve entire annotations.
- */
-public static void resolveDeprecatedAnnotations(BlockScope scope, Annotation[] annotations, Binding recipient) {
-	if (recipient != null) {
-		int kind = recipient.kind();
-		if (annotations != null) {
-			int length;
-			if ((length = annotations.length) >= 0) {
-				switch (kind) {
-					case Binding.PACKAGE :
-						PackageBinding packageBinding = (PackageBinding) recipient;
-						if ((packageBinding.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					case Binding.TYPE :
-					case Binding.GENERIC_TYPE :
-						ReferenceBinding type = (ReferenceBinding) recipient;
-						if ((type.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					case Binding.METHOD :
-						MethodBinding method = (MethodBinding) recipient;
-						if ((method.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					case Binding.FIELD :
-						FieldBinding field = (FieldBinding) recipient;
-						if ((field.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					case Binding.LOCAL :
-						LocalVariableBinding local = (LocalVariableBinding) recipient;
-						if ((local.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					case Binding.RECORD_COMPONENT :
-						RecordComponentBinding recordComponentBinding = (RecordComponentBinding) recipient;
-						if ((recordComponentBinding.tagBits & TagBits.DeprecatedAnnotationResolved) != 0) return;
-						break;
-					default :
+	/**
+	 * Figures if @Deprecated annotation is specified, do not resolve entire annotations.
+	 */
+	public static void resolveDeprecatedAnnotations(BlockScope scope, Annotation[] annotations, Binding recipient) {
+		if (recipient != null) {
+			if (annotations != null) {
+				int length;
+				if ((length = annotations.length) >= 0) {
+					if ((recipient.extendedTagBits & ExtendedTagBits.DeprecatedAnnotationResolved) != 0)
 						return;
-				}
-				for (int i = 0; i < length; i++) {
-					TypeReference annotationTypeRef = annotations[i].type;
-					// only resolve type name if 'Deprecated' last token
-					if (!CharOperation.equals(TypeConstants.JAVA_LANG_DEPRECATED[2], annotationTypeRef.getLastToken())) continue;
-					TypeBinding annotationType = annotations[i].type.resolveType(scope);
-					if(annotationType != null && annotationType.isValidBinding() && annotationType.id == TypeIds.T_JavaLangDeprecated) {
-						long deprecationTagBits = TagBits.AnnotationDeprecated | TagBits.DeprecatedAnnotationResolved;
-						if (scope.compilerOptions().complianceLevel >= ClassFileConstants.JDK9) {
-							for (MemberValuePair memberValuePair : annotations[i].memberValuePairs()) {
-								if (CharOperation.equals(memberValuePair.name, TypeConstants.FOR_REMOVAL)) {
-									if (memberValuePair.value instanceof TrueLiteral)
-										deprecationTagBits |= TagBits.AnnotationTerminallyDeprecated;
-									break;
+					for (int i = 0; i < length; i++) {
+						TypeReference annotationTypeRef = annotations[i].type;
+						// only resolve type name if 'Deprecated' last token
+						if (!CharOperation.equals(TypeConstants.JAVA_LANG_DEPRECATED[2], annotationTypeRef.getLastToken())) continue;
+						TypeBinding annotationType = annotations[i].type.resolveType(scope);
+						if(annotationType != null && annotationType.isValidBinding() && annotationType.id == TypeIds.T_JavaLangDeprecated) {
+							long deprecationTagBits = TagBits.AnnotationDeprecated;
+							if (scope.compilerOptions().complianceLevel >= ClassFileConstants.JDK9) {
+								for (MemberValuePair memberValuePair : annotations[i].memberValuePairs()) {
+									if (CharOperation.equals(memberValuePair.name, TypeConstants.FOR_REMOVAL)) {
+										if (memberValuePair.value instanceof TrueLiteral)
+											deprecationTagBits |= TagBits.AnnotationTerminallyDeprecated;
+										break;
+									}
 								}
+								annotations[i].recipient = recipient;
+								annotations[i].resolveType(scope); // allow downstream access to since & forRemoval
 							}
+							recipient.tagBits |= deprecationTagBits;
 						}
-						switch (kind) {
-							case Binding.PACKAGE :
-								PackageBinding packageBinding = (PackageBinding) recipient;
-								packageBinding.tagBits |= deprecationTagBits;
-								return;
-							case Binding.TYPE :
-							case Binding.GENERIC_TYPE :
-							case Binding.TYPE_PARAMETER :
-								ReferenceBinding type = (ReferenceBinding) recipient;
-								type.tagBits |= deprecationTagBits;
-								return;
-							case Binding.METHOD :
-								MethodBinding method = (MethodBinding) recipient;
-								method.tagBits |= deprecationTagBits;
-								return;
-							case Binding.FIELD :
-								FieldBinding field = (FieldBinding) recipient;
-								field.tagBits |= deprecationTagBits;
-								return;
-							case Binding.LOCAL :
-								LocalVariableBinding local = (LocalVariableBinding) recipient;
-								local.tagBits |= deprecationTagBits;
-								return;
-							case Binding.RECORD_COMPONENT :
-								RecordComponentBinding recordComponentBinding = (RecordComponentBinding) recipient;
-								recordComponentBinding.tagBits |= deprecationTagBits;
-								return;
-							default:
-								return;
+					}
+				}
+				recipient.extendedTagBits |= ExtendedTagBits.DeprecatedAnnotationResolved;
+			}
+		}
+	}
+	/**
+	 * Figures if @NonNullByDefault annotation is specified, do not resolve entire annotations.
+	 */
+	public static void resolveNullDefaultAnnotations(BlockScope scope, Annotation[] annotations, Binding recipient) {
+		if (recipient != null) {
+			if (annotations != null) {
+				int length;
+				if ((length = annotations.length) >= 0) {
+					if ((recipient.extendedTagBits & ExtendedTagBits.NullDefaultAnnotationResolved) != 0) return;
+					for (int i = 0; i < length; i++) {
+						TypeReference annotationTypeRef = annotations[i].type;
+						// only resolve type name if 'NonNullByDefault' last token (or corresponding configured annotation name)
+						if (!scope.environment().isNonNullByDefaultSimpleName(annotationTypeRef.getLastToken())) continue;
+						TypeBinding annotationType = annotations[i].type.resolveType(scope);
+						if(annotationType != null && annotationType.isValidBinding() && annotationType.hasTypeBit(TypeIds.BitNonNullByDefaultAnnotation)) {
+							annotations[i].recipient = recipient;
+							annotations[i].resolveType(scope); // possibly feeds bits into recipient.defaultNullness
 						}
 					}
 				}
 			}
-		}
-		switch (kind) {
-			case Binding.PACKAGE :
-				PackageBinding packageBinding = (PackageBinding) recipient;
-				packageBinding.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			case Binding.TYPE :
-			case Binding.GENERIC_TYPE :
-			case Binding.TYPE_PARAMETER :
-				ReferenceBinding type = (ReferenceBinding) recipient;
-				type.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			case Binding.METHOD :
-				MethodBinding method = (MethodBinding) recipient;
-				method.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			case Binding.FIELD :
-				FieldBinding field = (FieldBinding) recipient;
-				field.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			case Binding.LOCAL :
-				LocalVariableBinding local = (LocalVariableBinding) recipient;
-				local.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			case Binding.RECORD_COMPONENT :
-				RecordComponentBinding recordComponentBinding = (RecordComponentBinding) recipient;
-				recordComponentBinding.tagBits |= TagBits.DeprecatedAnnotationResolved;
-				return;
-			default:
-				return;
+			recipient.extendedTagBits |= ExtendedTagBits.NullDefaultAnnotationResolved;
 		}
 	}
-}
 
 	// ---- "default methods" for InvocationSite. Can we move to 1.8 and spare ourselves this ugliness please ?
 	public boolean checkingPotentialCompatibility() {
@@ -1496,7 +1393,7 @@ public static void resolveDeprecatedAnnotations(BlockScope scope, Annotation[] a
 	@Override
 	public String toString() {
 
-		return print(0, new StringBuffer(30)).toString();
+		return print(0, new StringBuilder(30)).toString();
 	}
 
 	public void traverse(ASTVisitor visitor, BlockScope scope) {
