@@ -18,9 +18,7 @@ import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
-
 import junit.framework.Test;
-
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.ToolFactory;
@@ -33,7 +31,6 @@ import org.eclipse.jdt.core.util.ILocalVariableTypeTableAttribute;
 import org.eclipse.jdt.core.util.ILocalVariableTypeTableEntry;
 import org.eclipse.jdt.core.util.IMethodInfo;
 import org.eclipse.jdt.core.util.ISignatureAttribute;
-import org.eclipse.jdt.internal.compiler.classfmt.ClassFileConstants;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFileReader;
 import org.eclipse.jdt.internal.compiler.classfmt.ClassFormatException;
 import org.eclipse.jdt.internal.compiler.env.IBinaryField;
@@ -43,13 +40,13 @@ import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 @SuppressWarnings({ "rawtypes" })
 public class GenericTypeSignatureTest extends AbstractRegressionTest {
 	static class Logger extends Thread {
-		StringBuffer buffer;
+		StringBuilder buffer;
 		InputStream inputStream;
 		String type;
 		Logger(InputStream inputStream, String type) {
 			this.inputStream = inputStream;
 			this.type = type;
-			this.buffer = new StringBuffer();
+			this.buffer = new StringBuilder();
 		}
 
 		@Override
@@ -79,7 +76,7 @@ public class GenericTypeSignatureTest extends AbstractRegressionTest {
 //		TESTS_RANGE = new int[] { 21, 50 };
 //	}
 	public static Test suite() {
-		return buildMinimalComplianceTestSuite(testClass(), F_1_5);
+		return buildMinimalComplianceTestSuite(testClass(), FIRST_SUPPORTED_JAVA_VERSION);
 	}
 
 	public static Class testClass() {
@@ -159,7 +156,7 @@ public class GenericTypeSignatureTest extends AbstractRegressionTest {
 					cmdLineAsString = cmdLine.toString();
 				}
 				// Launch process
-				process = Runtime.getRuntime().exec(cmdLineAsString, null, GenericTypeSignatureTest.this.dirPath.toFile());
+				process = Runtime.getRuntime().exec(cmdLineAsString.split("\\s"), null, GenericTypeSignatureTest.this.dirPath.toFile());
 	            // Log errors
 	            Logger errorLogger = new Logger(process.getErrorStream(), "ERROR");
 
@@ -175,10 +172,10 @@ public class GenericTypeSignatureTest extends AbstractRegressionTest {
 					System.out.println(testName+": javac has found error(s)!");
 				}
 			} catch (IOException ioe) {
-				System.out.println(testName+": Not possible to launch Sun javac compilation!");
+				System.out.println(testName+": Not possible to launch OpenJDK javac compilation!");
 			} catch (InterruptedException e1) {
 				if (process != null) process.destroy();
-				System.out.println(testName+": Sun javac compilation was aborted!");
+				System.out.println(testName+": OpenJDK javac compilation was aborted!");
 			}
 		} catch (Exception e) {
 			// fails silently...
@@ -1326,9 +1323,6 @@ public class GenericTypeSignatureTest extends AbstractRegressionTest {
 	}
 
 	public void testGenericVarargsMethodReferenceLambdasHaveNoSignature() {
-		// uses lambdas
-		if (this.complianceLevel < ClassFileConstants.JDK1_8)
-			return;
 		final String[] testsSource = new String[] {
 				"X.java",
 				"import java.util.Optional;\n" +
