@@ -15,13 +15,11 @@ package org.eclipse.jdt.core.tests.compiler.regression;
 
 import java.io.File;
 import java.io.IOException;
-
+import junit.framework.Test;
 import org.eclipse.jdt.core.tests.util.Util;
 import org.eclipse.jdt.internal.compiler.batch.ClasspathJrt;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
-import junit.framework.Test;
-
 public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 
 	protected static final String NONNULL_BY_DEFAULT_ANNOTATION_CONTENT = "package org.eclipse.jdt.annotation;\n" +
@@ -114,7 +112,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 	 * @see TestAll
 	 */
 	public static Test suite() {
-		return buildMinimalComplianceTestSuite(testClass(), F_1_5);
+		return buildMinimalComplianceTestSuite(testClass(), FIRST_SUPPORTED_JAVA_VERSION);
 	}
 
 	public static Class<?> testClass() {
@@ -165,7 +163,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -err:+nullAnnot -warn:-null -err:+nonnullNotRepeated -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"----------\n" +
@@ -190,7 +188,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 
 	// -warn option - regression tests to check option nullAnnot and missingNullDefault
 	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=372012
-	public void test315_warn_options() {
+	public void _2551_test315_warn_options() {
 		this.runConformTest(
 			new String[] {
 					"p/package-info.java",
@@ -220,7 +218,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot -warn:+null -missingNullDefault -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"",
@@ -246,7 +244,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p1" + File.separator + "X1.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot -warn:+null -missingNullDefault -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"----------\n" +
@@ -277,7 +275,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "X1.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot -warn:+null -missingNullDefault -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"----------\n" +
@@ -315,7 +313,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot(foo|bar) -warn:+null -nonNullByDefault -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"Token nullAnnot(foo|bar) is not in the expected format \"nullAnnot(<nullable annotation name> | <non null annotation name> | <non-null by default annotation name>)\"\n",
@@ -348,7 +346,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot -warn:+null,syntacticAnalysis -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"",
@@ -381,7 +379,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot -warn:-null -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"----------\n" +
@@ -432,7 +430,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "Sub.java\""
 			+ " -sourcepath \"" + OUTPUT_DIR + "\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -err:+nullAnnot,+null,+inheritNullAnnot -proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
 			"----------\n" +
@@ -479,7 +477,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 					"}"
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot(p.Nullable|p.NonNull|p.NonNullByDefault) -warn:+null -warn:-nullUncheckedConversion "
 			+ "-proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
@@ -509,7 +507,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 					"\"" + OUTPUT_DIR +  File.separator + "p2" + File.separator + "X2.java\""
 					+ " -sourcepath \"" + OUTPUT_DIR + "\""
 					+ " -classpath \"" + OUTPUT_DIR + "\""
-					+ " -1.5"
+					+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 					+ " -warn:+nullAnnot(org.eclipse.jdt.annotation.Nullable|org.eclipse.jdt.annotation.NonNull|org.eclipse.jdt.annotation.NonNullByDefault)"
 					+ " -warn:+nullAnnot(p.Nullable||p.NonNullByDefault) -warn+null -proc:none -d \"" + OUTPUT_DIR + "\"", // nonnull remains unset for secondaries
 					"",
@@ -561,7 +559,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 					"}"
 			},
 			"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
-			+ " -1.5"
+			+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 			+ " -warn:+nullAnnot(p.Nullable|p.NonNull|p.NonNullByDefault) -warn:+null -warn:-nullUncheckedConversion "
 			+ "-proc:none -d \"" + OUTPUT_DIR + "\"",
 			"",
@@ -593,7 +591,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				"\"" + OUTPUT_DIR +  File.separator + "p2" + File.separator + "X2.java\""
 				+ " -sourcepath \"" + OUTPUT_DIR + "\""
 				+ " -classpath \"" + OUTPUT_DIR + "\""
-				+ " -1.5"
+				+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 				+ " -warn:+nullAnnot(org.eclipse.jdt.annotation.Nullable|org.eclipse.jdt.annotation.NonNull|org.eclipse.jdt.annotation.NonNullByDefault)"
 				+ " -warn:+nullAnnot(|x.AbsentNonNull|) "
 				+ " -warn:+nullAnnot(p.Nullable||p.NonNullByDefault) "
@@ -641,7 +639,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				},
 				"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 				+ " -sourcepath \"" + OUTPUT_DIR + "\""
-				+ " -1.5"
+				+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 				+ " -properties " + OUTPUT_DIR + File.separator +".settings" + File.separator + "org.eclipse.jdt.core.prefs "
 				+ " -d \"" + OUTPUT_DIR + "\"",
 				"",
@@ -695,7 +693,7 @@ public class NullAnnotationBatchCompilerTest extends AbstractBatchCompilerTest {
 				},
 				"\"" + OUTPUT_DIR +  File.separator + "p" + File.separator + "X.java\""
 				+ " -sourcepath \"" + OUTPUT_DIR + "\""
-				+ " -1.5"
+				+ " -" + CompilerOptions.getFirstSupportedJavaVersion()
 				+ " -properties " + OUTPUT_DIR + File.separator +".settings" + File.separator + "org.eclipse.jdt.core.prefs "
 				+ " -d \"" + OUTPUT_DIR + "\"",
 				"",
