@@ -25,37 +25,10 @@ import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.Map;
-
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.compiler.IProblem;
-import org.eclipse.jdt.core.dom.AST;
-import org.eclipse.jdt.core.dom.ASTNode;
-import org.eclipse.jdt.core.dom.ASTParser;
-import org.eclipse.jdt.core.dom.Block;
-import org.eclipse.jdt.core.dom.CompilationUnit;
-import org.eclipse.jdt.core.dom.Expression;
-import org.eclipse.jdt.core.dom.ExpressionStatement;
-import org.eclipse.jdt.core.dom.FieldDeclaration;
-import org.eclipse.jdt.core.dom.FileASTRequestor;
-import org.eclipse.jdt.core.dom.IBinding;
-import org.eclipse.jdt.core.dom.IMethodBinding;
-import org.eclipse.jdt.core.dom.IPackageBinding;
-import org.eclipse.jdt.core.dom.ITypeBinding;
-import org.eclipse.jdt.core.dom.IVariableBinding;
-import org.eclipse.jdt.core.dom.MethodDeclaration;
-import org.eclipse.jdt.core.dom.MethodInvocation;
-import org.eclipse.jdt.core.dom.ModuleDeclaration;
-import org.eclipse.jdt.core.dom.Name;
-import org.eclipse.jdt.core.dom.NodeFinder;
-import org.eclipse.jdt.core.dom.SimpleName;
-import org.eclipse.jdt.core.dom.SimpleType;
-import org.eclipse.jdt.core.dom.SwitchExpression;
-import org.eclipse.jdt.core.dom.Type;
-import org.eclipse.jdt.core.dom.TypeDeclaration;
-import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
-import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
-import org.eclipse.jdt.core.dom.YieldStatement;
+import org.eclipse.jdt.core.dom.*;
 import org.eclipse.jdt.core.tests.compiler.regression.AbstractRegressionTest;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
@@ -65,6 +38,10 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		super(name);
 	}
 
+	static {
+		// TESTS_NAMES = new String [] { "testBug570472"};
+	}
+
 	private static final int AST_JLS_LATEST = AST.getJLSLatest();
 
 	public ASTNode runConversion(
@@ -243,7 +220,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		}
 
 		try {
-			final String canonicalPath = file.getCanonicalPath();
+			final String filePath = file.toPath().normalize().toAbsolutePath().toString();
 			final CompilationUnit[] units = new CompilationUnit[1];
 
 			FileASTRequestor requestor = new FileASTRequestor() {
@@ -253,15 +230,15 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 					}
 				}
 				public void acceptAST(String sourceFilePath, CompilationUnit ast) {
-					if (canonicalPath.equals(sourceFilePath)) {
+					if (filePath.equals(sourceFilePath)) {
 						units[0] = ast;
 					}
 				}
 			};
 
-			parser.setEnvironment(null, new String[] { rootDir.getCanonicalPath() }, null, true);
+			parser.setEnvironment(null, new String[] { rootDir.toPath().normalize().toAbsolutePath().toString() }, null, true);
 
-			parser.createASTs(new String[] {canonicalPath}, null, new String[] {key}, requestor, null);
+			parser.createASTs(new String[] {filePath}, null, new String[] {key}, requestor, null);
 
 			assertNotNull("No binding", bindings[0]);
 			assertEquals("Wrong type of binding", IBinding.TYPE, bindings[0].getKind());
@@ -354,7 +331,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		}
 
 		try {
-			final String canonicalPath = file.getCanonicalPath();
+			final String filePath = file.toPath().normalize().toAbsolutePath().toString();
 			final CompilationUnit[] units = new CompilationUnit[1];
 
 			FileASTRequestor requestor = new FileASTRequestor() {
@@ -368,15 +345,15 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 					}
 				}
 				public void acceptAST(String sourceFilePath, CompilationUnit ast) {
-					if (canonicalPath.equals(sourceFilePath)) {
+					if (filePath.equals(sourceFilePath)) {
 						units[0] = ast;
 					}
 				}
 			};
 
-			parser.setEnvironment(null, new String[] { rootDir.getCanonicalPath() }, null, true);
+			parser.setEnvironment(null, new String[] { rootDir.toPath().normalize().toAbsolutePath().toString() }, null, true);
 
-			parser.createASTs(new String[] {canonicalPath}, null, new String[] {key}, requestor, null);
+			parser.createASTs(new String[] {filePath}, null, new String[] {key}, requestor, null);
 
 			assertNotNull("No binding", bindings[0]);
 			assertEquals("Wrong type of binding", IBinding.TYPE, bindings[0].getKind());
@@ -453,7 +430,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		}
 
 		try {
-			final String canonicalPath = fileY.getCanonicalPath();
+			final String fileYPath = fileY.toPath().normalize().toAbsolutePath().toString();
 			final CompilationUnit[] units = new CompilationUnit[1];
 
 			FileASTRequestor requestor = new FileASTRequestor() {
@@ -467,15 +444,15 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 					}
 				}
 				public void acceptAST(String sourceFilePath, CompilationUnit ast) {
-					if (canonicalPath.equals(sourceFilePath)) {
+					if (fileYPath.equals(sourceFilePath)) {
 						units[0] = ast;
 					}
 				}
 			};
 
-			parser.setEnvironment(null, new String[] { rootDir.getCanonicalPath() }, null, true);
+			parser.setEnvironment(null, new String[] { rootDir.toPath().normalize().toAbsolutePath().toString() }, null, true);
 			org.eclipse.jdt.internal.core.builder.AbstractImageBuilder.MAX_AT_ONCE = 0;
-			parser.createASTs(new String[] {canonicalPath}, null, new String[] {key}, requestor, null);
+			parser.createASTs(new String[] {fileYPath}, null, new String[] {key}, requestor, null);
 			assertNotNull("No ast", units[0]);
 			assertEquals("No problem", 0, units[0].getProblems().length);
 		} finally {
@@ -542,7 +519,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		}
 
 		try {
-			final String canonicalPath = fileY.getCanonicalPath();
+			final String fileYPath = fileY.toPath().normalize().toAbsolutePath().toString();
 			final CompilationUnit[] units = new CompilationUnit[1];
 
 			FileASTRequestor requestor = new FileASTRequestor() {
@@ -556,14 +533,14 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 					}
 				}
 				public void acceptAST(String sourceFilePath, CompilationUnit ast) {
-					if (canonicalPath.equals(sourceFilePath)) {
+					if (fileYPath.equals(sourceFilePath)) {
 						units[0] = ast;
 					}
 				}
 			};
 
-			parser.setEnvironment(null, new String[] { rootDir.getCanonicalPath() }, null, true);
-			parser.createASTs(new String[] {canonicalPath}, null, new String[] {key}, requestor, null);
+			parser.setEnvironment(null, new String[] { rootDir.toPath().normalize().toAbsolutePath().toString() }, null, true);
+			parser.createASTs(new String[] {fileYPath}, null, new String[] {key}, requestor, null);
 			assertNotNull("No ast", units[0]);
 			IProblem[] problems = units[0].getProblems();
 			assertEquals("No problem", 1, problems.length);
@@ -623,7 +600,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			parser.setKind(ASTParser.K_COMPILATION_UNIT);
 			parser.setCompilerOptions(JavaCore.getOptions());
 			parser.createASTs(
-					new String[] { file.getCanonicalPath(), fileY.getCanonicalPath() },
+					new String[] { file.toPath().normalize().toAbsolutePath().toString(), fileY.toPath().normalize().toAbsolutePath().toString() },
 					null,
 					new String[] {},
 					new FileASTRequestor() {},
@@ -641,7 +618,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 				"  @V(v = A, d = \"\") Map p;\n" +
 				"}\n";
 		Map<String, String> options = JavaCore.getOptions();
-		JavaCore.setComplianceOptions(JavaCore.VERSION_1_7, options);
+		JavaCore.setComplianceOptions(CompilerOptions.getFirstSupportedJavaVersion(), options);
 		ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
 		parser.setCompilerOptions(options);
 		parser.setKind(ASTParser.K_COMPILATION_UNIT);
@@ -666,7 +643,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 				"  class InnerClass { }\n" +
 				"}\n";
 		Map<String, String> options = JavaCore.getOptions();
-		JavaCore.setComplianceOptions(JavaCore.VERSION_1_7, options);
+		JavaCore.setComplianceOptions(CompilerOptions.getFirstSupportedJavaVersion(), options);
 		ASTParser parser = ASTParser.newParser(AST.JLS9);
 		parser.setCompilerOptions(options);
 		parser.setKind(ASTParser.K_COMPILATION_UNIT);
@@ -797,18 +774,9 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			parser.setBindingsRecovery(true);
 			parser.setKind(ASTParser.K_COMPILATION_UNIT);
 			parser.setEnvironment(new String[0], new String[] { rootDir.getAbsolutePath() }, null, true);
-		    String[] files = null;
-			try {
-				files = new String[] {file.getCanonicalPath(), fileY.getCanonicalPath()};
-				parser.createASTs(files,
-						null,
-						new String[0],
-						astRequestor,
-						null);
-			} catch (IOException e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
+			String[] files = new String[] { file.toPath().normalize().toAbsolutePath().toString(),
+					fileY.toPath().normalize().toAbsolutePath().toString() };
+			parser.createASTs(files, null, new String[0], astRequestor, null);
 		} finally {
 			file.delete();
 			fileY.delete();
@@ -1603,18 +1571,9 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			parser.setBindingsRecovery(true);
 			parser.setKind(ASTParser.K_COMPILATION_UNIT);
 			parser.setEnvironment(new String[0], new String[] { rootDir.getAbsolutePath() }, null, true);
-		    String[] files = null;
-			try {
-				files = new String[] {file.getCanonicalPath(), fileY.getCanonicalPath()};
-				parser.createASTs(files,
-						null,
-						new String[0],
-						astRequestor,
-						null);
-			} catch (IOException e) {
-				// TODO Auto-generated catch block
-				e.printStackTrace();
-			}
+			String[] files = new String[] { file.toPath().normalize().toAbsolutePath().toString(),
+					fileY.toPath().normalize().toAbsolutePath().toString() };
+			parser.createASTs(files, null, new String[0], astRequestor, null);
 		} finally {
 			file.delete();
 			fileY.delete();
@@ -1679,12 +1638,12 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 		File packageDir = new File(rootDir, "p");
 		packageDir.mkdir();
 		File fileY = new File(packageDir, "Y.java");
-		String canonicalPath = fileY.getCanonicalPath();
+		String fileYPath = fileY.toPath().normalize().toAbsolutePath().toString();
 
 		packageDir = new File(rootDir, "p");
 		packageDir.mkdir();
 		fileY = new File(packageDir, "Z.java");
-		String canonicalPath2 = fileY.getCanonicalPath();
+		String fileZPath = fileY.toPath().normalize().toAbsolutePath().toString();
 
 		contents =
 				"enum X {\n" +
@@ -1714,7 +1673,7 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			parser.setResolveBindings(true);
 			parser.setCompilerOptions(JavaCore.getOptions());
 			parser.createASTs(
-					new String[] { file.getCanonicalPath(), canonicalPath, canonicalPath2, file2.getCanonicalPath() },
+					new String[] { file.toPath().normalize().toAbsolutePath().toString(), fileYPath, fileZPath, file2.toPath().normalize().toAbsolutePath().toString() },
 					null,
 					new String[] {},
 					new FileASTRequestor() {},
@@ -1956,5 +1915,115 @@ public class StandAloneASTParserTest extends AbstractRegressionTest {
 			assertEquals("Syntax error, insert \"AssignmentOperator Expression\" to complete Expression",cu.getProblems()[6].getMessage());
 	}
 
+	public void testBugGithub2402() throws JavaModelException {
+        String contents = """
+        			package test;
+					public class TestClass {
+					    @com.Missing
+					    public TestClass() {
+					        new test.TestClass();
+					    }
+					}
+					class com {
+					}
+        		""";
 
+        ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
+        parser.setResolveBindings(true);
+        parser.setStatementsRecovery(true);
+        parser.setBindingsRecovery(true);
+        parser.setKind(ASTParser.K_COMPILATION_UNIT);
+        parser.setEnvironment(new String[0], new String[0], null, false);
+        parser.setSource(contents.toCharArray());
+        parser.setUnitName("test.TestClass");
+        ASTNode node = parser.createAST(null);
+        assertTrue("Should be a compilation unit", node instanceof CompilationUnit);
+        CompilationUnit cu = (CompilationUnit) node;
+        TypeDeclaration type = (TypeDeclaration) cu.types().get(0);
+        MethodDeclaration method = (MethodDeclaration) type.bodyDeclarations().get(0);
+        ExpressionStatement stmt = (ExpressionStatement) method.getBody().statements().get(0);
+        ClassInstanceCreation expr = (ClassInstanceCreation) stmt.getExpression();
+        IMethodBinding ctorBinding = expr.resolveConstructorBinding();
+        assertNotNull(ctorBinding);
+        IAnnotationBinding[] annotations = ctorBinding.getAnnotations();
+        assertNotNull(annotations);
+}
+
+	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=570472
+	// Incorrect line number in Text Block having '\"' before endline
+	public void testBug570472() throws JavaModelException {
+        String contents = """
+				public class TestTextBlocks {
+
+				  public void str() {
+				    String question2 = \"\"\"
+				              \\"What's the point, really\\"
+				                            ?\"\"\";
+				  }
+				}
+        		""";
+
+        ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
+        parser.setResolveBindings(true);
+        parser.setStatementsRecovery(true);
+        parser.setBindingsRecovery(true);
+        parser.setKind(ASTParser.K_COMPILATION_UNIT);
+        parser.setEnvironment(new String[0], new String[0], null, false);
+        parser.setSource(contents.toCharArray());
+        parser.setUnitName("TestTextBlocks");
+        ASTNode node = parser.createAST(null);
+        assertTrue("Should be a compilation unit", node instanceof CompilationUnit);
+        CompilationUnit cu = (CompilationUnit) node;
+        int lineOfCharAt156 = cu.getLineNumber(156);
+        if (6 != lineOfCharAt156) {
+            throw new AssertionError();
+        }
+	}
+
+	// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/2462
+	// Incorrect line numbers when parsing text blocks
+	public void testIssue2462() throws JavaModelException {
+        String contents = """
+				public class TestWrongLineNumber {
+				    public static void main(String[] args) {
+				        String path = System.getenv("Path");
+				        String text = \"\"\"
+				                 text0 \\
+				                 text1 \\
+				                 text2 \\
+				                \"\"\";
+				        System.out.println(path.concat(text));
+				    }
+				}
+        		""";
+
+        ASTParser parser = ASTParser.newParser(AST_JLS_LATEST);
+        parser.setResolveBindings(true);
+        parser.setStatementsRecovery(true);
+        parser.setBindingsRecovery(true);
+        parser.setKind(ASTParser.K_COMPILATION_UNIT);
+        parser.setEnvironment(new String[0], new String[0], null, false);
+        parser.setSource(contents.toCharArray());
+        parser.setUnitName("TestTextBlocks");
+
+        CompilationUnit result = (CompilationUnit) parser.createAST(null);
+        assertTrue("Should be a compilation unit", result != null);
+
+        List<TypeDeclaration> listOfTypes = result.types();
+        for (TypeDeclaration td : listOfTypes) {
+            MethodDeclaration[] methods = td.getMethods();
+            for (MethodDeclaration m : methods) {
+                Block body = m.getBody();
+                List statments = body.statements();
+                for (var currentStatement : statments) {
+                    if (currentStatement instanceof ExpressionStatement) {
+                        ExpressionStatement es = (ExpressionStatement) currentStatement;
+                        int lineNumber = result.getLineNumber(es.getStartPosition());
+                        if (9 != lineNumber)
+                        	 throw new AssertionError();
+                    }
+                }
+            }
+        }
+	}
 }
\ No newline at end of file
