@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2023 IBM Corporation and others.
+ * Copyright (c) 2000, 2025 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,16 +14,16 @@
 package org.eclipse.jdt.core.tests.util;
 
 import java.io.File;
+import java.lang.annotation.Annotation;
 import java.lang.reflect.Constructor;
+import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-
 import junit.framework.Test;
 import junit.framework.TestSuite;
-
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.tests.compiler.regression.RegressionTestSetup;
@@ -34,11 +34,6 @@ import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 @SuppressWarnings({ "unchecked", "rawtypes" })
 public class AbstractCompilerTest extends TestCase {
 
-	public static final int F_1_3 = 0x01;
-	public static final int F_1_4 = 0x02;
-	public static final int F_1_5 = 0x04;
-	public static final int F_1_6 = 0x08;
-	public static final int F_1_7 = 0x10;
 	public static final int F_1_8 = 0x20;
 	public static final int F_9   = 0x40;
 	public static final int F_10  = 0x80;
@@ -53,8 +48,18 @@ public class AbstractCompilerTest extends TestCase {
 	public static final int F_19  = 0x10000;
 	public static final int F_20  = 0x20000;
 	public static final int F_21  = 0x40000;
+	public static final int F_22  = 0x80000;
+	public static final int F_23  = 0x100000;
+	public static final int F_24  = 0x200000;
+	/** Should be adopted if {@link CompilerOptions#getFirstSupportedJdkLevel()} changes */
+	public static final int FIRST_SUPPORTED_JAVA_VERSION = F_1_8;
 
+	// specifying "-Drun.javac=enabled" unconditionally enables comparison with javac for all tests:
 	public static final boolean RUN_JAVAC = CompilerOptions.ENABLED.equals(System.getProperty("run.javac"));
+	// specifying "-Drun.javac=optin" (case insensitive) enables comparison with javac for tests that set runJavacOptIn to true
+	public static final boolean RUN_JAVAC_OPT_IN = "optin".equalsIgnoreCase(System.getProperty("run.javac"));
+	protected boolean runJavacOptIn = false;
+
 	public static final boolean PERFORMANCE_ASSERTS = !CompilerOptions.DISABLED.equals(System.getProperty("jdt.performance.asserts"));
 	private static final int UNINITIALIZED = -1;
 	private static final int NONE = 0;
@@ -76,14 +81,12 @@ public class AbstractCompilerTest extends TestCase {
 	protected static boolean isJRE19Plus = false;
 	protected static boolean isJRE20Plus = false;
 	protected static boolean isJRE21Plus = false;
+	protected static boolean isJRE22Plus = false;
+	protected static boolean isJRE23Plus = false;
+	protected static boolean isJRE24Plus = false;
 	protected static boolean reflectNestedClassUseDollar;
 
 	public static int[][] complianceTestLevelMapping = new int[][] {
-		new int[] {F_1_3, ClassFileConstants.MAJOR_VERSION_1_3},
-		new int[] {F_1_4, ClassFileConstants.MAJOR_VERSION_1_4},
-		new int[] {F_1_5, ClassFileConstants.MAJOR_VERSION_1_5},
-		new int[] {F_1_6, ClassFileConstants.MAJOR_VERSION_1_6},
-		new int[] {F_1_7, ClassFileConstants.MAJOR_VERSION_1_7},
 		new int[] {F_1_8, ClassFileConstants.MAJOR_VERSION_1_8},
 		new int[] {F_9, ClassFileConstants.MAJOR_VERSION_9},
 		new int[] {F_10, ClassFileConstants.MAJOR_VERSION_10},
@@ -98,6 +101,9 @@ public class AbstractCompilerTest extends TestCase {
 		new int[] {F_19, ClassFileConstants.MAJOR_VERSION_19},
 		new int[] {F_20, ClassFileConstants.MAJOR_VERSION_20},
 		new int[] {F_21, ClassFileConstants.MAJOR_VERSION_21},
+		new int[] {F_22, ClassFileConstants.MAJOR_VERSION_22},
+		new int[] {F_23, ClassFileConstants.MAJOR_VERSION_23},
+		new int[] {F_24, ClassFileConstants.MAJOR_VERSION_24},
 	};
 
 	/**
@@ -189,12 +195,28 @@ public class AbstractCompilerTest extends TestCase {
 		}
 		if (complianceSuite == null)
 			return null;
-
+		String specVersion = System.getProperty("java.specification.version");
+		int spec = Integer.parseInt(specVersion);
+		boolean futureJREUsed = spec > Integer.parseInt(CompilerOptions.getLatestVersion());
 		// add tests
 		for (int i=0, m=testClasses.size(); i<m ; i++) {
 			Class testClass = (Class)testClasses.get(i);
+			if (futureJREUsed) {
+				Annotation annotation = testClass.getAnnotation(PreviewTest.class);
+				if (annotation != null) {
+					continue;
+				}
+			}
 			TestSuite suite = new TestSuite(testClass.getName());
-			List tests = buildTestsList(testClass);
+			int inheritedDepth = 0;
+			try {
+				Field depthField = testClass.getDeclaredField("INHERITED_DEPTH");
+				if (depthField != null)
+					inheritedDepth = depthField.getInt(null);
+			} catch (NoSuchFieldException | SecurityException | IllegalArgumentException | IllegalAccessException e) {
+				// ignore
+			}
+			List tests = buildTestsList(testClass, inheritedDepth, ORDERING);
 			for (int index=0, size=tests.size(); index<size; index++) {
 				suite.addTest((Test)tests.get(index));
 			}
@@ -224,7 +246,7 @@ public class AbstractCompilerTest extends TestCase {
 		}
 		return suite;
 	}
-	private static void checkCompliance(Class evaluationTestClass, int minimalCompliance, TestSuite suite,
+	protected static void checkCompliance(Class evaluationTestClass, int minimalCompliance, TestSuite suite,
 			int complianceLevels, int abstractCompilerTestCompliance, int classFileConstantsVersion, String release) {
 		int lev = complianceLevels & abstractCompilerTestCompliance;
 		if (lev != 0) {
@@ -255,16 +277,6 @@ public class AbstractCompilerTest extends TestCase {
 				complianceString = "9";
 			else if (highestLevel == ClassFileConstants.JDK1_8)
 				complianceString = "1.8";
-			else if (highestLevel == ClassFileConstants.JDK1_7)
-				complianceString = "1.7";
-			else if (highestLevel == ClassFileConstants.JDK1_6)
-				complianceString = "1.6";
-			else if (highestLevel == ClassFileConstants.JDK1_5)
-				complianceString = "1.5";
-			else if (highestLevel == ClassFileConstants.JDK1_4)
-				complianceString = "1.4";
-			else if (highestLevel == ClassFileConstants.JDK1_3)
-				complianceString = "1.3";
 			else {
 				highestLevel = ClassFileConstants.getLatestJDKLevel();
 				if (highestLevel > 0) {
@@ -298,7 +310,7 @@ public class AbstractCompilerTest extends TestCase {
 				return ClassFileConstants.getComplianceLevelForJavaVersion(map[1]);
 			}
 		}
-		return ClassFileConstants.JDK1_3;
+		return CompilerOptions.getFirstSupportedJdkLevel();
 	}
 
 	static void initReflectionVersion() {
@@ -336,7 +348,10 @@ public class AbstractCompilerTest extends TestCase {
 			if (spec > Integer.parseInt(CompilerOptions.getLatestVersion())) {
 				specVersion = CompilerOptions.getLatestVersion();
 			}
-			isJRE21Plus = CompilerOptions.VERSION_21.equals(specVersion);
+			isJRE24Plus = CompilerOptions.VERSION_24.equals(specVersion);
+			isJRE23Plus = isJRE24Plus || CompilerOptions.VERSION_23.equals(specVersion);
+			isJRE22Plus = isJRE23Plus || CompilerOptions.VERSION_22.equals(specVersion);
+			isJRE21Plus = isJRE22Plus || CompilerOptions.VERSION_21.equals(specVersion);
 			isJRE20Plus = isJRE21Plus || CompilerOptions.VERSION_20.equals(specVersion);
 			isJRE19Plus = isJRE20Plus || CompilerOptions.VERSION_19.equals(specVersion);
 			isJRE18Plus = isJRE19Plus || CompilerOptions.VERSION_18.equals(specVersion);
@@ -358,15 +373,9 @@ public class AbstractCompilerTest extends TestCase {
 			if (compliances != null) {
 				possibleComplianceLevels = 0;
 				for (String compliance : compliances.split(",")) {
-					if (CompilerOptions.VERSION_1_3.equals(compliance)) {
-						possibleComplianceLevels |= RUN_JAVAC ? NONE : F_1_3;
-					} else if (CompilerOptions.VERSION_1_4.equals(compliance)) {
-						possibleComplianceLevels |= RUN_JAVAC ? NONE : F_1_4;
-					}
 					boolean versionValid = false;
 					for(int i = 0; i < complianceTestLevelMapping.length; i++) {
 						int[] versionMap = complianceTestLevelMapping[i];
-						if (versionMap[0] < F_1_5) continue;
 						long jdkLevel = ClassFileConstants.getComplianceLevelForJavaVersion(versionMap[1]);
 						String versionString = CompilerOptions.versionFromJdkLevel(jdkLevel);
 						if (versionString.equals(compliance)) {
@@ -378,12 +387,6 @@ public class AbstractCompilerTest extends TestCase {
 					if (!versionValid) {
 						System.out.println("Ignoring invalid compliance (" + compliance + ")");
 						System.out.print("Use one of ");
-						System.out.print(CompilerOptions.VERSION_1_3 + ", ");
-						System.out.print(CompilerOptions.VERSION_1_4 + ", ");
-						System.out.print(CompilerOptions.VERSION_1_5 + ", ");
-						System.out.print(CompilerOptions.VERSION_1_6 + ", ");
-						System.out.print(CompilerOptions.VERSION_1_7 + ", ");
-						System.out.print(CompilerOptions.VERSION_1_8 + ", ");
 						System.out.print(CompilerOptions.VERSION_1_8 + ", ");
 						System.out.print(CompilerOptions.VERSION_9 + ", ");
 						System.out.print(CompilerOptions.VERSION_10 + ", ");
@@ -397,7 +400,10 @@ public class AbstractCompilerTest extends TestCase {
 						System.out.println(CompilerOptions.VERSION_18 + ", ");
 						System.out.println(CompilerOptions.VERSION_19 + ", ");
 						System.out.println(CompilerOptions.VERSION_20 + ", ");
-						System.out.println(CompilerOptions.VERSION_21);
+						System.out.println(CompilerOptions.VERSION_21 + ", ");
+						System.out.println(CompilerOptions.VERSION_22 + ", ");
+						System.out.println(CompilerOptions.VERSION_23 + ", ");
+						System.out.println(CompilerOptions.VERSION_24);
 					}
 				}
 				if (possibleComplianceLevels == 0) {
@@ -407,18 +413,11 @@ public class AbstractCompilerTest extends TestCase {
 			}
 			if (possibleComplianceLevels == UNINITIALIZED) {
 				if (!RUN_JAVAC) {
-					possibleComplianceLevels = F_1_3;
-					boolean canRunPrevious = !"1.0".equals(specVersion)
-						&& !CompilerOptions.VERSION_1_1.equals(specVersion)
-						&& !CompilerOptions.VERSION_1_2.equals(specVersion)
-						&& !CompilerOptions.VERSION_1_3.equals(specVersion);
-					if (canRunPrevious) {
-						possibleComplianceLevels |= F_1_4;
-					}
-					String previousVersion = CompilerOptions.VERSION_1_4;
+					possibleComplianceLevels = FIRST_SUPPORTED_JAVA_VERSION;
+					boolean canRunPrevious = true;
+					String previousVersion = CompilerOptions.getFirstSupportedJavaVersion();
 					for(int i = 0; i < complianceTestLevelMapping.length; i++) {
 						int[] versionMap = complianceTestLevelMapping[i];
-						if (versionMap[0] < F_1_5) continue;
 						long jdkLevel = ClassFileConstants.getComplianceLevelForJavaVersion(versionMap[1]);
 						String versionString = CompilerOptions.versionFromJdkLevel(jdkLevel);
 						boolean canRunNext = canRunPrevious && !previousVersion.equals(specVersion);
@@ -429,16 +428,9 @@ public class AbstractCompilerTest extends TestCase {
 						}
 						previousVersion = versionString;
 					}
-				} else if ("1.0".equals(specVersion)
-							|| CompilerOptions.VERSION_1_1.equals(specVersion)
-							|| CompilerOptions.VERSION_1_2.equals(specVersion)
-							|| CompilerOptions.VERSION_1_3.equals(specVersion)
-							|| CompilerOptions.VERSION_1_4.equals(specVersion)) {
-					possibleComplianceLevels = NONE;
 				} else {
 					for(int i = 0; i < complianceTestLevelMapping.length; i++) {
 						int[] versionMap = complianceTestLevelMapping[i];
-						if (versionMap[0] < F_1_5) continue;
 						long jdkLevel = ClassFileConstants.getComplianceLevelForJavaVersion(versionMap[1]);
 						String versionString = CompilerOptions.versionFromJdkLevel(jdkLevel);
 						if (versionString.equals(specVersion)) {
@@ -460,16 +452,6 @@ public class AbstractCompilerTest extends TestCase {
 	 */
 	public static Test suite(String suiteName, Class setupClass, ArrayList testClasses) {
 		TestSuite all = new TestSuite(suiteName);
-		int complianceLevels = AbstractCompilerTest.getPossibleComplianceLevels();
-		if ((complianceLevels & AbstractCompilerTest.F_1_3) != 0) {
-			all.addTest(suiteForComplianceLevel(ClassFileConstants.JDK1_3, setupClass, testClasses));
-		}
-		if ((complianceLevels & AbstractCompilerTest.F_1_4) != 0) {
-			all.addTest(suiteForComplianceLevel(ClassFileConstants.JDK1_4, setupClass, testClasses));
-		}
-		if ((complianceLevels & AbstractCompilerTest.F_1_5) != 0) {
-			all.addTest(suiteForComplianceLevel(ClassFileConstants.JDK1_5, setupClass, testClasses));
-		}
 		return all;
 	}
 
@@ -561,27 +543,7 @@ public class AbstractCompilerTest extends TestCase {
 	protected Map getCompilerOptions() {
 		Map options = new CompilerOptions().getMap();
 		options.put(CompilerOptions.OPTION_ReportUnusedLocal, CompilerOptions.IGNORE);
-		if (this.complianceLevel == ClassFileConstants.JDK1_3) {
-			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_3);
-			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_3);
-			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_1);
-		} else if (this.complianceLevel == ClassFileConstants.JDK1_4) {
-			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_4);
-			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_4);
-			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_4);
-		} else if (this.complianceLevel == ClassFileConstants.JDK1_5) {
-			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_5);
-			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_5);
-			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_5);
-		} else if (this.complianceLevel == ClassFileConstants.JDK1_6) {
-			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_6);
-			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_6);
-			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_6);
-		} else if (this.complianceLevel == ClassFileConstants.JDK1_7) {
-			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_7);
-			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_7);
-			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_7);
-		} else if (this.complianceLevel == ClassFileConstants.JDK1_8) {
+		if (this.complianceLevel == ClassFileConstants.JDK1_8) {
 			options.put(CompilerOptions.OPTION_Compliance, CompilerOptions.VERSION_1_8);
 			options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_8);
 			options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_1_8);
