@@ -16,9 +16,7 @@ package org.eclipse.jdt.core.tests.dom;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
-
 import junit.framework.Test;
-
 import org.eclipse.jdt.core.IAnnotation;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
@@ -26,35 +24,7 @@ import org.eclipse.jdt.core.IMethod;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.compiler.IProblem;
-import org.eclipse.jdt.core.dom.AST;
-import org.eclipse.jdt.core.dom.ASTNode;
-import org.eclipse.jdt.core.dom.ASTRequestor;
-import org.eclipse.jdt.core.dom.ASTVisitor;
-import org.eclipse.jdt.core.dom.CastExpression;
-import org.eclipse.jdt.core.dom.CatchClause;
-import org.eclipse.jdt.core.dom.ClassInstanceCreation;
-import org.eclipse.jdt.core.dom.CompilationUnit;
-import org.eclipse.jdt.core.dom.Expression;
-import org.eclipse.jdt.core.dom.ExpressionStatement;
-import org.eclipse.jdt.core.dom.FieldDeclaration;
-import org.eclipse.jdt.core.dom.IAnnotationBinding;
-import org.eclipse.jdt.core.dom.IBinding;
-import org.eclipse.jdt.core.dom.IMethodBinding;
-import org.eclipse.jdt.core.dom.ITypeBinding;
-import org.eclipse.jdt.core.dom.IVariableBinding;
-import org.eclipse.jdt.core.dom.MethodDeclaration;
-import org.eclipse.jdt.core.dom.MethodInvocation;
-import org.eclipse.jdt.core.dom.NullLiteral;
-import org.eclipse.jdt.core.dom.NumberLiteral;
-import org.eclipse.jdt.core.dom.QualifiedName;
-import org.eclipse.jdt.core.dom.SimpleName;
-import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
-import org.eclipse.jdt.core.dom.SwitchStatement;
-import org.eclipse.jdt.core.dom.TryStatement;
-import org.eclipse.jdt.core.dom.Type;
-import org.eclipse.jdt.core.dom.TypeDeclaration;
-import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
-import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
+import org.eclipse.jdt.core.dom.*;
 
 @SuppressWarnings({"rawtypes", "unchecked"})
 public class ASTConverter17Test extends ConverterTestSetup {
@@ -64,7 +34,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 	@Override
 	public void setUpSuite() throws Exception {
 		super.setUpSuite();
-		this.ast = AST.newAST(getJLS4(), false);
+		this.ast = AST.newAST(getJLSFirst(), false);
 	}
 
 	public ASTConverter17Test(String name) {
@@ -216,7 +186,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true);
+		ASTNode node = runConversion(this.workingCopy, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -280,7 +250,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", false/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, false);
+		ASTNode node = runConversion(this.workingCopy, false);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -313,7 +283,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", false/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, false);
+		ASTNode node = runConversion(this.workingCopy, false);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -346,7 +316,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", false/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, false);
+		ASTNode node = runConversion(this.workingCopy, false);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -380,7 +350,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", false/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, false);
+		ASTNode node = runConversion(this.workingCopy, false);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -408,7 +378,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"            int option= 1;\n" +
 			"            throw option == 1 ? new ExceptionA() : new ExceptionB();\n" +
 			"        } catch (/*final*/ ExceptionA | ExceptionB ex) {\n" +
-			"            System.out.println(\"type of ex: \" + ex.getClass());\n" +
+			"            // System.out.println(\"type of ex: \" + ex.getClass());\n" +
 			"            // next 2 methods on 'ex' use different parts of lub:\n" +
 			"            ex.myMethod();\n" +
 			"            throw ex;\n" +
@@ -438,7 +408,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true);
+		ASTNode node = runConversion(this.workingCopy, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -460,7 +430,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 	 * Binary literals with underscores
 	 */
 	public void test0012() throws JavaModelException {
-		AST localAst= AST.newAST(getJLS4(), false);
+		AST localAst= AST.newAST(getJLSFirst(), false);
 		NumberLiteral literal= localAst.newNumberLiteral();
 		try {
 			literal.setToken("0b1010");
@@ -486,7 +456,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 				"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true);
+		ASTNode node = runConversion(this.workingCopy, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
@@ -512,7 +482,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 				"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true, true);
+		ASTNode node = runConversion(this.workingCopy, true, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		node = getASTNode(unit, 0, 0);
@@ -571,7 +541,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 				"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true);
+		ASTNode node = runConversion(this.workingCopy, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		IProblem[] problems = unit.getProblems();
@@ -701,7 +671,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 	/*
 	 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=350897
 	 */
-	public void test0018() throws JavaModelException {
+	public void _2551_test0018() throws JavaModelException {
 		String contents =
 			"public class X<T> {\n" +
 			"	T field1;\n" +
@@ -721,7 +691,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"		X.testFunction(d.getField()); // prints 1\n" +
 			"	}\n" +
 			"	public static void testFunction(String param){\n" +
-			"		System.out.println(1 + \", String param: \" + param);\n" +
+			"		// System.out.println(1 + \", String param: \" + param);\n" +
 			"	}\n" +
 			"	public static void testFunction(Object param){\n" +
 			"		System.out.println(2);\n" +
@@ -732,12 +702,12 @@ public class ASTConverter17Test extends ConverterTestSetup {
 			"}";
 		this.workingCopy = getWorkingCopy("/Converter17/src/X.java", true/*resolve*/);
 		this.workingCopy.getBuffer().setContents(contents);
-		ASTNode node = runConversion(getJLS4(), this.workingCopy, true);
+		ASTNode node = runConversion(this.workingCopy, true);
 		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
 		CompilationUnit unit = (CompilationUnit) node;
 		assertProblemsSize(unit, 0);
 		class InferredTypeFromExpectedVisitor extends ASTVisitor {
-			StringBuffer buf = new StringBuffer();
+			StringBuilder buf = new StringBuilder();
 			public boolean visit(ClassInstanceCreation creation) {
 				this.buf.append(creation.isResolvedTypeInferredFromExpectedType());
 				return false;
@@ -799,150 +769,10 @@ public class ASTConverter17Test extends ConverterTestSetup {
 		IMethodBinding[] methods = binding.getDeclaredMethods();
 		assertEquals("Wrong size", 2, methods.length);
 	}
-	/**
-     * https://bugs.eclipse.org/bugs/show_bug.cgi?id=402673
-     */
-    public void test402673a() throws JavaModelException {
-            String contents = "package test402673;"
-                    + "public class X {\n"
-                    + "    Runnable r = () -> System.out.println(\"hi\");\n"
-                    +"}\n";
-        	this.workingCopy = getWorkingCopy("/Converter/src/test402673/X.java", true/* resolve */);
-        	this.workingCopy.getBuffer().setContents(contents);
-        	ASTNode node = runConversion(this.workingCopy, true);
-        	assertTrue(node != null);
-    		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
-    		CompilationUnit unit = (CompilationUnit) node;
-    		assertProblemsSize(unit, 1, "Lambda expressions are allowed only at source level 1.8 or above");
-    		TypeDeclaration type = (TypeDeclaration) getASTNode(unit, 0);
-    		assertTrue((type.getFlags() & ASTNode.MALFORMED) != 0);
-    		node = getASTNode(unit, 0, 0);
-    		assertEquals("Not a field declaration", ASTNode.FIELD_DECLARATION, node.getNodeType());
-    		FieldDeclaration fieldDeclaration = (FieldDeclaration) node;
-    		final List fragments = fieldDeclaration.fragments();
-    		assertEquals("Wrong size", 1, fragments.size());
-    		VariableDeclarationFragment fragment = (VariableDeclarationFragment) fragments.get(0);
-    		final Expression initializer = fragment.getInitializer();
-    		assertEquals("Not a null literal", ASTNode.NULL_LITERAL, initializer.getNodeType());
-    		NullLiteral nullLiteral = (NullLiteral) initializer;
-    		assertTrue((nullLiteral.getFlags() & ASTNode.MALFORMED) != 0);
-    }
-    /**
-     * https://bugs.eclipse.org/bugs/show_bug.cgi?id=402673
-     */
-    public void test402673b() throws JavaModelException {
-            String contents = "package test402673;"
-                    + "public class X {\n"
-            		+ "    public void foo() {\n"
-                    + "        Runnable r = () -> System.out.println(\"hi\");\n"
-                    +"    }\n"
-                    +"}\n";
-        	this.workingCopy = getWorkingCopy("/Converter/src/test402673/X.java", true/* resolve */);
-        	this.workingCopy.getBuffer().setContents(contents);
-        	ASTNode node = runConversion(this.workingCopy, true);
-        	assertTrue(node != null);
-    		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
-    		CompilationUnit unit = (CompilationUnit) node;
-    		assertProblemsSize(unit, 1, "Lambda expressions are allowed only at source level 1.8 or above");
-    		node = getASTNode(unit, 0, 0);
-    		assertEquals("Not a method declaration", ASTNode.METHOD_DECLARATION, node.getNodeType());
-    		MethodDeclaration methodDecl = (MethodDeclaration) node;
-    		assertTrue((methodDecl.getFlags() & ASTNode.MALFORMED) == 1);
-    		node = getASTNode(unit, 0, 0, 0);
-    		assertEquals("Not a variable declaration statement", ASTNode.VARIABLE_DECLARATION_STATEMENT, node.getNodeType());
-    		VariableDeclarationStatement variableDecl = (VariableDeclarationStatement) node;
-    		final List fragments = variableDecl.fragments();
-    		assertEquals("Wrong size", 1, fragments.size());
-    		VariableDeclarationFragment fragment = (VariableDeclarationFragment) fragments.get(0);
-    		final Expression initializer = fragment.getInitializer();
-    		assertEquals("Not a null literal", ASTNode.NULL_LITERAL, initializer.getNodeType());
-    		NullLiteral nullLiteral = (NullLiteral) initializer;
-    		assertTrue((nullLiteral.getFlags() & ASTNode.MALFORMED) != 0);
-    }
-	/**
-	 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=402674
-	 */
-	public void test403444() throws JavaModelException {
-		this.workingCopy = getWorkingCopy("/Converter18/src/test403444/X.java",
-				true/* resolve */);
-		String contents = "package test403444;" +
-				"public class X {\n" +
-				"  public static interface StringToInt {\n" +
-				"   	int stoi(String s);\n" +
-				"  }\n" +
-				"  public static interface ReduceInt {\n" +
-				"      int reduce(int a, int b);\n" +
-				"  }\n" +
-				"  void foo(StringToInt s) { }\n" +
-				"  void bar(ReduceInt r) { }\n" +
-				"  void bar() {\n" +
-				"      foo(s -> s.length());\n" +
-				"      foo((s) -> s.length());\n" +
-				"      foo((String s) -> s.length()); //SingleVariableDeclaration is OK\n" +
-				"      bar((x, y) -> x+y);\n" +
-				"      bar((int x, int y) -> x+y); //SingleVariableDeclarations are OK\n" +
-				"  }\n" +
-				"}\n";
-
-
-    	this.workingCopy = getWorkingCopy("/Converter/src/test403444/X.java", true/* resolve */);
-    	this.workingCopy.getBuffer().setContents(contents);
-    	ASTNode node = runConversion(this.workingCopy, true);
-    	assertTrue(node != null);
-		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
-		CompilationUnit unit = (CompilationUnit) node;
-
-		String error = "Lambda expressions are allowed only at source level 1.8 or above\n" +
-				"Lambda expressions are allowed only at source level 1.8 or above\n" +
-				"Lambda expressions are allowed only at source level 1.8 or above\n" +
-				"Lambda expressions are allowed only at source level 1.8 or above\n" +
-				"Lambda expressions are allowed only at source level 1.8 or above";
-		assertProblemsSize(unit, 5, error);
-
-		TypeDeclaration typedeclaration = (TypeDeclaration) getASTNode(unit, 0);
-		MethodDeclaration methoddecl = (MethodDeclaration)typedeclaration.bodyDeclarations().get(4);
-		List statements = methoddecl.getBody().statements();
-		int sCount = 0;
-
-		ExpressionStatement statement = (ExpressionStatement)statements.get(sCount++);
-		MethodInvocation methodInvocation = (MethodInvocation)statement.getExpression();
-		Expression expression = (Expression) methodInvocation.arguments().get(0);
-		assertTrue(expression instanceof NullLiteral);
-		ITypeBinding binding = expression.resolveTypeBinding();
-		assertNull(binding);
-
-		statement = (ExpressionStatement)statements.get(sCount++);
-		methodInvocation = (MethodInvocation)statement.getExpression();
-		expression = (Expression) methodInvocation.arguments().get(0);
-		assertTrue(expression instanceof NullLiteral);
-		binding = expression.resolveTypeBinding();
-		assertNull(binding);
-
-		statement = (ExpressionStatement)statements.get(sCount++);
-		methodInvocation = (MethodInvocation)statement.getExpression();
-		expression = (Expression) methodInvocation.arguments().get(0);
-		assertTrue(expression instanceof NullLiteral);
-		binding = expression.resolveTypeBinding();
-		assertNull(binding);
-
-		statement = (ExpressionStatement)statements.get(sCount++);
-		methodInvocation = (MethodInvocation)statement.getExpression();
-		expression = (Expression) methodInvocation.arguments().get(0);
-		assertTrue(expression instanceof NullLiteral);
-		binding = expression.resolveTypeBinding();
-		assertNull(binding);
-
-		statement = (ExpressionStatement)statements.get(sCount++);
-		methodInvocation = (MethodInvocation)statement.getExpression();
-		expression = (Expression) methodInvocation.arguments().get(0);
-		assertTrue(expression instanceof NullLiteral);
-		binding = expression.resolveTypeBinding();
-		assertNull(binding);
-	}
 	/*
 	 * https://bugs.eclipse.org/bugs/show_bug.cgi?id=399791
 	 */
-	public void test0021() throws JavaModelException {
+	public void _2551_test0021() throws JavaModelException {
 		String contents =
 				"public interface X {\n" +
 				"	static void foo(){}\n" +
@@ -966,7 +796,7 @@ public class ASTConverter17Test extends ConverterTestSetup {
 	 *
 	 * @deprecated as it uses deprecated methods
 	 */
-	public void test0022() throws JavaModelException {
+	public void _2551_test0022() throws JavaModelException {
 		String contents =
 				"public class X {\n" +
 				"	void foo() throws  @NonNull EOFException, java.io.@NonNull FileNotFoundException {}\n" +
