@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2020, 2023 IBM Corporation and others.
+ * Copyright (c) 2020, 2024 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,40 +13,13 @@
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.dom;
 
-import static org.junit.Assert.assertNotEquals;
-
 import java.util.ArrayList;
 import java.util.List;
-
+import junit.framework.Test;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.dom.AST;
-import org.eclipse.jdt.core.dom.ASTNode;
-import org.eclipse.jdt.core.dom.ASTVisitor;
-import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
-import org.eclipse.jdt.core.dom.CompilationUnit;
-import org.eclipse.jdt.core.dom.Expression;
-import org.eclipse.jdt.core.dom.GuardedPattern;
-import org.eclipse.jdt.core.dom.IfStatement;
-import org.eclipse.jdt.core.dom.MethodDeclaration;
-import org.eclipse.jdt.core.dom.ParenthesizedExpression;
-import org.eclipse.jdt.core.dom.Pattern;
-import org.eclipse.jdt.core.dom.PatternInstanceofExpression;
-import org.eclipse.jdt.core.dom.RecordPattern;
-import org.eclipse.jdt.core.dom.SimpleName;
-import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
-import org.eclipse.jdt.core.dom.Statement;
-import org.eclipse.jdt.core.dom.SwitchCase;
-import org.eclipse.jdt.core.dom.SwitchExpression;
-import org.eclipse.jdt.core.dom.SwitchStatement;
-import org.eclipse.jdt.core.dom.Type;
-import org.eclipse.jdt.core.dom.TypeDeclaration;
-import org.eclipse.jdt.core.dom.TypePattern;
-import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
-import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
-
-import junit.framework.Test;
+import org.eclipse.jdt.core.dom.*;
 
 public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 
@@ -56,7 +29,7 @@ public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 		super.setUpSuite();
 		this.ast = AST.newAST(getASTLatest(), false);
 		this.currentProject = getJavaProject("Converter_19");
-		if (this.ast.apiLevel() == AST.JLS21) {
+		if (this.ast.apiLevel() >= AST.JLS21) {
 			this.currentProject.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_21);
 			this.currentProject.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_21);
 			this.currentProject.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_21);
@@ -137,16 +110,12 @@ public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 		assertEquals("Type Pattern", typePattern.getNodeType(), ASTNode.TYPE_PATTERN);
 		SingleVariableDeclaration patternVariable = ((TypePattern)typePattern).getPatternVariable();
 		assertEquals("Type Pattern Integer", "Integer", patternVariable.getType().toString());
-		SingleVariableDeclaration patternVariable2 = ((TypePattern)typePattern).patternVariables().get(0);
-		assertEquals(patternVariable, patternVariable2);
 
 		SwitchCase caseString = (SwitchCase) statements.get(2);
 		typePattern = (Expression)caseString.expressions().get(0);
 		assertEquals("Type Pattern", typePattern.getNodeType(), ASTNode.TYPE_PATTERN);
 		patternVariable = ((TypePattern)typePattern).getPatternVariable();
 		assertEquals("Type Pattern Integer", "String", patternVariable.getType().toString());
-		patternVariable2 = ((TypePattern)typePattern).patternVariables().get(0);
-		assertEquals(patternVariable, patternVariable2);
 
 		SwitchCase caseDefault = (SwitchCase) statements.get(4);
 		assertTrue("Default case", caseDefault.isDefault());
@@ -186,8 +155,6 @@ public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 		Pattern pattern = ((GuardedPattern)guardedPattern).getPattern();
 		SingleVariableDeclaration patternVariable = ((TypePattern)pattern).getPatternVariable();
 		assertEquals("Type Pattern Integer", "Integer", patternVariable.getType().toString());
-		SingleVariableDeclaration patternVariable2 = ((TypePattern)pattern).patternVariables().get(0);
-		assertEquals(patternVariable, patternVariable2);
 		Expression expression = ((GuardedPattern)guardedPattern).getExpression();
 		Expression expression2 = ((ParenthesizedExpression)expression).getExpression();
 		assertEquals("Infix expression", "i.intValue() > 10", expression2.toString());
@@ -199,8 +166,6 @@ public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 		pattern = ((GuardedPattern)guardedPattern).getPattern();
 		patternVariable = ((TypePattern)pattern).getPatternVariable();
 		assertEquals("Type Pattern String", "String", patternVariable.getType().toString());
-		patternVariable2 = ((TypePattern)pattern).patternVariables().get(0);
-		assertEquals(patternVariable, patternVariable2);
 		expression = ((GuardedPattern)guardedPattern).getExpression();
 		assertEquals("Infix expression", "s.equals(\"ff\")",expression.toString());
 
@@ -571,38 +536,30 @@ public class ASTConverter_RecordPattern_Test extends ConverterTestSetup {
 		GuardedPattern guardedPattern = (GuardedPattern)caseStmt.expressions().get(0);
 		assertEquals("There should be 1 Record Pattern", ASTNode.RECORD_PATTERN , guardedPattern.getPattern().getNodeType());
 	}
-	public void testIssue882_1() throws Exception {
-		if (!isJRE21) {
-			System.err.println("Test "+getName()+" requires a JRE 21");
-			return;
-		}
-		String contents =  "import java.util.List;\n"
-				+ "public class X {\n"
-				+ "	public static void foo(List<R> rList) {\n"
-				+ "		for(R(Integer abcs):rList) {\n"
-				+ "			System.out.println(abcs);\n"
-				+ "		}\n"
-				+ "	}\n"
-				+ "	record R(int i) {}\n"
-				+ "}";
+	public void testVisitPattern() {
+        class NodeFinder extends ASTVisitor {
+            PatternInstanceofExpression patternInstanceofExpression;
+            public boolean visit(PatternInstanceofExpression node) {
+                this.patternInstanceofExpression = node;
+                return super.visit(node);
+            }
+        }
+        String content = """
+        		public class Foo {
+        			static boolean checkCollisionIfs(Object p1, Object p2) {
+        				if (p1 instanceof Point(int x1, int y1)) {
+        					return x1 == x2 && y1 == y2;
+        				}
+        			}
+        			record Point(int x, int y) {}
+        			record ColoredPoint(Point T, String color) {}
+        			record Decorator(Object obj) {}}""";
 
-		this.workingCopy = getWorkingCopy("/Converter_19/src/X.java", true/*resolve*/);
-		ASTNode node = buildAST(
-				contents,
-				this.workingCopy,
-				false);
-		assertEquals("Not a compilation unit", ASTNode.COMPILATION_UNIT, node.getNodeType());
-		CompilationUnit compilationUnit = (CompilationUnit) node;
-		node = ((AbstractTypeDeclaration)compilationUnit.types().get(0));
-		assertEquals("Not a Type Declaration", ASTNode.TYPE_DECLARATION, node.getNodeType());
-		TypeDeclaration type = (TypeDeclaration)node;
-		MethodDeclaration[] methods = type.getMethods();
-		assertEquals("Method size incorrect", 1, methods.length);
-		MethodDeclaration printMethod = methods[0];
-		assertEquals("Method name is not foo", "foo", printMethod.getName().toString());
-		List<ASTNode> statements = printMethod.getBody().statements();
-		assertEquals("statement count incorrect", 1, statements.size());
-		Statement stmt = (Statement) statements.get(0);
-		assertNotEquals("Should not be an empty statement", ASTNode.EMPTY_STATEMENT, stmt.getNodeType());
+        ASTParser parser = ASTParser.newParser(AST.JLS21);
+        parser.setSource(content.toCharArray());
+        CompilationUnit cunit = (CompilationUnit) parser.createAST(null);
+        NodeFinder astVisitor = new NodeFinder();
+        cunit.accept(astVisitor);
+        assertEquals("Wrong node", "p1 instanceof Point(int x1, int y1)", astVisitor.patternInstanceofExpression.toString());
 	}
 }
