@@ -15,29 +15,8 @@ package org.eclipse.jdt.core.tests.dom;
 
 import java.util.HashMap;
 import java.util.Map;
-
 import org.eclipse.jdt.core.compiler.IProblem;
-import org.eclipse.jdt.core.dom.ASTNode;
-import org.eclipse.jdt.core.dom.AnonymousClassDeclaration;
-import org.eclipse.jdt.core.dom.ArrayType;
-import org.eclipse.jdt.core.dom.Assignment;
-import org.eclipse.jdt.core.dom.CompilationUnit;
-import org.eclipse.jdt.core.dom.IBinding;
-import org.eclipse.jdt.core.dom.MarkerAnnotation;
-import org.eclipse.jdt.core.dom.MethodDeclaration;
-import org.eclipse.jdt.core.dom.MethodInvocation;
-import org.eclipse.jdt.core.dom.NormalAnnotation;
-import org.eclipse.jdt.core.dom.PackageDeclaration;
-import org.eclipse.jdt.core.dom.ParameterizedType;
-import org.eclipse.jdt.core.dom.QualifiedName;
-import org.eclipse.jdt.core.dom.SimpleName;
-import org.eclipse.jdt.core.dom.SimpleType;
-import org.eclipse.jdt.core.dom.SingleMemberAnnotation;
-import org.eclipse.jdt.core.dom.TypeDeclaration;
-import org.eclipse.jdt.core.dom.TypeDeclarationStatement;
-import org.eclipse.jdt.core.dom.TypeParameter;
-import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
-import org.eclipse.jdt.core.dom.WildcardType;
+import org.eclipse.jdt.core.dom.*;
 import org.eclipse.jdt.core.tests.util.Util;
 import org.eclipse.jdt.internal.core.dom.NaiveASTFlattener;
 
@@ -55,7 +34,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			this.options = options;
 		}
 
-		private void appendBinding(ASTNode node, StringBuffer buffer) {
+		private void appendBinding(ASTNode node, StringBuilder buffer) {
 			buffer.append('[');
 			try {
 				IBinding binding = resolveBinding(node);
@@ -89,7 +68,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			buffer.append(']');
 		}
 
-		private void appendBindingFlags(IBinding binding, StringBuffer buffer) {
+		private void appendBindingFlags(IBinding binding, StringBuilder buffer) {
 			boolean firstFlag = true;
 			if (binding.isDeprecated()) {
 				if (!firstFlag) buffer.append('|');
@@ -111,11 +90,11 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			}
 		}
 
-		private void appendBindingKey(IBinding binding, StringBuffer buffer) {
+		private void appendBindingKey(IBinding binding, StringBuilder buffer) {
 			buffer.append(binding.getKey());
 		}
 
-		private void appendBindingKind(IBinding binding, StringBuffer buffer) {
+		private void appendBindingKind(IBinding binding, StringBuilder buffer) {
 			switch (binding.getKind()) {
 				case IBinding.ANNOTATION:
 					buffer.append("ANNOTATION");break;
@@ -134,7 +113,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			}
 		}
 
-		private void appendFlags(ASTNode node, StringBuffer buffer) {
+		private void appendFlags(ASTNode node, StringBuilder buffer) {
 			boolean firstFlag = true;
 			int flags = node.getFlags();
 			if ((flags & ASTNode.MALFORMED) != 0) {
@@ -165,7 +144,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			}
 		}
 
-		private void appendNodeExtendedPosition(ASTNode node, StringBuffer buffer) {
+		private void appendNodeExtendedPosition(ASTNode node, StringBuilder buffer) {
 			ASTNode root = node.getRoot();
 
 			if (root.getNodeType() == ASTNode.COMPILATION_UNIT) {
@@ -188,7 +167,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 
 		}
 
-		private void appendNodePosition(ASTNode node, StringBuffer buffer) {
+		private void appendNodePosition(ASTNode node, StringBuilder buffer) {
 			buffer.append('[');
 			buffer.append(node.getStartPosition());
 			buffer.append(',');
@@ -196,7 +175,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			buffer.append(']');
 		}
 
-		private void appendNodeType(ASTNode node, StringBuffer buffer) {
+		private void appendNodeType(ASTNode node, StringBuilder buffer) {
 			switch (node.getNodeType()) {
 				case ASTNode.ANNOTATION_TYPE_DECLARATION :
 					buffer.append("ANNOTATION_TYPE_DECLARATION");break;
@@ -383,7 +362,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 
 		@Override
 		public String getText(ASTNode node) {
-			StringBuffer buffer = new StringBuffer();
+			StringBuilder buffer = new StringBuilder();
 
 			boolean first = true;
 
@@ -495,7 +474,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 	private Map markerPositonInBuffer;
 
 	private boolean[] foundNodeFromMarker;
-	private final StringBuffer markedNodesBuffer;
+	private final StringBuilder markedNodesBuffer;
 
 	private final MarkedNodeLabelProvider labelProvider;
 
@@ -507,12 +486,12 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 		this.reportAST = reportAST;
 		this.reportProblems = reportProblems;
 
-		this.markedNodesBuffer = new StringBuffer();
+		this.markedNodesBuffer = new StringBuilder();
 		this.labelProvider = labelProvider;
 	}
 
 	public String getResult() {
-		StringBuffer resultBuffer = new StringBuffer();
+		StringBuilder resultBuffer = new StringBuilder();
 
 		if (this.reportAST) {
 			resultBuffer.append(AST_DELIMITER);
@@ -529,7 +508,7 @@ public class MarkedASTFlattener extends NaiveASTFlattener {
 			resultBuffer.append(PROBLEMS_DELIMITER);
 			resultBuffer.append('\n');
 
-			StringBuffer problemBuffer = new StringBuffer();
+			StringBuilder problemBuffer = new StringBuilder();
 			IProblem[] problems = this.unit.getProblems();
 			int problemCount = problems.length;
 			if (problemCount != 0) {
