@@ -17,14 +17,13 @@ import java.io.File;
 import java.io.IOException;
 import java.util.HashSet;
 import java.util.Set;
-
 import junit.framework.Test;
-
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.tests.util.Util;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.parser.JavadocTagConstants;
 
 @SuppressWarnings({"rawtypes", "unchecked"})
@@ -35,20 +34,30 @@ public abstract class AbstractJavadocCompletionModelTest extends AbstractJavaMod
 	protected final static int JAVADOC_RELEVANCE = R_DEFAULT+ R_INTERESTING+ R_NON_RESTRICTED;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING<br>+R_UNQUALIFIED+R_NON_RESTRICTED<br>= 9 */
 	protected final static int R_DRINR= R_DEFAULT+R_RESOLVED+R_INTERESTING+R_NON_RESTRICTED;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY<br>= 11 */
+	protected final static int R_DRINRJ= R_DEFAULT+R_RESOLVED+R_INTERESTING+R_NON_RESTRICTED+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING<br>+R_UNQUALIFIED+R_NON_RESTRICTED<br>= 12 */
 	protected final static int R_DRIUNR= R_DEFAULT+R_RESOLVED+R_INTERESTING+R_UNQUALIFIED+R_NON_RESTRICTED;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY<br>= 14 */
+	protected final static int R_DRIUNRJ= R_DEFAULT+R_RESOLVED+R_INTERESTING+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED<br>= 19 */
 	protected static final int R_DRICNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_NON_RESTRICTED;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_JAVA_LIBRARY<br>= 21 */
+	protected static final int R_DRICNRJ = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_NON_RESTRICTED+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_QUALIFIED+R_NON_RESTRICTED<br>= 21 */
 	protected static final int R_DRICQNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_QUALIFIED+R_NON_RESTRICTED;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_UNQUALIFIED+R_NON_RESTRICTED<br>= 22 */
 	protected static final int R_DRICUNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_UNQUALIFIED+R_NON_RESTRICTED;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED<br>= 23 */
 	protected static final int R_DRICENNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_EXACT_NAME+R_NON_RESTRICTED;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY<br>= 24 */
+	protected static final int R_DRICUNRJ = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_QUALIFIED+R_NON_RESTRICTED<br>= 25 */
 	protected static final int R_DRICENQNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_EXACT_NAME+R_QUALIFIED+R_NON_RESTRICTED;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_UNQUALIFIED+R_NON_RESTRICTED<br>= 26 */
 	protected static final int R_DRICENUNR = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_EXACT_NAME+R_UNQUALIFIED+R_NON_RESTRICTED;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY<br>= 28 */
+	protected static final int R_DRICENUNRJ = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_EXACT_NAME+R_UNQUALIFIED+R_NON_RESTRICTED+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_NON_STATIC<br>= 30 */
 	protected static final int R_DRICNRNS = R_DEFAULT+R_RESOLVED+R_INTERESTING+R_CASE+R_NON_RESTRICTED+R_NON_STATIC;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED+R_NON_STATIC<br>= 34 */
@@ -57,30 +66,44 @@ public abstract class AbstractJavadocCompletionModelTest extends AbstractJavaMod
 	// Exception relevance values
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_EXCEPTION<br>= 39 */
 	protected static final int R_DRICNRE = R_DRICNR+R_EXCEPTION;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_EXCEPTION+R_JAVA_LIBRARY<br>= 41 */
+	protected static final int R_DRICNREJ = R_DRICNR+R_EXCEPTION+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_EXCEPTION<br>= 42 */
 	protected static final int R_DRICUNRE = R_DRICUNR+R_EXCEPTION;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED+R_EXCEPTION<br>= 43 */
 	protected static final int R_DRICENNRE = R_DRICENNR+R_EXCEPTION;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED+R_EXCEPTION+R_JAVA_LIBRARY<br>= 45 */
+	protected static final int R_DRICUNREJ = R_DRICUNR+R_EXCEPTION+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_EXCEPTION<br>= 46 */
 	protected static final int R_DRICENUNRE = R_DRICENUNR+R_EXCEPTION;
 
 	// Exact Expected relevance values
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE<br>= 49 */
 	protected static final int R_DRICNREET = R_DRICNR+R_EXACT_EXPECTED_TYPE;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY<br>= 51 */
+	protected static final int R_DRICNREETJ = R_DRICNR+R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE<br>= 52 */
 	protected static final int R_DRICUNREET = R_DRICUNR+R_EXACT_EXPECTED_TYPE;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE+R_EXCEPTION<br>= 72 */
 	protected static final int R_DRICUNREETE = R_DRICUNR+R_EXACT_EXPECTED_TYPE+R_EXCEPTION;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE+R_EXCEPTION
+	 * +R_JAVA_LIBRARY<br>= 74 */
+	protected static final int R_DRICUNREETEJ = R_DRICUNR+R_EXACT_EXPECTED_TYPE+R_EXCEPTION+R_JAVA_LIBRARY;
 
 	// Exact Expected Exception relevance values
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_NON_RESTRICTED<br>+R_EXCEPTION+R_EXACT_EXPECTED_TYPE<br>= 69 */
 	protected static final int R_DRICNREEET = R_DRICNRE+R_EXACT_EXPECTED_TYPE;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_NON_RESTRICTED<br>+R_EXCEPTION+R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY<br>= 71 */
+	protected static final int R_DRICNREEETJ = R_DRICNRE+R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXCEPTION<br>
 	 * +R_EXACT_EXPECTED_TYPE<br>= 72 */
 	protected static final int R_DRICUNREEET = R_DRICUNRE+R_EXACT_EXPECTED_TYPE;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED+R_EXCEPTION<br>
 	 * +R_EXACT_EXPECTED_TYPE<br>= 73 */
 	protected static final int R_DRICENNREEET = R_DRICENNRE+R_EXACT_EXPECTED_TYPE;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXCEPTION<br>
+	 * +R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY<br>= 74 */
+	protected static final int R_DRICUNREEETJ = R_DRICUNRE+R_EXACT_EXPECTED_TYPE+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_EXCEPTION<br>
 	 * +R_EXACT_EXPECTED_TYPE<br>= 76 */
 	protected static final int R_DRICENUNREEET = R_DRICENUNRE+R_EXACT_EXPECTED_TYPE;
@@ -88,20 +111,27 @@ public abstract class AbstractJavadocCompletionModelTest extends AbstractJavaMod
 	// Inline tag relevance values
 	/** R_DEFAULT+R_INTERESTING+R_NON_RESTRICTED<br>+R_INLINE_TAG<br>= 39 */
 	protected static final int JAVADOC_RELEVANCE_IT = JAVADOC_RELEVANCE+R_INLINE_TAG;
-	/** R_DEFAULT+R_RESOLVED<br+R_INTERESTING+R_NON_RESTRICTED<br>+R_INLINE_TAG<br>= 40 */
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_NON_RESTRICTED<br>+R_INLINE_TAG<br>= 40 */
 	protected static final int R_DRINRIT = R_DRINR+R_INLINE_TAG;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_INLINE_TAG<br>= 50 */
 	protected static final int R_DRICNRIT = R_DRICNR+R_INLINE_TAG;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_INLINE_TAG+R_JAVA_LIBRARY<br>= 52 */
+	protected static final int R_DRICNRITJ = R_DRICNR+R_INLINE_TAG+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_INLINE_TAG<br>= 53 */
 	protected static final int R_DRICUNRIT = R_DRICUNR+R_INLINE_TAG;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_NON_RESTRICTED+R_INLINE_TAG<br>= 54 */
 	protected static final int R_DRICENNRIT = R_DRICENNR+R_INLINE_TAG;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_INLINE_TAG+R_JAVA_LIBRARY<br>= 55 */
+	protected static final int R_DRICUNRITJ = R_DRICUNR+R_INLINE_TAG+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_EXACT_NAME<br>+R_UNQUALIFIED+R_NON_RESTRICTED+R_INLINE_TAG<br>= 57 */
 	protected static final int R_DRICENUNRIT = R_DRICENUNR+R_INLINE_TAG;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE<br>+R_NON_RESTRICTED+R_NON_STATIC+R_INLINE_TAG<br>= 61 */
 	protected static final int R_DRICNRNSIT = R_DRICNRNS+R_INLINE_TAG;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_NON_RESTRICTED<br>+R_EXACT_EXPECTED_TYPE+R_INLINE_TAG<br>= 80 */
 	protected static final int R_DRICNREETIT = R_DRICNREET+R_INLINE_TAG;
+	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_NON_RESTRICTED<br>+R_EXACT_EXPECTED_TYPE+R_INLINE_TAG
+	 * +R_JAVA_LIBRARY<br>= 82 */
+	protected static final int R_DRICNREETITJ = R_DRICNREET+R_INLINE_TAG+R_JAVA_LIBRARY;
 	/** R_DEFAULT+R_RESOLVED<br>+R_INTERESTING+R_CASE+R_UNQUALIFIED<br>+R_NON_RESTRICTED+R_EXACT_EXPECTED_TYPE<br>
 	 * +R_INLINE_TAG<br>= 83 */
 	protected static final int R_DRICUNREETIT = R_DRICUNREET+R_INLINE_TAG;
@@ -427,7 +457,7 @@ public abstract class AbstractJavadocCompletionModelTest extends AbstractJavaMod
 			COMPLETION_PROJECT = setUpJavaProject("Completion");
 			createFolder(new Path("/Completion/src/javadoc/tags"));
 		} else {
-			setUpProjectCompliance(COMPLETION_PROJECT, "1.4");
+			setUpProjectCompliance(COMPLETION_PROJECT, CompilerOptions.getFirstSupportedJavaVersion());
 			this.currentProject = COMPLETION_PROJECT;
 		}
 	}
@@ -445,9 +475,6 @@ public abstract class AbstractJavadocCompletionModelTest extends AbstractJavaMod
 	public void tearDownSuite() throws Exception {
 		deleteFolder(new Path("/Completion/src/javadoc/tags"));
 		super.tearDownSuite();
-		if (COMPLETION_SUITES == null) {
-			COMPLETION_PROJECT = null;
-		}
 	}
 
 	/*
