@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2025 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,9 +19,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.net.URI;
 import java.util.Hashtable;
-
 import junit.framework.Test;
-
 import org.eclipse.core.filesystem.URIUtil;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IFolder;
@@ -36,24 +34,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
-import org.eclipse.jdt.core.IBuffer;
-import org.eclipse.jdt.core.IClassFile;
-import org.eclipse.jdt.core.IClasspathEntry;
-import org.eclipse.jdt.core.ICompilationUnit;
-import org.eclipse.jdt.core.IJavaElement;
-import org.eclipse.jdt.core.IJavaProject;
-import org.eclipse.jdt.core.IMember;
-import org.eclipse.jdt.core.IMethod;
-import org.eclipse.jdt.core.IModularClassFile;
-import org.eclipse.jdt.core.IModuleDescription;
-import org.eclipse.jdt.core.IOrdinaryClassFile;
-import org.eclipse.jdt.core.IPackageFragment;
-import org.eclipse.jdt.core.IPackageFragmentRoot;
-import org.eclipse.jdt.core.ISourceRange;
-import org.eclipse.jdt.core.IType;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.JavaModelException;
-import org.eclipse.jdt.core.SourceRange;
+import org.eclipse.jdt.core.*;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTParser;
@@ -136,10 +117,10 @@ private void setupExternalLibrary() throws IOException {
 			"public class X {\n" +
 			"}"
 		};
-	org.eclipse.jdt.core.tests.util.Util.createClassFolder(pathsAndContents, externalFolder + "/lib", "1.4");
+	org.eclipse.jdt.core.tests.util.Util.createClassFolder(pathsAndContents, externalFolder + "/lib", CompilerOptions.getFirstSupportedJavaVersion());
 	org.eclipse.jdt.core.tests.util.Util.createSourceDir(pathsAndContents, externalFolder + "/src");
 
-	org.eclipse.jdt.core.tests.util.Util.createJar(pathsAndContents, externalFolder + "/lib.abc", "1.4");
+	org.eclipse.jdt.core.tests.util.Util.createJar(pathsAndContents, externalFolder + "/lib.abc", CompilerOptions.getFirstSupportedJavaVersion());
 	org.eclipse.jdt.core.tests.util.Util.createSourceZip(pathsAndContents, externalFolder + "/src.abc");
 }
 private void setUpGenericJar() throws IOException, CoreException {
@@ -182,48 +163,96 @@ private void setUpGenericJar() throws IOException, CoreException {
 		"	}\n" +
 		"}"
 	};
-	addLibrary("generic.jar", "genericsrc.zip", pathAndContents, JavaCore.VERSION_1_5);
+	addLibrary("generic.jar", "genericsrc.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 }
 private void setUpInnerClassesJar() throws IOException, CoreException {
 	String[] pathAndContents = new String[] {
 		"inner/X.java",
-		"package inner;\n" +
-		"public class X {\n" +
-		"  void foo() {\n" +
-		"    new X() {};\n" +
-		"    class Y {}\n" +
-		"    new Y() {\n" +
-		"      class Z {}\n" +
-		"    };\n" +
-		"    class W {\n" +
-		"      void bar() {\n" +
-		"        new W() {};\n" +
-		"      }\n" +
-		"    }\n" +
-		"    new Object() {\n" +
-		"      class U {\n" +
-		"        U(String s) {\n" +
-		"        }\n" +
-		"      }\n" +
-		"    };\n" +
-		"  }\n" +
-		"  class V {\n" +
-		"    V(String s) {\n" +
-		"    }\n" +
-		"  }\n" +
-		"  class Inner {\n" +
-		"    Inner() {\n" +
-		"    }\n" +
-		"    class WW {\n" +
-		"      WW() {}\n" +
-		"      class WWW {\n" +
-		"        WWW() {}\n" +
-		"      }\n" +
-		"    }\n" +
-		"  }\n" +
-		"}"
-	};
-	addLibrary("innerClasses.jar", "innerClassessrc.zip", pathAndContents, JavaCore.VERSION_1_4);
+		"""
+	    package inner;
+	    public class X {
+	      void foo() {
+	        new X() {};
+	        class Y {}
+	        new Y() {
+	          class Z {}
+	        };
+	        class W {
+	          {
+	            class Y { // One
+	            }
+	          }
+	          void bar() {
+	            new W() {};
+	            {
+	              class Y { // Two
+	              }
+	            }
+	            {
+	              class Y { // Three
+	              }
+	            }
+	          }
+	        }
+	        new Object() {
+	          class U {
+	            U(String s) {
+	            }
+	          }
+	        };
+	      }
+	      class V {
+	        V(String s) {
+	        }
+	      }
+	      class Inner {
+	        Inner() {
+	        }
+	        class WW {
+	          WW() {}
+	          class WWW {
+	            WWW() {}
+	          }
+	        }
+	      }
+	      void foo1() {
+	        class W1 {
+	          void bar() {
+	            new W1() {
+	              class W2 {
+	                void foobar() {
+	                  new W2() {
+	                    void foobar2() {
+	                      class W3 {
+	                        void foobar3() {
+	                          new W3() {
+	                            void foobar4() {
+	                              class W4 {
+	                                void foobar5() {
+	                                  new W4();
+	                                }
+	                              }
+	                            }
+	                          };
+	                        }
+	                      }
+	                    }
+	                  };
+	                }
+	              }
+	            };
+	          }
+	        }
+	      }
+	      void foo2 () {
+	        class W1 {
+	          void bar() {
+	            new W1() {};
+	          }
+	        }
+	      }
+	    }"""};
+	addLibrary("innerClasses.jar", "innerClassessrc.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 }
 @Override
 protected void tearDown() throws Exception {
@@ -912,8 +941,20 @@ public void testInnerClass1() throws JavaModelException {
 		"      class Z {}\n" +
 		"    };\n" +
 		"    class W {\n" +
+		"      {\n" +
+		"        class Y { // One\n" +
+		"        }\n" +
+		"      }\n" +
 		"      void bar() {\n" +
 		"        new W() {};\n" +
+		"        {\n" +
+		"          class Y { // Two\n" +
+		"          }\n" +
+		"        }\n" +
+		"        {\n" +
+		"          class Y { // Three\n" +
+		"          }\n" +
+		"        }\n" +
 		"      }\n" +
 		"    }\n" +
 		"    new Object() {\n" +
@@ -937,7 +978,43 @@ public void testInnerClass1() throws JavaModelException {
 		"      }\n" +
 		"    }\n" +
 		"  }\n" +
-		"}",
+		"  void foo1() {\n"
+		+ "    class W1 {\n"
+		+ "      void bar() {\n"
+		+ "        new W1() {\n"
+		+ "          class W2 {\n"
+		+ "            void foobar() {\n"
+		+ "              new W2() {\n"
+		+ "                void foobar2() {\n"
+		+ "                  class W3 {\n"
+		+ "                    void foobar3() {\n"
+		+ "                      new W3() {\n"
+		+ "                        void foobar4() {\n"
+		+ "                          class W4 {\n"
+		+ "                            void foobar5() {\n"
+		+ "                              new W4();\n"
+		+ "                            }\n"
+		+ "                          }\n"
+		+ "                        }\n"
+		+ "                      };\n"
+		+ "                    }\n"
+		+ "                  }\n"
+		+ "                }\n"
+		+ "              };\n"
+		+ "            }\n"
+		+ "          }\n"
+		+ "        };\n"
+		+ "      }\n"
+		+ "    }\n"
+		+ "  }\n"
+		+ "  void foo2 () {\n"
+		+ "    class W1 {\n"
+		+ "      void bar() {\n"
+		+ "        new W1() {};\n"
+		+ "      }\n"
+		+ "    }\n"
+		+ "  }\n"
+		+ "}",
 		type.getSource());
 	attachSource(root, null, null); // detach source
 }
@@ -984,7 +1061,7 @@ public void testInnerClass4() throws JavaModelException {
 	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
 	IPackageFragment fragment = root.getPackageFragment("inner");
 
-	IType type = fragment.getOrdinaryClassFile("X$3.class").getType();
+	IType type = fragment.getOrdinaryClassFile("X$1W$1.class").getType();
 	assertSourceEquals(
 		"Unexpected source",
 		"new W() {}",
@@ -1000,7 +1077,7 @@ public void testInnerClass5() throws JavaModelException {
 	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
 	IPackageFragment fragment = root.getPackageFragment("inner");
 
-	IType type = fragment.getOrdinaryClassFile("X$1$Y.class").getType();
+	IType type = fragment.getOrdinaryClassFile("X$1Y.class").getType();
 	assertSourceEquals(
 		"Unexpected source",
 		"class Y {}",
@@ -1016,12 +1093,24 @@ public void testInnerClass6() throws JavaModelException {
 	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
 	IPackageFragment fragment = root.getPackageFragment("inner");
 
-	IType type = fragment.getOrdinaryClassFile("X$1$W.class").getType();
+	IType type = fragment.getOrdinaryClassFile("X$1W.class").getType();
 	assertSourceEquals(
 		"Unexpected source",
 		"class W {\n" +
+		"      {\n" +
+		"        class Y { // One\n" +
+		"        }\n" +
+		"      }\n" +
 		"      void bar() {\n" +
 		"        new W() {};\n" +
+		"        {\n" +
+		"          class Y { // Two\n" +
+		"          }\n" +
+		"        }\n" +
+		"        {\n" +
+		"          class Y { // Three\n" +
+		"          }\n" +
+		"        }\n" +
 		"      }\n" +
 		"    }",
 		type.getSource());
@@ -1071,8 +1160,7 @@ public void testInnerClass9() throws JavaModelException {
 	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
 	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
 	IPackageFragment fragment = root.getPackageFragment("inner");
-
-	IType type = fragment.getOrdinaryClassFile("X$4$U.class").getType();
+	IType type = fragment.getOrdinaryClassFile("X$3$U.class").getType();
 	assertSourceEquals(
 		"Unexpected source",
 		"class U {\n" +
@@ -1108,6 +1196,133 @@ public void testInnerClass10() throws JavaModelException {
 		type.getSource());
 	attachSource(root, null, null); // detach source
 }
+public void testInnerClass11() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W1$1$W2$1$1W3$1$1W4.class").getType();
+	assertSourceEquals(
+		"Unexpected source",
+		"class W4 {\n"
+		+ "                            void foobar5() {\n"
+		+ "                              new W4();\n"
+		+ "                            }\n"
+		+ "                          }",
+		type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass12() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W1$1$W2$1$1W3$1.class").getType();
+	assertSourceEquals(
+		"Unexpected source",
+		"new W3() {\n"
+		+ "                        void foobar4() {\n"
+		+ "                          class W4 {\n"
+		+ "                            void foobar5() {\n"
+		+ "                              new W4();\n"
+		+ "                            }\n"
+		+ "                          }\n"
+		+ "                        }\n"
+		+ "                      }",
+		type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass13() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W1$1$W2$1$1W3.class").getType();
+	assertSourceEquals(
+		"Unexpected source",
+		"class W3 {\n"
+		+ "                    void foobar3() {\n"
+		+ "                      new W3() {\n"
+		+ "                        void foobar4() {\n"
+		+ "                          class W4 {\n"
+		+ "                            void foobar5() {\n"
+		+ "                              new W4();\n"
+		+ "                            }\n"
+		+ "                          }\n"
+		+ "                        }\n"
+		+ "                      };\n"
+		+ "                    }\n"
+		+ "                  }",
+		type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass14() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$2W1.class").getType();
+	assertSourceEquals(
+		"Unexpected source",
+		"class W1 {\n"
+		+ "      void bar() {\n"
+		+ "        new W1() {};\n"
+		+ "      }\n"
+		+ "    }",
+		type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass15() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$2W1$1.class").getType();
+	assertSourceEquals(
+			"Unexpected source",
+			"new W1() {}",
+			type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass16() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W$1Y.class").getType();
+	assertSourceEquals(
+			"Unexpected source",
+			"class Y { // One\n" +
+					"        }",
+			type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass17() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W$2Y.class").getType();
+	assertSourceEquals(
+			"Unexpected source",
+			"class Y { // Two\n" +
+					"          }",
+			type.getSource());
+	attachSource(root, null, null); // detach source
+}
+public void testInnerClass18() throws JavaModelException {
+	IJavaProject project = this.getJavaProject("/AttachSourceTests");
+	IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/AttachSourceTests/innerClasses.jar"));
+	attachSource(root, "/AttachSourceTests/innerClassessrc.zip", null);
+	IPackageFragment fragment = root.getPackageFragment("inner");
+	IType type = fragment.getOrdinaryClassFile("X$1W$3Y.class").getType();
+	assertSourceEquals(
+			"Unexpected source",
+			"class Y { // Three\n" +
+					"          }",
+			type.getSource());
+	attachSource(root, null, null); // detach source
+}
 /**
  * Ensures that a source folder can be attached to a lib folder.
  */
@@ -1653,7 +1868,7 @@ public void testRootPath13() throws JavaModelException {
 	attachSource(root, null, null); // detach source
 }
 /**
- * @test bug 153133: [model] toggle breakpoint in constructor creates a class load breakpoint
+ * bug 153133: [model] toggle breakpoint in constructor creates a class load breakpoint
  * @see "http://bugs.eclipse.org/bugs/show_bug.cgi?id=153133"
  */
 public void testBug153133() throws JavaModelException {
@@ -1678,7 +1893,7 @@ public void testBug153133() throws JavaModelException {
 		// Need to get type members constructors
 		for (int i = 0; i < length; i++) {
 			assertTrue(members[i] instanceof IMember);
-			if (((IMember)members[i]).getElementType() == IJavaElement.TYPE) {
+			if (members[i].getElementType() == IJavaElement.TYPE) {
 				IType typeMember = (IType) members[i];
 				String typeName = typeMember.getElementName();
 				IMethod[] methods = typeMember.getMethods();
