@@ -12,12 +12,11 @@
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.model;
 
+import junit.framework.Test;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 
-import junit.framework.Test;
-
 public class CompletionTests17 extends AbstractJavaModelCompletionTests {
 
 	private static int expected_Rel = R_DEFAULT+R_RESOLVED+ R_CASE+ R_INTERESTING+R_EXACT_EXPECTED_TYPE+R_NON_STATIC+R_NON_RESTRICTED;
@@ -25,9 +24,8 @@ public class CompletionTests17 extends AbstractJavaModelCompletionTests {
 	private static int nonVoid_Rel = R_DEFAULT+R_RESOLVED+ R_CASE+ R_INTERESTING +R_NON_STATIC+R_NON_RESTRICTED;
 	private static int unqualified_Rel = R_DEFAULT+R_RESOLVED+ R_CASE+ R_INTERESTING +R_UNQUALIFIED+R_NON_RESTRICTED;
 	private static int unqualifiedExact_Rel = R_DEFAULT+R_RESOLVED+R_EXACT_EXPECTED_TYPE+ R_CASE+ R_INTERESTING +R_UNQUALIFIED+R_NON_RESTRICTED;
-	private static int keyword_Rel= R_DEFAULT + R_RESOLVED + R_INTERESTING + R_CASE + R_NON_RESTRICTED;
 	static {
-		// TESTS_NAMES = new String[]{"test034"};
+		 // TESTS_NAMES = new String[]{"test034"};
 	}
 
 	public CompletionTests17(String name) {
@@ -36,9 +34,9 @@ public class CompletionTests17 extends AbstractJavaModelCompletionTests {
 
 	public void setUpSuite() throws Exception {
 		if (COMPLETION_PROJECT == null) {
-			COMPLETION_PROJECT = setUpJavaProject("Completion", "21");
+			COMPLETION_PROJECT = setUpJavaProject("Completion", "17");
 		} else {
-			setUpProjectCompliance(COMPLETION_PROJECT, "21");
+			setUpProjectCompliance(COMPLETION_PROJECT, "17");
 		}
 		super.setUpSuite();
 		COMPLETION_PROJECT.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.DISABLED);
@@ -414,245 +412,7 @@ public class CompletionTests17 extends AbstractJavaModelCompletionTests {
 				requestor.getResults());
 
 	}
-	public void test011() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case     : System.out.println(\"Integer:\" + i);break;\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case ";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("default[KEYWORD]{default, null, null, default, null, "+keyword_Rel+"}\n"
-				+ "null[KEYWORD]{null, null, null, null, null, "+keyword_Rel+"}",
-				requestor.getResults());
 
-	}
-	public void test012() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case nu    : System.out.println(\"Integer:\" + i);break;\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case nu";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("null[KEYWORD]{null, null, null, null, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
-	public void test013() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case de    : System.out.println(\"Integer:\" + i);break;\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case de";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("default[KEYWORD]{default, null, null, default, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
-	public void test014() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case null    : System.out.println(\"Integer:\" + i);break;\n" +
-						"	/*here*/case nu    : System.out.println(\"Integer:\" + i);break;\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "/*here*/case nu";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("",
-				requestor.getResults());
-
-	}
-	public void test015() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case default    : System.out.println(\"Integer:\" + i);break;\n" +
-						"	/*here*/case de    : System.out.println(\"Integer:\" + i);break;\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "/*here*/case de";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("",
-				requestor.getResults());
-
-	}
-	public void test016() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case nu    -> System.out.println(\"Integer:\" + i);\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case nu";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("null[KEYWORD]{null, null, null, null, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
-	public void test017() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case de    -> System.out.println(\"Integer:\" + i);\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case de";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("default[KEYWORD]{default, null, null, default, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
-	public void test018() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case Integer i    -> System.out.println(\"Integer:\"  +i);\n" +
-						"	case de    -> System.out.println(\"Integer:\" + i);\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case de";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("default[KEYWORD]{default, null, null, default, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
-	public void test019() throws JavaModelException {
-		this.workingCopies = new ICompilationUnit[1];
-		this.workingCopies[0] = getWorkingCopy(
-				"/Completion/src/X.java",
-				"public class X {\n" +
-						"public static void main(String[] args) {\n" +
-						"foo(Integer.valueOf(5));\n" +
-						"foo(new Object());\n" +
-						"}\n" +
-						"private static void foo(Object o) {\n" +
-						" switch (o) {\n" +
-						"	case Integer i    -> System.out.println(\"Integer:\"  +i);\n" +
-						"	case n    -> System.out.println(\"Integer:\" + i);\n" +
-						" 	}\n" +
-						"}\n" +
-						"}\n"
-				);
-		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
-		requestor.allowAllRequiredProposals();
-		String str = this.workingCopies[0].getSource();
-		String completeBehind = "case n";
-		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
-		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
-		assertResults("null[KEYWORD]{null, null, null, null, null, "+keyword_Rel+"}",
-				requestor.getResults());
-
-	}
 	// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/1100
 	// ContentAssist / CompletionScanner running into deadlock
 	public void testGH1100() throws JavaModelException {
@@ -683,4 +443,211 @@ public class CompletionTests17 extends AbstractJavaModelCompletionTests {
 				requestor.getResults());
 
 	}
+	// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/92
+	// [Patterns] Suggest identifier completion for obj instanceof Dog
+	public void testIssue92() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy(
+				"/Completion/src/Dog.java",
+				"public class Dog {\n" +
+				"	public static void main(String[] args) {\n" +
+				"		Object o = null;\n" +
+				"		if (o instanceof Dog )\n" +
+				"	}\n" +
+				"}\n");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "Dog ";
+		int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("dog[VARIABLE_DECLARATION]{dog, null, LDog;, dog, null, 48}",
+				requestor.getResults());
+
+	}
+
+	public void testGH2256() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy("/Completion/src/EnumClass.java", """
+				public enum EnumClass  {
+
+				}\
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "EnumClass ";
+		int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("""
+				implements[KEYWORD]{implements, null, null, implements, null, 49}\
+					""", requestor.getResults());
+	}
+
+	public void testGH2261() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy("/Completion/src/SealedI.java", """
+				public sealed interface SealedI p  {
+				}\
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "SealedI p";
+		int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("""
+				permits[RESTRICTED_IDENTIFIER]{permits, null, null, permits, null, 49}\
+					""", requestor.getResults());
+	}
+	// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/2540
+	// Completion fails within the body of a permitted class
+	public void testGH2540() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[2];
+		this.workingCopies[0] = getWorkingCopy("/Completion/src/Storage.java", """
+				public sealed class Storage permits SqlStorage {
+				}\
+				""");
+		this.workingCopies[1] = getWorkingCopy("/Completion/src/SqlStorage.java", """
+				public final class SqlStorage extends Storage {
+				/*here*/Sq
+				}\
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[1].getSource();
+		String completeBehind = "/*here*/Sq";
+		int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[1].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("""
+				Sq[POTENTIAL_METHOD_DECLARATION]{Sq, LSqlStorage;, ()V, Sq, null, 39}
+				SqlStorage[TYPE_REF]{SqlStorage, , LSqlStorage;, null, null, 52}\
+					""", requestor.getResults());
+	}
+	// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/2106
+	public void testGH2106() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy(
+				"/Completion/src/X.java",
+				"""
+				import java.util.ArrayList;
+				import java.util.List;
+				public class X {
+				  public static void main(String[] args) {
+				    Object unknown = "abc";
+				    if (unknown instanceof String str) {
+				      str.le
+				      Object nothing = null;
+				      str.le
+				    }
+				  }
+				}
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "str.le";
+		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("length[METHOD_REF]{length(), Ljava.lang.String;, ()I, length, null, 60}",
+				requestor.getResults());
+	}
+	public void testGH2106a() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy(
+				"/Completion/src/X.java",
+				"""
+				import java.util.ArrayList;
+				import java.util.List;
+				public class X {
+				  public static void main(String[] args) {
+				    Object unknown = "abc";
+				    if (unknown instanceof String str) {
+				      str.
+				      Object nothing = null;
+				      str.
+				    }
+				  }
+				}
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "str.";
+		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("clone[METHOD_REF]{clone(), Ljava.lang.Object;, ()Ljava.lang.Object;, clone, null, 60}\n"
+				+ "codePointAt[METHOD_REF]{codePointAt(), Ljava.lang.String;, (I)I, codePointAt, (index), 60}\n"
+				+ "equals[METHOD_REF]{equals(), Ljava.lang.Object;, (Ljava.lang.Object;)Z, equals, (obj), 60}\n"
+				+ "finalize[METHOD_REF]{finalize(), Ljava.lang.Object;, ()V, finalize, null, 60}\n"
+				+ "getClass[METHOD_REF]{getClass(), Ljava.lang.Object;, ()Ljava.lang.Class<+Ljava.lang.Object;>;, getClass, null, 60}\n"
+				+ "hashCode[METHOD_REF]{hashCode(), Ljava.lang.Object;, ()I, hashCode, null, 60}\n"
+				+ "length[METHOD_REF]{length(), Ljava.lang.String;, ()I, length, null, 60}\n"
+				+ "notify[METHOD_REF]{notify(), Ljava.lang.Object;, ()V, notify, null, 60}\n"
+				+ "notifyAll[METHOD_REF]{notifyAll(), Ljava.lang.Object;, ()V, notifyAll, null, 60}\n"
+				+ "toString[METHOD_REF]{toString(), Ljava.lang.Object;, ()Ljava.lang.String;, toString, null, 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, ()V, wait, null, 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, (J)V, wait, (millis), 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, (JI)V, wait, (millis, nanos), 60}",
+				requestor.getResults());
+	}
+	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=568934#c6
+	public void testGH2106b() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy(
+				"/Completion/src/X.java",
+				"""
+				public class X {
+				public static void main(String[] args) {
+					Object o = new Object();
+					if(o instanceof X mc) {
+							mc.
+							System.out.println("hello "+mc.);
+						}
+					}
+				}
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "mc.";
+		int cursorLocation = str.indexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("main[METHOD_REF]{main(), LX;, ([Ljava.lang.String;)V, main, (args), 49}\n"
+				+ "clone[METHOD_REF]{clone(), Ljava.lang.Object;, ()Ljava.lang.Object;, clone, null, 60}\n"
+				+ "equals[METHOD_REF]{equals(), Ljava.lang.Object;, (Ljava.lang.Object;)Z, equals, (obj), 60}\n"
+				+ "finalize[METHOD_REF]{finalize(), Ljava.lang.Object;, ()V, finalize, null, 60}\n"
+				+ "getClass[METHOD_REF]{getClass(), Ljava.lang.Object;, ()Ljava.lang.Class<+Ljava.lang.Object;>;, getClass, null, 60}\n"
+				+ "hashCode[METHOD_REF]{hashCode(), Ljava.lang.Object;, ()I, hashCode, null, 60}\n"
+				+ "notify[METHOD_REF]{notify(), Ljava.lang.Object;, ()V, notify, null, 60}\n"
+				+ "notifyAll[METHOD_REF]{notifyAll(), Ljava.lang.Object;, ()V, notifyAll, null, 60}\n"
+				+ "toString[METHOD_REF]{toString(), Ljava.lang.Object;, ()Ljava.lang.String;, toString, null, 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, ()V, wait, null, 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, (J)V, wait, (millis), 60}\n"
+				+ "wait[METHOD_REF]{wait(), Ljava.lang.Object;, (JI)V, wait, (millis, nanos), 60}",
+				requestor.getResults());
+	}
+	// https://bugs.eclipse.org/bugs/show_bug.cgi?id=568934#c8
+	public void testGH2106c() throws JavaModelException {
+		this.workingCopies = new ICompilationUnit[1];
+		this.workingCopies[0] = getWorkingCopy(
+				"/Completion/src/X.java",
+				"""
+				class X {
+				    int x, y;
+				    public boolean equals(Object o) {
+						return o instanceof X other && this.x == oth // content assist here gives the issues
+					}
+				}
+				""");
+		CompletionTestsRequestor2 requestor = new CompletionTestsRequestor2(true);
+		requestor.allowAllRequiredProposals();
+		String str = this.workingCopies[0].getSource();
+		String completeBehind = "oth";
+		int cursorLocation = str.lastIndexOf(completeBehind) + completeBehind.length();
+		this.workingCopies[0].codeComplete(cursorLocation, requestor, this.wcOwner);
+		assertResults("other[LOCAL_VARIABLE_REF]{other, null, LX;, other, null, 52}",
+				requestor.getResults());
+		}
+
 }
