@@ -14,9 +14,7 @@
 package org.eclipse.jdt.core.tests.model;
 
 import java.io.IOException;
-
 import junit.framework.Test;
-
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.jdt.core.ICompilationUnit;
@@ -25,6 +23,7 @@ import org.eclipse.jdt.core.IOrdinaryClassFile;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.ITypeHierarchy;
 import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 public class HierarchyOnWorkingCopiesTests extends WorkingCopyTests {
 
@@ -174,7 +173,7 @@ public void test228845b() throws CoreException, IOException {
 			"package my.pkg;\n" +
 			"public class Y {\n" +
 			"  }\n",
-		}, JavaCore.VERSION_1_4);
+		}, CompilerOptions.getFirstSupportedJavaVersion());
 
 
 	IFile file = null;
