@@ -15,14 +15,16 @@
 package org.eclipse.jdt.core.tests.model;
 
 import junit.framework.Test;
-
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IWorkspaceRunnable;
-
 import org.eclipse.core.resources.IncrementalProjectBuilder;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.OperationCanceledException;
+import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.*;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 
 public class RenameTests extends CopyMoveTests {
 	ICompilationUnit cu;
@@ -166,7 +168,7 @@ public void setUp() throws Exception {
 public void setUpSuite() throws Exception {
 	super.setUpSuite();
 
-	IJavaProject project = this.createJavaProject("BinaryProject", new String[] {"src"}, new String[] {"JCL_LIB"}, "lib");
+	IJavaProject project = this.createJavaProject("BinaryProject", new String[] {"src"}, new String[] {"JCL18_LIB"}, "lib");
 	this.createFile(
 		"/BinaryProject/src/X.java",
 		"public class X {\n" +
@@ -430,7 +432,7 @@ public void testRenameEmptyPF() throws CoreException {
  */
 public void testRenameEnum() throws CoreException {
 	try {
-		createJavaProject("P15", new String[] {""}, new String[] {"JCL15_LIB"}, "", "1.5");
+		createJavaProject("P15", new String[] {""}, new String[] {"JCL18_LIB"}, "", CompilerOptions.getFirstSupportedJavaVersion());
 		createFile(
 			"/P15/En.java",
 			"public enum En {\n" +
@@ -461,7 +463,7 @@ public void testRenameEnum() throws CoreException {
  */
 public void testRenameEnum2() throws CoreException {
 	try {
-		createJavaProject("P15", new String[] {""}, new String[] {"JCL15_LIB"}, "", "1.5");
+		createJavaProject("P15", new String[] {""}, new String[] {"JCL18_LIB"}, "", CompilerOptions.getFirstSupportedJavaVersion());
 		createFile(
 			"/P15/En.java",
 			"public enum En {\n" +
