@@ -14,13 +14,12 @@
 
 package org.eclipse.jdt.core.tests.model;
 
+import junit.framework.Test;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.WorkingCopyOwner;
 
-import junit.framework.Test;
-
 public class ResolveTests12To15 extends AbstractJavaModelTests {
 	ICompilationUnit wc = null;
 
@@ -296,7 +295,7 @@ public void test009() throws JavaModelException {
  * which is referencing a local variable defined in the case block
  */
 public void test010() throws JavaModelException {
-	this.wc = getWorkingCopy("/Resolve/src/X.java","public class X {\n" +
+	this.wc = getWorkingCopy("/Resolve15/src/X.java","public class X {\n" +
 	"  public static void foo(Num num_) {\n" +
 	" 	 switch (num_) {\n" +
 	"	   case ONE, TWO, THREE -> {\n" +
@@ -315,7 +314,7 @@ public void test010() throws JavaModelException {
 	IJavaElement[] elements = this.wc.codeSelect(start, length);
 	assertElementsEqual(
 		"Unexpected elements",
-		"i_j [in foo(Num) [in X [in [Working copy] X.java [in <default> [in src [in Resolve]]]]]]",
+		"i_j [in foo(Num) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]]",
 		elements
 	);
 }
@@ -481,8 +480,10 @@ public void test017() throws JavaModelException {
 	);
 }
 public void test018() throws JavaModelException {
-	this.wc = getWorkingCopy("/Resolve/src/X.java",
-			"import java.util.function.*;\n" +
+	this.wc = getWorkingCopy("/Resolve15/src/X.java",
+			 "interface Supplier<T> {\n" +
+			"    T get();\n" +
+			"}\n" +
 			"interface IN0 {} \n" +
 			"interface IN1 extends IN0 {} \n" +
 			"interface IN2 extends IN0 {}\n" +
@@ -503,7 +504,7 @@ public void test018() throws JavaModelException {
 	IJavaElement[] elements = this.wc.codeSelect(start, length);
 	assertElementsEqual(
 		"Unexpected elements",
-		"n_1() [in X [in [Working copy] X.java [in <default> [in src [in Resolve]]]]]",
+		"n_1() [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]",
 		elements
 	);
 }
@@ -678,7 +679,7 @@ public void testBug553149_3() throws JavaModelException {
 		elements
 	);
 }
-public void _testBug553149_4() throws JavaModelException {
+public void testBug553149_4() throws JavaModelException {
 	this.wc = getWorkingCopy("/Resolve15/src/X.java",
 			"public class X {\n"
 					+ "    protected Object x_ = \"FIELD X\";\n"
@@ -690,17 +691,17 @@ public void _testBug553149_4() throws JavaModelException {
 					+ "    }\n"
 					+ "}");
 	String str = this.wc.getSource();
-	String selection = "x_ instanceof";
+	String selection = "x_";
 	int start = str.lastIndexOf(selection);
 	int length = "x_".length();
 	IJavaElement[] elements = this.wc.codeSelect(start, length);
 	assertElementsEqual(
 		"Unexpected elements",
-		"x_ [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]",
+		"x_ [in f(Object, boolean) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]]",
 		elements
 	);
 }
-public void _testBug553149_5() throws JavaModelException {
+public void testBug553149_5() throws JavaModelException {
 	this.wc = getWorkingCopy("/Resolve15/src/X.java",
 			"public class X {\n"
 					+ "    protected Object x_ = \"FIELD X\";\n"
@@ -1702,4 +1703,101 @@ public void testGH1568_5() throws JavaModelException {
 		elements
 	);
 }
+// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/2443
+// ArrayStoreException in SelectionParser.buildMoreCompletionContext
+public void testGH2443() throws JavaModelException {
+	this.wc = getWorkingCopy("/Resolve15/src/X.java",
+					"""
+					 public class X {
+
+						public static void main(String[] args) {
+
+							for (String sourcePath : args) {
+								new X() {
+									public void foo(String file) {
+										file.hashCode();
+									}
+
+								};
+							}
+						}
+					}
+					""");
+	String str = this.wc.getSource();
+	String selection = "file";
+	int start = str.lastIndexOf(selection);
+	int length = selection.length();
+	IJavaElement[] elements = this.wc.codeSelect(start, length);
+	assertElementsEqual(
+		"Unexpected elements",
+		"file [in foo(String) [in <anonymous #1> [in main(String[]) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]]]]",
+		elements
+	);
+}
+// https://github.com/eclipse-jdt/eclipse.jdt.core/issues/3777
+// [Code select] NPE in SwitchExpression: Cannot invoke "org.eclipse.jdt.internal.compiler.lookup.TypeBinding.unboxedType()" because "rxpressionType" is null
+public void testIssue3777() throws JavaModelException {
+	this.wc = getWorkingCopy("/Resolve15/src/X.java",
+			"""
+			public interface X <T, U> {
+				void accept(T t, U u);
+
+				default void foo(String s) {
+					X<String, String> set = switch (this) {
+						default -> {
+							yield (k, v) -> {
+								foo/*first*/(s);
+							};
+						}
+					};
+					set = switch (this) {
+						default -> {
+							yield (k, v) -> {
+								foo/*second*/(s);
+							};
+						}
+					};
+				}
+
+				X<String, String> set = switch (this) {
+						default -> {
+							yield (k, v) -> {
+								foo/*third*/("test");
+							};
+						}
+					};
+
+			}
+			""");
+	String str = this.wc.getSource();
+	String selection = "foo/*first*/";
+	int start = str.lastIndexOf(selection);
+	int length = selection.length();
+	IJavaElement[] elements = this.wc.codeSelect(start, length);
+	assertElementsEqual(
+		"Unexpected elements",
+		"foo(String) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]",
+		elements
+	);
+
+	selection = "foo/*second*/";
+	start = str.lastIndexOf(selection);
+	length = selection.length();
+	elements = this.wc.codeSelect(start, length);
+	assertElementsEqual(
+		"Unexpected elements",
+		"foo(String) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]",
+		elements
+	);
+
+	selection = "foo/*third*/";
+	start = str.lastIndexOf(selection);
+	length = selection.length();
+	elements = this.wc.codeSelect(start, length);
+	assertElementsEqual(
+		"Unexpected elements",
+		"foo(String) [in X [in [Working copy] X.java [in <default> [in src [in Resolve15]]]]]",
+		elements
+	);
+}
 }
