@@ -16,26 +16,18 @@ package org.eclipse.jdt.core.tests.model;
 import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
-
+import junit.framework.Test;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.jdt.core.Flags;
-import org.eclipse.jdt.core.IAnnotation;
-import org.eclipse.jdt.core.ICodeAssist;
-import org.eclipse.jdt.core.ICompilationUnit;
-import org.eclipse.jdt.core.IJavaElement;
-import org.eclipse.jdt.core.IJavaProject;
-import org.eclipse.jdt.core.ILocalVariable;
-import org.eclipse.jdt.core.IMemberValuePair;
-import org.eclipse.jdt.core.IMethod;
-import org.eclipse.jdt.core.IPackageFragment;
-import org.eclipse.jdt.core.IPackageFragmentRoot;
-import org.eclipse.jdt.core.ISourceRange;
-import org.eclipse.jdt.core.IType;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.JavaModelException;
-import org.eclipse.jdt.core.Signature;
+import org.eclipse.jdt.core.*;
+import org.eclipse.jdt.core.dom.AST;
+import org.eclipse.jdt.core.dom.CompilationUnit;
+import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
+import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
+import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
 import org.eclipse.jdt.core.tests.util.Util;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.core.JavaProject;
 import org.eclipse.jdt.internal.core.LambdaExpression;
 import org.eclipse.jdt.internal.core.LambdaMethod;
@@ -44,8 +36,6 @@ import org.eclipse.jdt.internal.core.NameLookup;
 import org.eclipse.jdt.internal.core.NameLookup.Answer;
 import org.eclipse.jdt.internal.core.SourceType;
 
-import junit.framework.Test;
-
 @SuppressWarnings({"rawtypes", "unchecked"})
 public class TypeResolveTests extends ModifyingResourceTests {
 	ICompilationUnit cu;
@@ -123,7 +113,7 @@ public void setUpSuite() throws Exception {
 			"   return new X() {};" +
 			"  }\n" +
 			"}",
-		}, JavaCore.VERSION_1_4);
+		}, CompilerOptions.getFirstSupportedJavaVersion());
 }
 	static {
 //		TESTS_NUMBERS = new int[] { 182, 183 };
@@ -166,7 +156,7 @@ public void testResolveMemberTypeInInner() throws JavaModelException {
  */
 public void testResolveParameterizedType() throws CoreException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		createFile(
 			"/P/src/X.java",
 			"public class X<T> {\n" +
@@ -235,7 +225,7 @@ public void testResolveTypeInBinary4() throws Exception {
 			"    }\n" +
 			"  }\n" +
 			"}"
-		}, "1.4");
+		}, CompilerOptions.getFirstSupportedJavaVersion());
 		IType type = getPackageFragmentRoot("/TypeResolve/lib212224.jar").getPackageFragment("").getOrdinaryClassFile("X212224$Member.class").getType();
 		String[][] types = type.resolveType("int");
 		assertTypesEqual(
@@ -337,7 +327,7 @@ public void testResolveInnerType2() throws JavaModelException {
  */
 public void testParamAnnotations() throws CoreException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n" +
 				"public class X<T> {\n" +
 				"	X<String> field;\n" +
@@ -356,7 +346,7 @@ public void testParamAnnotations() throws CoreException {
 		waitForAutoBuild();
 
 		ICompilationUnit unit = getCompilationUnit("/P/src/p/X.java");
-		IJavaElement[] variable = ((ICodeAssist) unit).codeSelect(source.indexOf("processor"), "processor".length());
+		IJavaElement[] variable = unit.codeSelect(source.indexOf("processor"), "processor".length());
 
 		assertEquals(1, variable.length);
 		String annotationString = "@Default [in processor [in Test(String) [in X [in X.java [in p [in src [in P]]]]]]]";
@@ -374,7 +364,7 @@ public void testParamAnnotations() throws CoreException {
  */
 public void testParamAnnotations2() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String[] pathAndContents = new String[]{"p/X.java",
 				"package p;\n" +
 				"public class X<T> {\n" +
@@ -386,7 +376,7 @@ public void testParamAnnotations2() throws CoreException, IOException {
 				"}" +
 				"@interface Default{\n" +
 				"}"};
-		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, JavaCore.VERSION_1_5);
+		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783.jar"));
@@ -404,7 +394,7 @@ public void testParamAnnotations2() throws CoreException, IOException {
  */
 public void testParamAnnotations3() throws CoreException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n" +
 				"public class X<T> {\n" +
 				"	X<String> field;\n" +
@@ -426,7 +416,7 @@ public void testParamAnnotations3() throws CoreException {
 		waitForAutoBuild();
 
 		ICompilationUnit unit = getCompilationUnit("/P/src/p/X.java");
-		IJavaElement[] variable = ((ICodeAssist) unit).codeSelect(source.indexOf("processor"), "processor".length());
+		IJavaElement[] variable = unit.codeSelect(source.indexOf("processor"), "processor".length());
 
 		assertEquals(1, variable.length);
 		String annotationString1 = "@Default [in processor [in Test(int, String, int) [in X [in X.java [in p [in src [in P]]]]]]]";
@@ -442,7 +432,7 @@ public void testParamAnnotations3() throws CoreException {
 		assertEquals(annotationString2, iAnnotation.toString());
 		IMemberValuePair[] memberValuePairs = iAnnotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		StringBuffer output = new StringBuffer();
+		StringBuilder output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -458,7 +448,7 @@ public void testParamAnnotations3() throws CoreException {
  */
 public void testParamAnnotations4() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String sourceX =
 				"package p;\n" +
 				"public class X<T> {\n" +
@@ -481,7 +471,7 @@ public void testParamAnnotations4() throws CoreException, IOException {
 				"package p;\n" +
 				"public @interface Default{\n" +
 				"}"};
-		addLibrary(project, "lib334783_2.jar", "lib334783_2src.zip", pathAndContents, JavaCore.VERSION_1_5);
+		addLibrary(project, "lib334783_2.jar", "lib334783_2src.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783_2.jar"));
@@ -496,7 +486,7 @@ public void testParamAnnotations4() throws CoreException, IOException {
 		assertEquals("@p.Marker [in Test(int, java.lang.String, int) [in X [in X.class [in p [in lib334783_2.jar [in P]]]]]]", annotation.toString());
 		IMemberValuePair[] memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		StringBuffer output = new StringBuffer();
+		StringBuilder output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -515,7 +505,7 @@ public void testParamAnnotations4() throws CoreException, IOException {
 		assertEquals(annotationString2, annotation.toString());
 		memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		output = new StringBuffer();
+		output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -533,7 +523,7 @@ public void testParamAnnotations4() throws CoreException, IOException {
  */
 public void testParamAnnotations5() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String[] pathAndContents = new String[]{"p/X.java",
 				"package p;\n" +
 				"public class X<T> {\n" +
@@ -556,7 +546,7 @@ public void testParamAnnotations5() throws CoreException, IOException {
 				"}"};
 		Map options = new HashMap();
 		options.put(JavaCore.COMPILER_LOCAL_VARIABLE_ATTR, JavaCore.DO_NOT_GENERATE);
-		addLibrary(project, "lib334783_3.jar", "lib334783_3src.zip", pathAndContents, JavaCore.VERSION_1_5, options);
+		addLibrary(project, "lib334783_3.jar", "lib334783_3src.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion(), options);
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783_3.jar"));
@@ -571,7 +561,7 @@ public void testParamAnnotations5() throws CoreException, IOException {
 		assertEquals("@p.Marker [in Test(int, java.lang.String, int) [in X [in X.class [in p [in lib334783_3.jar [in P]]]]]]", annotation.toString());
 		IMemberValuePair[] memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		StringBuffer output = new StringBuffer();
+		StringBuilder output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -583,7 +573,7 @@ public void testParamAnnotations5() throws CoreException, IOException {
 		assertEquals(annotationString2, annotation.toString());
 		memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		output = new StringBuffer();
+		output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -599,7 +589,7 @@ public void testParamAnnotations5() throws CoreException, IOException {
  */
 public void testParamAnnotations6() throws CoreException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n" +
 				"public class X<T> {\n" +
 				"	X<String> field;\n" +
@@ -627,7 +617,7 @@ public void testParamAnnotations6() throws CoreException {
  */
 public void testParamAnnotations7() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String[] pathAndContents = new String[]{"p/X.java",
 				"package p;\n" +
 				"public class X<T> {\n" +
@@ -635,7 +625,7 @@ public void testParamAnnotations7() throws CoreException, IOException {
 				"	public void Test() {}\n" +
 				"}"
 		};
-		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, JavaCore.VERSION_1_5);
+		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783.jar"));
@@ -654,7 +644,7 @@ public void testParamAnnotations7() throws CoreException, IOException {
  */
 public void testParamAnnotations8() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String[] pathAndContents = new String[]{"p/X.java",
 				"package p;\n" +
 				"public class X<T> {\n" +
@@ -677,7 +667,7 @@ public void testParamAnnotations8() throws CoreException, IOException {
 				"}"};
 		Map options = new HashMap();
 		options.put(JavaCore.COMPILER_LOCAL_VARIABLE_ATTR, JavaCore.DO_NOT_GENERATE);
-		addLibrary(project, "lib334783_3.jar", "lib334783_3src.zip", pathAndContents, JavaCore.VERSION_1_5, options);
+		addLibrary(project, "lib334783_3.jar", "lib334783_3src.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion(), options);
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783_3.jar"));
@@ -692,7 +682,7 @@ public void testParamAnnotations8() throws CoreException, IOException {
 		assertEquals("@p.Marker [in X(int, java.lang.String, int) [in X [in X.class [in p [in lib334783_3.jar [in P]]]]]]", annotation.toString());
 		IMemberValuePair[] memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		StringBuffer output = new StringBuffer();
+		StringBuilder output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -704,7 +694,7 @@ public void testParamAnnotations8() throws CoreException, IOException {
 		assertEquals(annotationString2, annotation.toString());
 		memberValuePairs = annotation.getMemberValuePairs();
 		assertEquals("Wrong number of pairs", 1, memberValuePairs.length);
-		output = new StringBuffer();
+		output = new StringBuilder();
 		output.append(memberValuePairs[0].getMemberName());
 		output.append(' ');
 		output.append(memberValuePairs[0].getValue());
@@ -720,7 +710,7 @@ public void testParamAnnotations8() throws CoreException, IOException {
  */
 public void testParamAnnotations9() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String[] pathAndContents = new String[]{"p/X.java",
 				"package p;\n" +
 				"public class X {\n" +
@@ -730,7 +720,7 @@ public void testParamAnnotations9() throws CoreException, IOException {
 				"}" +
 				"@interface Default{\n" +
 				"}"};
-		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, JavaCore.VERSION_1_5);
+		addLibrary(project, "lib334783.jar", "libsrc.zip", pathAndContents, CompilerOptions.getFirstSupportedJavaVersion());
 
 		waitForAutoBuild();
 		IPackageFragmentRoot root = project.getPackageFragmentRoot(getFile("/P/lib334783.jar"));
@@ -745,13 +735,13 @@ public void testParamAnnotations9() throws CoreException, IOException {
 	}
 }
 /**
- * @bug 342393: Anonymous class' occurrence count is incorrect when two methods in a class have the same name.
+ * bug 342393: Anonymous class' occurrence count is incorrect when two methods in a class have the same name.
  *
  * @see "https://bugs.eclipse.org/bugs/show_bug.cgi?id=342393"
  */
 public void testBug342393() throws Exception {
 	try {
-		IJavaProject project = createJavaProject("Test342393", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("Test342393", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		project.open(null);
 			String fileContent =  "package p;\n"
 					 + "public class Test {\n"
@@ -851,7 +841,7 @@ public void testBug342393() throws Exception {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=377710
 public void test377710() throws CoreException, IOException {
 	try {
-		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		IJavaProject project = createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "public class Foo {}\n";
 		createFile("/P/src/Foo.java", source);
 		waitForAutoBuild();
@@ -866,7 +856,7 @@ public void test377710() throws CoreException, IOException {
 //Partial Match is not set for the API Calls.
 public void test405026a() throws CoreException, IOException {
 	try {
-		JavaProject project = (JavaProject) createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		JavaProject project = (JavaProject) createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n"  +
 						"\n" +
 						"public interface test13 {\n"  +
@@ -971,7 +961,7 @@ public void test405026a() throws CoreException, IOException {
 //Partial Match is set for the API's.
 public void test405026b() throws CoreException, IOException {
 	try {
-		JavaProject project = (JavaProject) createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		JavaProject project = (JavaProject) createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n"  +
 						"\n" +
 						"public interface test13 {\n"  +
@@ -1022,7 +1012,7 @@ public void test405026b() throws CoreException, IOException {
 // https://bugs.eclipse.org/bugs/show_bug.cgi?id=433404
 public void test433404() throws CoreException, IOException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL15_LIB"}, "bin", "1.5");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n"  +
 						"public class X {\n"  +
 						" 	FI fi = (i_) -> { return 0;};\n" +
@@ -1054,7 +1044,7 @@ public void test433404() throws CoreException, IOException {
 public void testBug458613() throws CoreException, IOException {
 	IJavaProject prj = null;
 	try {
-		prj = createJavaProject("Bug458613", new String[] {"src"}, new String[] {"JCL_LIB"}, "bin", "1.8");
+		prj = createJavaProject("Bug458613", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		createFolder("/Bug458613/src/p");
 		String source = "package p;\n" +
 				"interface I9<T> {\n" +
@@ -1093,7 +1083,7 @@ public void testBug458613() throws CoreException, IOException {
 public void testBug458613b() throws CoreException, IOException {
 	IJavaProject prj = null;
 	try {
-		prj = createJavaProject("Bug458613", new String[] {"src"}, new String[] {"JCL_LIB"}, "bin", "1.8");
+		prj = createJavaProject("Bug458613", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		createFolder("/Bug458613/src/p");
 		String source = "package p;\n" +
 				"interface I9<U, T> {\n" +
@@ -1133,7 +1123,7 @@ public void testBug458613b() throws CoreException, IOException {
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=479963
 public void test479963() throws CoreException, IOException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL_LIB"}, "bin", "1.8");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n" +
 						"public class X {\n" +
 						"	public void foo() {\n" +
@@ -1167,7 +1157,7 @@ public void test479963() throws CoreException, IOException {
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=479963
 public void test479963a() throws CoreException, IOException {
 	try {
-		createJavaProject("P", new String[] {"src"}, new String[] {"JCL_LIB"}, "bin", "1.8");
+		createJavaProject("P", new String[] {"src"}, new String[] {"JCL18_LIB"}, "bin", CompilerOptions.getFirstSupportedJavaVersion());
 		String source = "package p;\n" +
 						"public class X {\n" +
 						"	public void foo() {\n" +
@@ -1423,6 +1413,46 @@ public void test531046h() throws CoreException, IOException {
 		deleteProject("P");
 	}
 }
+// derived from test531046a, verifying we get same value from codeSelect or bindings
+public void testJavaElementViaBindings() throws CoreException, IOException {
+	if (!isJRE9) return;
+	org.eclipse.jdt.internal.core.CompilationUnit unit = null;
+	try {
+		createJava10Project("P", new String[] {"src"});
+		createFolder("/P/src/p");
+		createFile("/P/src/p/X.java", "");
+		waitForAutoBuild();
+
+		unit = (org.eclipse.jdt.internal.core.CompilationUnit)getCompilationUnit("/P/src/p/X.java");
+		unit.becomeWorkingCopy(new ProblemRequestor(), null);
+		unit.getBuffer().setContents("""
+			package p;
+			public class X {
+			  public static void main(java.lang.String[] args) {
+			    var s1 = args[0];
+			    System.out.println(s1);
+			  }
+			}
+			""");
+		CompilationUnit dom = unit.makeConsistent(AST.getJLSLatest(), true, 0, null, null);
+		VariableDeclarationFragment domVariable = (VariableDeclarationFragment)
+			((VariableDeclarationStatement)
+				((TypeDeclaration)dom.types().get(0)).getMethods()[0].getBody().statements().get(0))
+			.fragments().get(0);
+		ILocalVariable variable = (ILocalVariable)domVariable.resolveBinding().getJavaElement();
+		assertEquals("incorrect type", "Ljava.lang.String;", variable.getTypeSignature());
+
+		SingleVariableDeclaration parameterVar = (SingleVariableDeclaration)
+				((TypeDeclaration)dom.types().get(0)).getMethods()[0].parameters().get(0);
+		variable = (ILocalVariable)parameterVar.resolveBinding().getJavaElement();
+		assertEquals("incorrect type", "[Ljava.lang.String;", variable.getTypeSignature());
+	} finally {
+		if (unit != null) {
+			unit.discardWorkingCopy();
+		}
+		deleteProject("P");
+	}
+}
 public void testBug533884a() throws Exception {
 	if (!isJRE9) return;
 	try {
