@@ -16,13 +16,15 @@ package org.eclipse.jdt.core.tests.model;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
-
 import junit.framework.Test;
-
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.IWorkspaceRunnable;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.NullProgressMonitor;
+import org.eclipse.core.runtime.OperationCanceledException;
+import org.eclipse.core.runtime.Path;
 import org.eclipse.jdt.core.*;
 import org.eclipse.jdt.internal.core.util.Util;
 import org.eclipse.team.core.RepositoryProvider;
@@ -292,6 +294,7 @@ public void testDelete2Fields() throws CoreException {
  * <li>closing the package of the compilation unit does not close the copy</li>
  * <li>ensures that working copies are unique
  * <li>ensures committing changes from working copies
+ * </ul>
  */
 public void testGeneral() throws JavaModelException, CoreException {
 
@@ -635,25 +638,25 @@ public void testNonExistingCU() throws JavaModelException {
 	try {
 		// getBuffer()
 		workingCopy = nonExistingCU.getWorkingCopy(null);
-		assertSourceEquals("Buffer should be empty", "", ((IOpenable)workingCopy).getBuffer().getContents());
+		assertSourceEquals("Buffer should be empty", "", workingCopy.getBuffer().getContents());
 
 		// exists()
-		assertTrue("Working copy should exists", ((IJavaElement)workingCopy).exists());
+		assertTrue("Working copy should exists", workingCopy.exists());
 
 		// getCorrespondingResource()
-		assertEquals("Corresponding resource should be null", null, ((IJavaElement)workingCopy).getCorrespondingResource());
+		assertEquals("Corresponding resource should be null", null, workingCopy.getCorrespondingResource());
 
 		// getPrimaryElement()
 		assertEquals("Unexpected orginal element", nonExistingCU, workingCopy.getPrimaryElement());
 
 		// getPath()
-		assertEquals("Unexpected path", new Path("/P/src/x/y/NonExisting.java"), ((IJavaElement)workingCopy).getPath());
+		assertEquals("Unexpected path", new Path("/P/src/x/y/NonExisting.java"), workingCopy.getPath());
 
 		// getResource()
-		assertEquals("Unexpected resource", nonExistingCU.getResource(), ((IJavaElement)workingCopy).getResource());
+		assertEquals("Unexpected resource", nonExistingCU.getResource(), workingCopy.getResource());
 
 		// isConsistent()
-		assertTrue("Working copy should be consistent", ((IOpenable)workingCopy).isConsistent());
+		assertTrue("Working copy should be consistent", workingCopy.isConsistent());
 
 		// restore()
 		boolean exception = false;
@@ -665,19 +668,19 @@ public void testNonExistingCU() throws JavaModelException {
 		assertTrue("Should not be able to restore from primary element", exception);
 
 		// makeConsistent()
-		((IOpenable)workingCopy).getBuffer().setContents(
+		workingCopy.getBuffer().setContents(
 			"public class X {\n" +
 			"}");
-		assertTrue("Working copy should not be consistent", !((IOpenable)workingCopy).isConsistent());
-		((IOpenable)workingCopy).makeConsistent(null);
-		assertTrue("Working copy should be consistent", ((IOpenable)workingCopy).isConsistent());
+		assertTrue("Working copy should not be consistent", !workingCopy.isConsistent());
+		workingCopy.makeConsistent(null);
+		assertTrue("Working copy should be consistent", workingCopy.isConsistent());
 
 		// save()
-		((IOpenable)workingCopy).getBuffer().setContents(
+		workingCopy.getBuffer().setContents(
 			"public class Y {\n" +
 			"}");
-		((IOpenable)workingCopy).save(null, false);
-		assertTrue("Working copy should be consistent after save", ((IOpenable)workingCopy).isConsistent());
+		workingCopy.save(null, false);
+		assertTrue("Working copy should be consistent after save", workingCopy.isConsistent());
 		assertTrue("Primary cu should not exist", !nonExistingCU.exists());
 
 		// commitWorkingCopy()
@@ -701,6 +704,7 @@ public void testNonExistingCU() throws JavaModelException {
  * <li>ensures that the copy cannot be renamed</li>
  * <li>ensures that the copy cannot be moved to the same location as the primary cu</li>
  * <li>ensures that the copy can be copied to a different location as the primary cu</li>
+ * </ul>
  */
 public void testOperations() throws JavaModelException {
 	// rename working copy
