@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2022, 2023 IBM Corporation and others.
+ * Copyright (c) 2022, 2024 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -8,42 +8,19 @@
  *
  * SPDX-License-Identifier: EPL-2.0
  *
+ * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.rewrite.describing;
 
 import java.util.List;
-
+import junit.framework.Test;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IPackageFragment;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.dom.AST;
-import org.eclipse.jdt.core.dom.ASTNode;
-import org.eclipse.jdt.core.dom.Block;
-import org.eclipse.jdt.core.dom.CompilationUnit;
-import org.eclipse.jdt.core.dom.ExpressionStatement;
-import org.eclipse.jdt.core.dom.GuardedPattern;
-import org.eclipse.jdt.core.dom.InfixExpression;
-import org.eclipse.jdt.core.dom.MethodDeclaration;
-import org.eclipse.jdt.core.dom.MethodInvocation;
-import org.eclipse.jdt.core.dom.NullPattern;
-import org.eclipse.jdt.core.dom.QualifiedName;
-import org.eclipse.jdt.core.dom.RecordPattern;
-import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
-import org.eclipse.jdt.core.dom.StringLiteral;
-import org.eclipse.jdt.core.dom.SwitchCase;
-import org.eclipse.jdt.core.dom.SwitchExpression;
-import org.eclipse.jdt.core.dom.SwitchStatement;
-import org.eclipse.jdt.core.dom.TypeDeclaration;
-import org.eclipse.jdt.core.dom.TypePattern;
-import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
-import org.eclipse.jdt.core.dom.VariableDeclarationStatement;
-import org.eclipse.jdt.core.dom.YieldStatement;
+import org.eclipse.jdt.core.dom.*;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ListRewrite;
 
-import junit.framework.Test;
-
 @SuppressWarnings({"rawtypes", "deprecation"})
 public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 
@@ -59,12 +36,7 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 	@Override
 	protected void setUp() throws Exception {
 		super.setUp();
-		if (this.apiLevel == AST.JLS21 ) { // Remove this after it is a standard feature
-			this.project1.setOption(JavaCore.COMPILER_COMPLIANCE, JavaCore.VERSION_21);
-			this.project1.setOption(JavaCore.COMPILER_SOURCE, JavaCore.VERSION_21);
-			this.project1.setOption(JavaCore.COMPILER_CODEGEN_TARGET_PLATFORM, JavaCore.VERSION_21);
-			this.project1.setOption(JavaCore.COMPILER_PB_ENABLE_PREVIEW_FEATURES, JavaCore.ENABLED);
-		}
+		setUpProjectAbove21();
 	}
 
 	private boolean checkAPILevel() {
@@ -76,6 +48,7 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 	}
 
 
+	@SuppressWarnings("removal")
 	public void testAddRecordSwitchPattern() throws Exception {
 		if (checkAPILevel()) {
 			return;
@@ -124,7 +97,13 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 			SingleVariableDeclaration patternVariable = ast.newSingleVariableDeclaration();
 			patternVariable.setType(ast.newSimpleType(ast.newSimpleName("Rectangle")));
 			patternVariable.setName(ast.newSimpleName("r1"));
-			tPattern.setPatternVariable(patternVariable);
+
+			if (this.apiLevel < AST.JLS22) {
+				tPattern.setPatternVariable(patternVariable);
+			} else {
+				tPattern.setPatternVariable((VariableDeclaration) patternVariable);
+			}
+
 			caseStatement.expressions().add(tPattern);
 			ListRewrite listRewrite= rewrite.getListRewrite(switchExpression, SwitchExpression.STATEMENTS_PROPERTY);
 			listRewrite.insertAt(caseStatement, 0, null);
@@ -159,6 +138,7 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 	}
 
 
+	@SuppressWarnings("removal")
 	public void testModifyRecordSwitchPattern() throws Exception {
 		if (checkAPILevel()) {
 			return;
@@ -207,7 +187,13 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 			SingleVariableDeclaration variableDeclaration = ast.newSingleVariableDeclaration();
 			variableDeclaration.setType(ast.newSimpleType(ast.newSimpleName("ColoredPoint")));
 			variableDeclaration.setName(ast.newSimpleName("clr1"));
-			typePattern.setPatternVariable(variableDeclaration);
+
+			if (this.apiLevel < AST.JLS22) {
+				typePattern.setPatternVariable(variableDeclaration);
+			} else {
+				typePattern.setPatternVariable((VariableDeclaration) variableDeclaration);
+			}
+
 			ListRewrite listRewrite= rewrite.getListRewrite(recordPatternR, RecordPattern.PATTERNS_PROPERTY);
 			listRewrite.insertAt(typePattern, 0, null);
 		}
@@ -304,6 +290,7 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 	}
 
 
+	@SuppressWarnings("removal")
 	public void testAddRecordInstanceOfPattern() throws Exception {
 		if (checkAPILevel()) {
 			return;
@@ -345,7 +332,12 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 			SingleVariableDeclaration patternVariable = ast.newSingleVariableDeclaration();
 			patternVariable.setType(ast.newSimpleType(ast.newSimpleName("Integer")));
 			patternVariable.setName(ast.newSimpleName("i"));
-			typePattern.setPatternVariable(patternVariable);
+			if (this.apiLevel < AST.JLS22) {
+				typePattern.setPatternVariable(patternVariable);
+			} else {
+				typePattern.setPatternVariable((VariableDeclaration) patternVariable);
+			}
+
 			guardedPattern.setPattern(typePattern);
 			InfixExpression infixExpression = ast.newInfixExpression();
 			infixExpression.setOperator(InfixExpression.Operator.GREATER);
@@ -387,6 +379,7 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 		assertEqualString(preview, buf.toString());
 	}
 
+	@SuppressWarnings("removal")
 	public void testModifyGuardedPattern() throws Exception {
 		if (checkAPILevel()) {
 			return;
@@ -428,7 +421,13 @@ public class ASTRewritingRecordPatternTest extends ASTRewritingTest {
 			SingleVariableDeclaration patternVariable = ast.newSingleVariableDeclaration();
 			patternVariable.setType(ast.newSimpleType(ast.newSimpleName("Integer")));
 			patternVariable.setName(ast.newSimpleName("i"));
-			typePattern.setPatternVariable(patternVariable);
+
+			if (this.apiLevel < AST.JLS22) {
+				typePattern.setPatternVariable(patternVariable);
+			} else {
+				typePattern.setPatternVariable((VariableDeclaration) patternVariable);
+			}
+
 			guardedPattern.setPattern(typePattern);
 			InfixExpression infixExpression = ast.newInfixExpression();
 			infixExpression.setOperator(InfixExpression.Operator.GREATER);
