@@ -16,12 +16,11 @@
  *******************************************************************************/
 package org.eclipse.jdt.core.tests.performance;
 
-import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.PrintStream;
 import java.util.ArrayList;
-
+import junit.framework.Test;
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IProjectDescription;
@@ -34,23 +33,7 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.Path;
-import org.eclipse.jdt.core.IClassFile;
-import org.eclipse.jdt.core.IClasspathEntry;
-import org.eclipse.jdt.core.ICompilationUnit;
-import org.eclipse.jdt.core.IField;
-import org.eclipse.jdt.core.IInitializer;
-import org.eclipse.jdt.core.IJavaElement;
-import org.eclipse.jdt.core.IJavaModel;
-import org.eclipse.jdt.core.IJavaProject;
-import org.eclipse.jdt.core.IMethod;
-import org.eclipse.jdt.core.IModuleDescription;
-import org.eclipse.jdt.core.IPackageFragment;
-import org.eclipse.jdt.core.IPackageFragmentRoot;
-import org.eclipse.jdt.core.IProblemRequestor;
-import org.eclipse.jdt.core.IType;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.JavaModelException;
-import org.eclipse.jdt.core.WorkingCopyOwner;
+import org.eclipse.jdt.core.*;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.search.IJavaSearchConstants;
@@ -68,8 +51,6 @@ import org.eclipse.jdt.internal.core.JavaProject;
 import org.eclipse.jdt.internal.core.NameLookup;
 import org.eclipse.test.performance.Performance;
 
-import junit.framework.Test;
-
 @SuppressWarnings({"rawtypes", "unchecked"})
 public class FullSourceWorkspaceModelTests extends FullSourceWorkspaceTests implements IJavaSearchConstants {
 
@@ -129,8 +110,8 @@ private void setUpBigProject() throws CoreException, IOException {
 	try {
 		IWorkspace workspace = ResourcesPlugin.getWorkspace();
 		IWorkspaceRoot workspaceRoot = workspace.getRoot();
-		String targetWorkspacePath = workspaceRoot.getLocation().toFile().getCanonicalPath();
-		long start = System.currentTimeMillis();
+		String targetWorkspacePath = workspaceRoot.getLocation().toFile().toPath().normalize().toAbsolutePath().toString();
+		long startNanos = System.nanoTime();
 
 		// Print for log in case of project creation troubles...
 		File wkspDir = new File(targetWorkspacePath);
@@ -157,26 +138,28 @@ private void setUpBigProject() throws CoreException, IOException {
 			String path = workspaceRoot.getLocation().toString() + "/BigProject/src";
 			for (int i = 0; i < FOLDERS_COUNT; i++) {
 				if (PRINT && i>0 && i%10==0) System.out.print("		+ folder src"+i+"...");
-				long top = System.currentTimeMillis();
+				long topNanos = System.nanoTime();
 				for (int j = 0; j < PACKAGES_COUNT; j++) {
 					new java.io.File(path + i + "/org/eclipse/jdt/core/tests" + i + "/performance" + j).mkdirs();
 				}
-				if (PRINT && i>0 && i%10==0) System.out.println("("+(System.currentTimeMillis()-top)+"ms)");
+				if (PRINT && i > 0 && i % 10 == 0) {
+					System.out.println("(" + (System.nanoTime() - topNanos) / 1_000_000L + " ms)");
+				}
 			}
-			System.out.println("		=> global time = "+(System.currentTimeMillis()-start)/1000.0+" seconds)");
+			System.out.println("		=> global time = " + (System.nanoTime() - startNanos) / 1_000_000L + " ms)");
 
 			// Add project to workspace
-			start = System.currentTimeMillis();
+			startNanos = System.nanoTime();
 			System.out.print("	- add project to full source workspace...");
 			ENV.addProject(BIG_PROJECT_NAME);
 			BIG_PROJECT = (JavaProject) createJavaProject(BIG_PROJECT_NAME, sourceFolders, "bin", "1.4");
 			BIG_PROJECT.setRawClasspath(BIG_PROJECT.getRawClasspath(), null);
 		}
-		System.out.println("("+(System.currentTimeMillis()-start)+"ms)");
+		System.out.println("(" + (System.nanoTime() - startNanos) / 1_000_000L + " ms)");
 
 		// Add CU with secondary type
 		System.out.print("	- Create compilation unit with secondary type...");
-		start = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 		BIG_PROJECT_TYPE_PATH = new Path("/BigProject/src" + (FOLDERS_COUNT-1) + "/org/eclipse/jdt/core/tests" + (FOLDERS_COUNT-1) + "/performance" + (PACKAGES_COUNT-1) + "/TestBigProject.java");
 		IFile file = workspaceRoot.getFile(BIG_PROJECT_TYPE_PATH);
 		if (!file.exists()) {
@@ -203,10 +186,10 @@ private void setUpBigProject() throws CoreException, IOException {
 				"	}\n" +
 				"}\n" +
 				"class TestSecondary {}\n";
-			file.create(new ByteArrayInputStream(content.getBytes()), true, null);
+			file.create(content.getBytes(), true, false, null);
 		}
 		WORKING_COPY = (ICompilationUnit)JavaCore.create(file);
-		System.out.println("("+(System.currentTimeMillis()-start)+"ms)");
+		System.out.println("(" + (System.nanoTime() - startNanos) / 1_000_000L + "ms)");
 	} finally {
 		// do not delete project
 	}
@@ -337,7 +320,7 @@ protected void assertElementsEqual(String message, String expected, IJavaElement
  * @see org.eclipse.jdt.core.tests.model.AbstractJavaModelTests#assertElementsEqual(String, String, IJavaElement[], boolean)
  */
 protected void assertElementsEqual(String message, String expected, IJavaElement[] elements, boolean showResolvedInfo) {
-	StringBuffer buffer = new StringBuffer();
+	StringBuilder buffer = new StringBuilder();
 	if (elements != null) {
 		for (int i = 0, length = elements.length; i < length; i++){
 			JavaElement element = (JavaElement)elements[i];
@@ -760,7 +743,7 @@ public void testPerfReconcileBigFileWithSyntaxError() throws JavaModelException
 		"	 \"}\\n\"" +
 		"  );\n" +
 		"}\n";
-	StringBuffer bigContents = new StringBuffer();
+	StringBuilder bigContents = new StringBuilder();
 	bigContents.append("public class BigCU {\n");
 	int fooIndex = 0;
 	while (fooIndex < 2000) { // add 2000 methods (so that source is close to 1MB)
@@ -811,7 +794,7 @@ public void testReconcileDuplicates() throws JavaModelException {
 	tagAsSummary("Reconcile editor change on file with lots of duplicates", false); // do NOT put in fingerprint
 
 	// build big file contents
-	StringBuffer contents = new StringBuffer();
+	StringBuilder contents = new StringBuilder();
 	contents.append("public class CUWithDuplicates {\n");
 	int fooIndex = 0;
 	while (fooIndex < 2000) { // add 2000 duplicate methods
@@ -861,7 +844,7 @@ public void testPerfDeleteLotsOfMembersAndReconcile() throws JavaModelException
 	tagAsSummary("Reconcile editor change after deleting lots of members", false); // do NOT put in fingerprint
 
 	// build big file contents
-	StringBuffer contents = new StringBuffer();
+	StringBuilder contents = new StringBuilder();
 	contents.append("public class LotsOfMembers {\n");
 	int fooIndex = 0;
 	while (fooIndex < 15000) { // add 15000 methods
@@ -1363,10 +1346,10 @@ public void testReopenSingleProject() throws CoreException {
 	tagAsSummary("Reopen a single project in a workspace", false); // do NOT put in fingerprint
 
 	// First close all Eclipse projects
-	long startTime = 0;
+	long startNanos = 0;
 	if (PRINT) {
 		System.out.print("Close all Eclipse projects...");
-		startTime = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 	}
 	int length=ALL_PROJECTS.length;
 	for (int j=0; j<length; j++) {
@@ -1375,14 +1358,14 @@ public void testReopenSingleProject() throws CoreException {
 	waitUntilIndexesReady();
 	waitForAutoBuild();
 	if (PRINT) {
-		System.out.println((System.currentTimeMillis()-startTime)+"ms");
+		System.out.println((System.nanoTime() - startNanos) / 1_000_000L + "ms");
 	}
 
 
 	// Warm-up
 	if (PRINT) {
 		System.out.print("Warmup test...");
-		startTime = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 	}
 	final int warmup = WARMUP_COUNT / 10;
 	for (int i=0; i<warmup; i++) {
@@ -1395,14 +1378,14 @@ public void testReopenSingleProject() throws CoreException {
 		waitForManualRefresh();
 	}
 	if (PRINT) {
-		System.out.println((System.currentTimeMillis()-startTime)+"ms");
+		System.out.println((System.nanoTime() - startNanos) / 1_000_000L + "ms");
 	}
 
 	// Measures
 	if (PRINT) {
 		System.out.println();
 		System.out.println("Start measures:");
-		startTime = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 	}
 	for (int i=0; i<MEASURES_COUNT; i++) {
 		runGc();
@@ -1417,14 +1400,14 @@ public void testReopenSingleProject() throws CoreException {
 		stopMeasuring();
 	}
 	if (PRINT) {
-		System.out.println("	total time: "+((System.currentTimeMillis()-startTime)/1000.0)+"s");
+		System.out.println("	total time: " + ((System.nanoTime() - startNanos) / 1_000_000L) + "ms");
 	}
 
 	// Commit
 	if (PRINT) {
 		System.out.println();
 		System.out.println("Commit measures:");
-		startTime = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 	}
 	commitMeasurements();
 	assertPerformance();
@@ -1432,7 +1415,7 @@ public void testReopenSingleProject() throws CoreException {
 	// Finally reopen all Eclipse projects
 	if (PRINT) {
 		System.out.print("Reopen Eclipse projects...");
-		startTime = System.currentTimeMillis();
+		startNanos = System.nanoTime();
 	}
 	for (int i=0; i<length; i++) {
 		ALL_PROJECTS[i].getProject().open(null);
@@ -1442,7 +1425,7 @@ public void testReopenSingleProject() throws CoreException {
 	waitForManualRefresh();
 	runGc();
 	if (PRINT) {
-		System.out.println((System.currentTimeMillis()-startTime)+"ms");
+		System.out.println((System.nanoTime() - startNanos) / 1_000_000L + "ms");
 	}
 }
 //https://bugs.eclipse.org/bugs/show_bug.cgi?id=354332
