@@ -14,22 +14,23 @@
 package org.eclipse.jdt.internal.codeassist.impl;
 
 import java.util.Map;
-
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.internal.compiler.env.IElementInfo;
 import org.eclipse.jdt.internal.core.Annotation;
 import org.eclipse.jdt.internal.core.JavaElement;
 
-@SuppressWarnings("rawtypes")
 public class AssistAnnotation extends Annotation {
-	private final Map infoCache;
-	public AssistAnnotation(JavaElement parent, String name, Map infoCache) {
+	private final Map<IJavaElement, IElementInfo> infoCache;
+
+	public AssistAnnotation(JavaElement parent, String name, Map<IJavaElement, IElementInfo> infoCache) {
 		super(parent, name);
 		this.infoCache = infoCache;
 	}
 
 	@Override
-	public Object getElementInfo(IProgressMonitor monitor) throws JavaModelException {
+	public IElementInfo getElementInfo(IProgressMonitor monitor) throws JavaModelException {
 		return this.infoCache.get(this);
 	}
 }
